#!/bin/csh -f
setenv XPA_METHOD local
set pwd = `pwd`
###############################################
# INITIALIZE DEFAULTS
set force_view = 0
set REDO = 0
set image = "null"
set scriptpath = $0:h/      # LOCATION OF THIS SCRIPT. and the custom sex.config and sex.param files.   
set dao = "~/software/daophot/amonson"    # LOCATION OF PBS's daophot executables   
set coord = null           
set iraf = "/iraf/iraf/"   # THIS IS CORRECT FOR (MOST)
set irafarch = "macintel"  # THIS IS CORRECT FOR (MOST)MACS
set sedi = "sed -i '' "    # THIS IS CORRECT FOR MACS
set sex = 3                #  0 for all sextractor |  1 for sextractor detection and DAOPHOT PSF PHOTOMETRY | 2 for DAOFIND AND DAOPHOT PSF PHOTOMETRY  | 3 sex find psf, daofind sources.   
# IF USING THE SExtractor options a weight image will be used if found, otherwise not.   The expected weight name suffix is .exp.fits
set covfrac = 5           # minimum percentage coverage for acceptable sources.   (reject sources with coverage less than this). 
set psf2 = 0              # run a second pass PSF creation with 1st pass background stars subtracted.    
set npsf = 50
set thresh = ( 10 )    # iterate over the number of thresholds provided
set telescope = "null"
set border = ( 1 0 1 0 )
set filter = "null"
set logfile = /dev/null
set SEXSMOOTH = N
set density = 0
set rmfake = 0
set ZPOFFSET = 0
set PSFS = null
set ASSOC = null
set MAGZP = 25.0     
# set magnitude limits for artificial stars.  
set mag = ( 15 25 )
# spacing in pixels between adjacent artificial stars, should be large enough to not introduce significant crowding to the image.  
set grid = ( 50 50 ) 
# number of artificial star tests (each test will be on an offset grid).  The number of stars is limited by the grid spacing.  So run it a few times.  
set fake = 0

echo $*


while ( 1 )
    switch( $1 )
	case -npsf
	    if ( "$2" =~ "" ) then
		echo number of PSFs to use not specified... exiting.
		exit 1
	    endif
	    set npsf = $2 ; shift; shift
	    breaksw
	case -psf2
	    if ( "$2" =~ "" ) then
		echo number of PSF iterations to use not specified... exiting.
		exit 1
	    endif
	    set psf2 = $2 ; shift ; shift
	    breaksw
	case -border
	    if ( "$2" =~ "" ) then
		echo border not specified... exiting.
		exit 1
	    endif
	    set border = ( $2 ) ; shift; shift
	    breaksw
	case -fake
	    if ( "$2" =~ "" ) then
		echo fake star analysis not specified... exiting.
		exit 1
	    endif
	    set fake = ( $2 ) ; shift; shift
	    breaksw
	case -filter
	    if ( "$2" =~ "" ) then
		echo filter not specified... exiting.
		exit 1
	    endif
	    set filter = $2 ; shift; shift
	    breaksw
	case -covfrac
	    if ( "$2" =~ "" ) then
		echo min coverage not specified... exiting.
		exit 1
	    endif
	    set covfrac = $2 ; shift; shift
	    breaksw
	case -thresh
	    if ( "$2" =~ "" ) then
		echo Thresholds not specified... exiting.
		exit 1
	    endif
	    set thresh = ( $2 ) ; shift; shift
	    echo $thresh
	    breaksw
	case -force
	    if ( "$2" =~ "" ) then
		echo no force specified... exiting.
		exit 1
	    endif
	    set force_view = $2 ; shift; shift
	    breaksw
	case -sedi
	    if ( "$2" =~ "" ) then
		echo no sed command specified... exiting.
		exit 1
	    endif
	    set sedi = "$2" ; shift; shift
	    breaksw
	case -sex
	    if ( "$2" =~ "" ) then
		echo no extraction option specified... exiting.
		exit 1
	    endif
	    set sex = $2 ; shift; shift
	    breaksw
	case -assoc
	    if ( "$2" =~ "" ) then
		echo no coord list specified... exiting.
		exit 1
	    endif
	    set ASSOC = "$2" ; shift; shift
	    breaksw
	case -psfs
	    if ( "$2" =~ "" ) then
		echo no psf list specified... exiting.
		exit 1
	    endif
	    set PSFS = "$2" ; shift; shift
	    breaksw
	case -image
	    if ( "$2" =~ "" ) then
		echo no image specified... exiting.
		exit 1
	    endif
	    set image = "$2" ; shift; shift
	    breaksw
	case -dao
	    if ( "$2" =~ "" ) then
		echo no daopath specified... exiting.
		exit 1
	    endif
	    set dao = "$2" ; shift; shift
	    breaksw
	case -iraf
	    if ( "$2" =~ "" ) then 
		echo no irafpath specified... exiting. 
		exit 1
	    endif
	    set iraf = "$2" ; shift; shift
	    breaksw
	case -irafarch
	    if ( "$2" =~ "" ) then
		echo no irafarch specified... exiting. 
		exit 1
	    endif
	    set irafarch = $2 ; shift; shift
	    breaksw
	case -coord
	    if ( "$2" =~ "" ) then
		echo no coords specified... exiting. 
		exit 1
	    endif
	    set coord = ( $2 ) ; shift; shift
	    echo $coord
	    breaksw
	case -redo
	    if ( "$2" =~ "" ) then
		echo no redo specified... exiting. 
		exit 1
	    endif
	    set REDO = $2 ; shift; shift
	    breaksw
	case -telescope
	    if ( "$2" =~ "" ) then
		echo no telescope specified... exiting.
		exit 1
	    endif
	    set telescope = $2 ; shift; shift
	    breaksw
	default:
	    break
    endsw
end
if ( $scriptpath == "./" ) then
    set scriptpath = $pwd
endif
set daopath = $scriptpath
set fsast = $daopath/astromatic
echo $dao $daopath $fsast  
alias sedi $sedi

###############################################
# alias PROGRAM EXECUTABLES
alias images $iraf/bin.$irafarch/x_images.e
alias dataio $iraf/bin.$irafarch/x_dataio.e
alias iapphot $iraf/noao/bin.$irafarch/x_apphot.e
alias idaophot $iraf/noao/bin.$irafarch/x_daophot.e
alias daophot $dao/daophot 
alias allstar $dao/allstar 
alias daomatch $dao/daomatch 
alias daomaster $dao/daomaster 
#set daopars = $daopath/daopars
###############################################

###############################################
# GET IMAGE PARAMETERS
if ( ! -e $image ) then
    printf "\n$image does not exist... Exiting.\n" 
    exit 1
endif
set imgpath = $image:h
set image = $image:t
if ( $imgpath == $image ) then
    set imgpath = $pwd
endif
cd $imgpath
echo $image >>& $logfile
set MAXEXP = ( 0 0 )
foreach keyword ( TELESCOP GAIN SATURATE SCALE FWHM_AVE EFFRN BACKGND BACKSIG MAGZP EXPTIME MJD FILTER NAXIS1 NAXIS2 )
    set $keyword = `gethead -u $image $keyword`
    if ( `eval echo \$$keyword` == ___ ) then
	eval set $keyword = 1.0
    endif
    eval echo $keyword \$$keyword 
end
if ( $telescope != null ) then
    set TELESCOP = $telescope
    echo "TELESCOPE = $telescope"
endif
set EFFRN = 1
set GAIN = 1

if ( $border[2] == 0 ) then
    set border[2] = $NAXIS1
endif
if ( $border[4] == 0 ) then
    set border[4] = $NAXIS2
endif
echo "border = $border" 

set coadd = $image
set coaddw = $image:s/.fits/.exp.fits/



# SPITZER SPECIFIC 
if ( $TELESCOP == Spitzer ) then
    set coaddw = $image:s/.fits/_expt.fits/
    set SATURATE = 15000
    set FWHM_AVE = 3
    set FZP = ( 280.9 179.7 )
    # SET IRAC FLUX CONSTANTS
#    set zp = ( 18.593 18.089 )   # vicky's guide
    set zp = ( 18.6716 18.1876 )   # 1MJy/st = 1e6 (Jy/MJy) / (206265^2 "/st) * ( 0.6^2 "/pix ) = 8.4616e-6 Jy/pix
    # FOR 3.6um
    #  zp (standard aperture) = 2.5*log(280.9/8.4616e-6) = 18.803
    #  zp (small aperture) = 18.80275 - 2.5*log(1.12841) = 18.67158
    # FOR 4.5um
    #  zp (standard aperture) = 2.5*log(179.7/8.4616e-6) = 18.318
    #  zp (small aperture) = 18.31774 - 2.5*log(1.12738) = 18.18756

    set FC = ( 0.1253 0.1469 )  # mJy/st/DN
    set EFFRN = `gethead -u $image RONOISE TOTALBCD`
    echo $EFFRN
    if ( "$EFFRN" =~ __*  ) then
	set EFFRN = 1.0
    else
	set EFFRN = `awk 'BEGIN{print '$EFFRN[1]'/sqrt('$EFFRN[2]')}'`
#	set EFFRN = 0.01
    endif
    set GAIN = `gethead -u $image GAIN`
#    set GAIN = 100
    if ( $GAIN == ___ ) then
	set GAIN = 3.7
    endif
    echo "GAIN = $GAIN"
    echo "RNOI = $EFFRN"

    set attrib = `gethead $image CHNLNUM FLUXCONV FRAME_EX pxscal1 pxscal2`
    set CHN = $attrib[1]
    set FC = $attrib[2]
    set EXP = $attrib[3]
    set cora = ( $image:s/3p6um/correction_3p6um/ $image:s/4p5um/correction_4p5um/ )
    set corr = $imgpath/$cora[$CHN]:s/_dn//
    set ZP = $zp[$CHN]
    set BACKGND = 0.0
    set SCALE = 0.600012
    printf "\n$image\n$corr\nIRAC CHANNEL %1d: GAIN=%5.4f   FRAME_EX=%6.3f    ZP=%7.3f  SCALE = %f, %f\n\n" $CHN $FC $EXP $ZP $attrib[4] $attrib[5] 
    if ( $attrib[4] == -0.600012 && $attrib[5] == 0.600012   ) then
	echo Image parameters look okay 
    else
	echo Image scale are incorrect 
    endif
    printf "\nExp image $coaddw\n"
endif



# MAX FWHM  45 pixels is largest aperture allowed.  1.5" for fourstar images.  
if ( `echo " 7 * $FWHM_AVE / $SCALE > 45 " | bc -l `  ) then
    set FWHM_AVE = `echo " 45*$SCALE/7  " | bc -l `
    printf "Setting $image FWHM to $FWHM_AVE \n" 
endif



# MAKE FILENAME SHORTER
set coadd = image
set ndir = daophot_$image:r
if ( $REDO == 1 ) then
    rm -fr ./$ndir >>& /dev/null
endif
if ( ! -d $ndir ) then
    mkdir $ndir
endif
cd $ndir


# Update data dependent parameters. 
    # mathsubs.f
    # 1 - GAUSSIAN
    # 2 - MOFFAT15 beta=1.5
    # 3 - MOFFAT25 beta=2.5
    # 4 - MOFFAT35 beta=3.5
    # 5 - LORENTZ
    # 6 - PENNY1 (gaussian core(tilted), lorentzian wings (elongated))
    # 7 - PENNY2 (gaussian core(tilted), lorentzian wings (tilted))
    # -N try all up to N
set function = -7
set varorder = 1          # 1 constant | 2 linear  | 3  quadratic
set nclean = 5
set maxval = `awk 'BEGIN{print 1.0*'$SATURATE'+ 1*'$BACKGND'}'`
#set maxval = `awk 'BEGIN{print 0.5*'$SATURATE'+ 1*'$BACKGND'}'`
#set maxval = 5000
set daofwhm = `awk 'BEGIN{print 1*'$FWHM_AVE'/'$SCALE'}'`
set fitrad = `awk 'BEGIN{print 2*'$FWHM_AVE'/'$SCALE'}'`
#set fitrad = `awk 'BEGIN{print (5/3)*('$FWHM_AVE'/'$SCALE')**(3/5)}'`   # APPROX THEORETICALLY OPTIMUM APERTURE PHOTOMETRY
set psfrad = `awk 'BEGIN{print 5*'$FWHM_AVE'/'$SCALE'}'`
#set psfrad = `awk 'BEGIN{print 2*'$fitrad'}'`
set APER = `awk 'BEGIN{print 1.35*'$FWHM_AVE'/'$SCALE'}'`
set INAP = `awk 'BEGIN{print 3*'$FWHM_AVE'/'$SCALE'}'`
set OUTAP = `awk 'BEGIN{print 7*'$FWHM_AVE'/'$SCALE'}'`
# PSF SCALED BY FLUX, MAKE FLUX MEASURMENTS FOR PSF LARGE ENOUGH.  
set PINAP = $INAP
set POUTAP = $OUTAP



if ( $TELESCOP == Spitzer ) then
    # RUN PHOT ON PSF STARS WITH 6-6-14 APERTURES, IRAC PHOT IS 3-3-7, BUT SCALE IS 0.5 THE ORIGINAL.
    # MAKE APERTURES LARGE ENOUGH TO SCALE THE PSF FLUX CORRECTLY, USE 6,6,14 FOR THE FINAL SPITZER CORRECTION.  THE STANDARD APERTURE IS 10-12-20 BUT 337 WILL AVOID NEIGHBORS. BUT REQUIRES AN ADDITIONAL APERTURE CORRECTION OF 1.127 
    set MAGZP = 25.0
    set APER = 3
    set INAP = 6
    set OUTAP = 14
    set PINAP = 6
    set POUTAP = 14
    set varorder = 1
    set daofwhm = 3
    set fitrad = 3
    set psfrad = 10
endif


# GALEX SPECIFIC 
if ( $TELESCOP == Galex ) then
    set MAGZP = 25.0
#    set coaddw = $image:s/int.fits/rrhr.fits/
    set coaddw = $image:s/.fits/_rr.fits/
    echo Setting exposure map to $coaddw
    set SCALE = 1.5
    set GSCALE = 10000
    set maxval = `awk 'BEGIN{print 7*'$GSCALE' }'`
    set APER = 3
    set INAP = 6
    set OUTAP = 14
    set PINAP = 6
    set POUTAP = 14
    set varorder = 1
    set daofwhm = 3
    set fitrad = 3
    set psfrad = 10
    set SEXSMOOTH = N
endif


#set maxval = 1000000
set skyest = 0
set losharp = 0.3
set hisharp = 0.9
set recenter = 1
set photverbose = -1 # DAOPHOT VERBOSE OUTPUT -1 no err prompt| 0 prompts | 1 prompts+progress
set alsverbose = 2   # ALLSTAR VERBOSE OUTPUT
set usesat = 0     #  DOES NOT WORK WELL SINCE SATURATED PEAKS ARE OFTEN INVERTED, AND DAOPHOT LOOKS FOR A MAX VALUE TO CENTER.


# SKIP AHEAD IF BEING CALLED FROM FAKESTAR
if ( $sex == -1 ) then
    cp $imgpath/$image $coadd.fits
    cp $imgpath/image.cpsf $coadd.cpsf
    cp $imgpath/*.opt ./
    cp $imgpath/image.als.0 image.als.0 
    set TELESCOP = fakestar
    goto detect
endif
###############################################
if ( $sex == 1 || $sex == 2 || $sex == 3 ) then 
    printf "\n\n   RUNNING COMMAND LINE DAOPHOT FOR PSF CREATION AND PHOTOMETRY \n\n" 

    # CREATE A NEW IMAGE WITH A SHORTER FILENAME, SINCE DAOPHOT DOES NOT LIKE LONG FILENAMES.
    if ( -e $coadd.cpsf && ! $REDO == 1 ) then
	printf "\n $coadd.psf already exists... \n" 
    else
	rm -fr $coadd.fits >>& /dev/null
# DAOPHOT USES THE POISSON STATISTICS WHICH DEPEND ON THE BACKGROUND GAIN AND RN. 
	cp $daopath/iraf/imexpr.par imexpr.par
	if ( $TELESCOP == Spitzer ) then
	    # DAOPHOT LIKE e/s, REMEMBER TO BACK THIS OUT AT THE END PHOTOMETRY
	    sedi 's|imexpr.expr = |imexpr.expr = \"a/a.FLUXCONV*a.FRAME_EX \"|' imexpr.par
#	    sedi 's|imexpr.expr = |imexpr.expr = \"a+'$BACKGND'\"|' imexpr.par
	else if ( $TELESCOP == Galex ) then
	    if ( $filter == FUV ) then
		set ZP = 18.82
	    endif
	    if ( $filter == NUV ) then
		set ZP = 20.08
	    endif
	    sedi 's|imexpr.expr = |imexpr.expr = \"a*'$GSCALE'\"|' imexpr.par
	else
	    sedi 's|imexpr.expr = |imexpr.expr = \"a+'$BACKGND'\"|' imexpr.par
	endif
	sedi 's|imexpr.output = |imexpr.output = \"'$coadd.fits'\"|' imexpr.par
	sedi 's|imexpr.a = |imexpr.a = \"'$imgpath/$image'\"|' imexpr.par
	images imexpr \@imexpr.par

	# CREATE DAOPHOT .OPT FILES
	printf "\n  Creating daophot.opt to local directory `pwd` and setting parameters \n" 
	printf "Setting high good value to $maxval\n" 
	cat - <<EOF > daophot.opt
REad noise = $EFFRN
GAin = $GAIN
LOw good value (in sigmas) =  1.0
HIgh good value (in DN) = $maxval
FWhm of object = $daofwhm
THreshold for star detection = $thresh[1]
LS (low sharpness cutoff) = $losharp
HS (high sharpness cutoff) = $hisharp
LR (LOW ROUNDNESS CUTOFF) = -1.0
HR (HIGH ROUNDNESS CUTOFF) = 1.0
WAtch progress = $photverbose
FItting radius = $fitrad
PSf radius = $psfrad
VAriable psf = $varorder
SKy estimator = $skyest
ANalytical function type = $function
EXtra psf cleaning passes = $nclean
USe SATURATED PSF STARS  = $usesat
PErcent error = 0.750
PRofile error = 5.000
EOF
	printf "\n  Creating photo.opt to local directory `pwd` and setting parameters \n"
	cat - <<EOF > photo.opt
A1 = $APER
IS = $INAP
OS = $OUTAP
EOF
	printf "\n  Creating allstar.opt to local directory `pwd` and setting parameters \n\n"
	cat - <<EOF > allstar.opt
FItting radius =  $fitrad
REdetermine centroids = $recenter
WAtch progress = $alsverbose
PErcent error =  0.75
IS (INNER SKY RADIUS) =  $PINAP
OS (OUTER SKY RADIUS)  = $POUTAP
CE (CLIPPING EXPONENT)  =  6.0
CR (CLIPPING RANGE)  =  2.5
MAximum group size = 50.0
PRofile error =  5.0
EOF

	# MAKE COPY OF IMAGE
	cp $coadd.fits $coadd.psf.fits

	# PERFORM FIRST PASS DETECTION ON IMAGE
detect:
	# FIND SOURCES TO MATCH TO OTHER FRAMES, A SUBSET OF WHICH WILL BE USED FOR PSF CREATION.
	rm -fr $coadd.sex >>& /dev/null
	if ( -e $ASSOC ) then
	    echo "Found master coo coord file, using that.  $ASSOC " 
#	    set thresh = ( 1000000 1000000 1000000 )
#	    @ niter = $#thresh
	    @ niter = 1
	else
	    echo "No master coord file found " 
	    @ niter = $#thresh
	endif

	rm -fr allstar.log >>& /dev/null
	# COPY IMAGE TO INITIAL STATE
	if ( ! -e $coadd.sub.0.fits ) then
	    cp $coadd.fits $coadd.sub.0.fits
	endif
	if ( -e $imgpath/$coaddw ) then
	    echo copying $imgpath/$coaddw to $coadd.exp.0.fits
	    cp -f $imgpath/$coaddw $coadd.exp.0.fits
	    cp $daopath/iraf/imstat.par imstat.par
	    sedi 's|imstatistics.images = |imstatistics.images = \"'$coadd.exp.0.fits'\"|' imstat.par
	    sedi 's|imstatistics.fields = |imstatistics.fields = \"max,min\"|' imstat.par
	    set MAXEXP = `images imstatistics \@imstat.par`
	    printf "MAXEXP = $MAXEXP\n"
	endif

	@ i = 0
	while ( $i < $niter )
	    @ i ++
	    echo iteration $i of $niter 
	    @ j = $i - 1
	    #  UPDATE MASK FILE
	    if ( $j > 0 ) then
		@ k = $j - 1
		if ( -e $coadd.obj.$j.fits ) then
		    echo "Creating new mask" 
		    cp $daopath/iraf/imexpr.par imexpr.par
		    sedi 's|imexpr.expr = |imexpr.expr = \"b>0 ? 0 : a\"|' imexpr.par
		    sedi 's|imexpr.output = |imexpr.output = \"'$coadd.exp.$j.fits'\"|' imexpr.par
		    sedi 's|imexpr.a = |imexpr.a = \"'$coadd.exp.$k.fits'\"|' imexpr.par
		    sedi 's|imexpr.b = |imexpr.b = \"'$coadd.obj.$j.fits'\"|' imexpr.par
		    images imexpr \@imexpr.par
		    set sexw = MAP_WEIGHT
		else
		    ln -s $coadd.exp.0.fits $coadd.exp.$j.fits
		    set sexw = NONE
		endif
		if ( 1 ) then 
		    echo "Filling in craters with background value to avoid null detections..." 
		    cp $daopath/iraf/imexpr.par imexpr.par
		    mv $coadd.sub.$j.fits $coadd.tmp.$j.fits
		    sedi 's|imexpr.expr = |imexpr.expr = \"a<'$BACKGND' ? '$BACKGND' : a\"|' imexpr.par
		    sedi 's|imexpr.output = |imexpr.output = \"'$coadd.sub.$j.fits'\"|' imexpr.par
		    sedi 's|imexpr.a = |imexpr.a = \"'$coadd.tmp.$j.fits'\"|' imexpr.par
		    images imexpr \@imexpr.par
		endif
	    endif
	    set sexi = $coadd.exp.$j.fits

	    # USE FIND OR SEXTRACTOR
	    if ( -e $ASSOC && $i == 1 ) then
		printf "\nUsing Previously defined positions in $ASSOC \n" >>& /dev/stderr
		if ( -e image.als.0 ) then
		    head -n3 image.als.0 > $coadd.coo.$i
		else
 		    awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > $coadd.coo.$i
		    awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
			'$NAXIS1','$NAXIS2','-100','$maxval','$thresh[$i]','$APER','$GAIN','$EFFRN','$fitrad'}' >> $coadd.coo.$i
		endif
		awk '! /#/{printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,0,0,0,0}' $ASSOC  >> $coadd.coo.$i
	    else
		if ( $sex == 2 || $sex == 3 ) then
		    printf "\nStarting DAOPHOT see daophot.log for details\n" 
		    echo " Running FIND to find sources in $coadd.fits. Iteration = $i,  Threshold = $thresh[$i]"
		    mv daophot.opt daophot.opt.OLD
		    awk '{if($1 ~ /TH/ ){$NF = '$thresh[$i]';print }else{print}}' daophot.opt.OLD > daophot.opt
		    rm -fr $coadd.coo.$i >>& /dev/null
		    set log = daophot.log
		    @ loglim = 1000
		    daophot <<EOF >>& $log &
AT $coadd.sub.$j.fits
FIND
1,1                # Number of frames averaged, summed:
$coadd.coo.$i      # File for positions
y                  # Are you happy with this?
EOF
		    set lbid = $! # last job ID
		    set wcold = 0 
		    while ( `ps -c | grep $lbid` != "" )
			set wcnew = `cat $log | wc -l`
			if ( $wcnew > $loglim ) then
			    kill -9 $lbid
			    printf "\nSomething went wrong.  Check $log for details.\n" >>& /dev/stderr
			    exit 1
			endif
			set wcold = $wcnew
			sleep 1
		    end
		    awk '{if(NR>3)print $2,$3,$4,$5}' $coadd.coo.$i > $coadd.dao
		else
#		    set sexw = MAP_WEIGHT
		    # CANNOT USE MAP_WEIGHT AND A FLAG IMAGE.  
		    set sexw = NONE
		    if ( ! -e $sexi ) then
			set sexw = NONE
		    endif
		    set flagi = $coadd.flag.fits
		    if ( ! -e $flagi ) then
			cp $daopath/iraf/imexpr.par imexpr.par
			sedi 's|imexpr.output = |imexpr.output = \"'$flagi'\"|' imexpr.par
			sedi 's|imexpr.outtype = \"real\"|imexpr.outtype = \"int\"|' imexpr.par
			sedi 's|imexpr.expr = |imexpr.expr = \"(a==0 ? 1 : 0 )\"|' imexpr.par
			sedi 's|imexpr.a = |imexpr.a = \"'$imgpath/$image'\"|' imexpr.par
			images imexpr \@imexpr.par
		    endif
		    echo " Running `sex -v` to find sources in $coadd.fits. Iteration = $i,  Threshold = $thresh[$i], Flag = $flagi, Weight = $sexw " 
		    set param = sex.param
		    rm -fr $coadd.aper.$i.fits $coadd.obj.$i.fits $coadd.sex >>& /dev/null
#		    sex $coadd.sub.$j.fits -c $fsast/sex.config -PARAMETERS_NAME $fsast/$param -FILTER_NAME $fsast/gauss_1.5_3x3.conv -FILTER $SEXSMOOTH \
		    sex $coadd.sub.$j.fits -c $fsast/sex.config -PARAMETERS_NAME $fsast/$param -FILTER_NAME $fsast/default.conv -FILTER $SEXSMOOTH \
		    -STARNNW_NAME $fsast/default.nnw -CATALOG_NAME $coadd.sex -CATALOG_TYPE ASCII_HEAD -VERBOSE_TYPE QUIET \
		    -PIXEL_SCALE $SCALE -SEEING_FWHM $FWHM_AVE -SATUR_LEVEL $maxval -SATUR_KEY NONE \
		    -PHOT_APERTURES $APER -MAG_ZEROPOINT $MAGZP \
		    -FLAG_IMAGE $flagi \
		    -BACK_TYPE AUTO -BACK_VALUE $BACKGND -BACK_SIZE 16 -BACK_FILTERSIZE 2 \
		    -CHECKIMAGE_TYPE APERTURES,OBJECTS -CHECKIMAGE_NAME $coadd.aper.$i.fits,$coadd.obj.$i.fits \
		    -DETECT_THRESH $thresh[$i] -ANALYSIS_THRESH $thresh[$i]
#		    -WEIGHT_TYPE $sexw -WEIGHT_GAIN N -WEIGHT_THRESH "0" -WEIGHT_IMAGE $sexi \
		    if ( $status != 0 ) then
			echo SExtractor ERROR
			exit 0
		    endif
		endif

#		echo $coord $xycoord

		# CONVERT .coo.$i
		awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > $coadd.coo.$i
		awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
		'$NAXIS1','$NAXIS2','-100','$maxval','$thresh[$i]','$APER','$GAIN','$EFFRN','$fitrad'}' >> $coadd.coo.$i

		if ( $coord[1] == null ) then
		    set xycoord = ( 500 500 1000000 )
		else
		    set xycoord = `sky2xy $coadd.fits $coord | awk '{print $(NF-1),$NF,'$coord[3]'*3600/'$SCALE'}'`
		endif

		if ( $sex == 3 || $sex == 2 ) then
		    if ( -e $sexi ) then
			awk ' ! /#/ {print }' $coadd.dao > $coadd.tmp
			printf "Rejecting dao sources with less than $covfrac percent coverage.\n " 
			getpix -n 1 %7.0f $sexi @$coadd.tmp | paste $coadd.tmp - | awk '! /#/{if ( $NF>('$covfrac'/100*('$MAXEXP[1]')) && ( $1>'$border[1]' && $1<'$border[2]' && $2>'$border[3]' && $2<'$border[4]' ) && sqrt((($1-'$xycoord[1]'))**2+($2-'$xycoord[2]')**2)<'$xycoord[3]' ){printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,$3,$4,0,0}}'  >> $coadd.coo.$i
		    else
			awk '! /#/{if ( $4>='$losharp' && $4<='$hisharp' && ( $1>'$border[1]' && $1<'$border[2]' && $2>'$border[3]' && $2<'$border[4]' ) && sqrt((($1-'$xycoord[1]'))**2+($2-'$xycoord[2]')**2)<'$xycoord[3]' ){printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,$3,$4,0,0}}' $coadd.dao >> $coadd.coo.$i
		    endif		    
		else
		    if ( -e $sexi ) then
			awk ' ! /#/ {print }' $coadd.sex > $coadd.tmp
			printf "Rejecting sex sources with less than $covfrac percent coverage.\n " 
			getpix -n 1 %7.0f $sexi @$coadd.tmp | paste $coadd.tmp - | awk '! /#/{if ( $16<=0 && $NF>('$covfrac'/100*('$MAXEXP[1]')) && ($9+$10)<(1+10*'$usesat')*('$maxval') && $14<=15 && ( $1>'$border[1]' && $1<'$border[2]' && $2>'$border[3]' && $2<'$border[4]' ) && sqrt((($1-'$xycoord[1]'))**2+($2-'$xycoord[2]')**2)<'$xycoord[3]' ){printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,$3,$4,0,0}}'  >> $coadd.coo.$i
		    else
			awk '! /#/{if ( ($9+$10)<(1+10*'$usesat')*('$maxval') && $14<=15 && $16<=0 && ( $1>'$border[1]' && $1<'$border[2]' && $2>'$border[3]' && $2<'$border[4]' ) && sqrt((($1-'$xycoord[1]'))**2+($2-'$xycoord[2]')**2)<'$xycoord[3]' ){printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,$3,$4,0,0}}' $coadd.sex >> $coadd.coo.$i
		    endif
		endif
	    endif



	    # INTERACTIVELY TWEAK SOURCES
	    if (  $force_view == 1  ) then
#		if ( `xpaaccess daophot` == "yes" ) then
#		    xpaset -p daophot exit
#		endif
		set ccoords = `pwd`
		set ccoords = $ccoords:h/authors/rr_lyrae.cat
		echo $ccoords
		if ( -e $ccoords  ) then
		    awk '! /#/ {if($1~":"){split($1,a,":");split($2,b,":");RA=15*(a[1]+a[2]/60+a[3]/3600);DEC=(b[1]~"-"?-1:1)*((b[1]~"-"?-(b[1]):b[1])+b[2]/60+b[3]/3600)}else{RA=$1;DEC=$2};TEXT=$3;printf "wcs; circle(%10.6f,%10.6f,0.0001) # text = {%s}\n",RA,DEC,TEXT}' $ccoords > $ccoords.ds9
		endif
		if ( `xpaaccess daophot` == "yes" ) then
		    xpaset -p daophot cd `pwd`
		    if ( -e $ccoords  ) then
			xpaset -p daophot frame new
			xpaset -p daophot file $coadd.fits
			xpaset -p daophot regions load $ccoords.ds9
		    endif
		    xpaset -p daophot frame new
		    xpaset -p daophot file $coadd.sub.$j.fits
		    xpaset -p daophot scale log
		    xpaset -p daophot scale zscale
		    xpaset -p daophot lock frame wcs
		    xpaset -p daophot lock scale yes
		    xpaset -p daophot lock colorbar yes
		else
#		    ds9 -xpa local -title daophot  $coadd.sub.$j.fits -view colorbar no -scale log -scale log exp 1000 \
#			-scale zscale -zoom to fit -lock frame wcs -lock scale yes -lock colorbar yes &
#		    sleep 3


		    ds9 -xpa local -title daophot -view colorbar no -scale log -scale log exp 1000 -scale zscale -zoom to fit -lock frame wcs -lock scale yes -lock colorbar yes &
		    sleep 3
		    xpaset -p daophot cd `pwd`
		    if ( -e $ccoords  ) then
			xpaset -p daophot frame new
			xpaset -p daophot file $coadd.fits
			xpaset -p daophot regions load $ccoords.ds9
		    endif
		    xpaset -p daophot frame new
		    xpaset -p daophot file $coadd.sub.$j.fits
		endif
		if ( `xpaaccess daophot` == "yes" ) then
		    set limits = `xpaget daophot scale limits`
		    xpaset -p daophot scale limits $limits[1] `awk 'BEGIN{print '$limits[1]'+1000}'`
		    xpaset -p daophot regions format xy
		    xpaset -p daophot regions system image
		    xpaset -p daophot regions sky fk5
		    awk '{if(NR>3)print $2,$3 }' $coadd.coo.$i > $coadd.coords.$i
		    if ( -z $coadd.coords.$i ) then 
			printf "No stars in $coadd.coord.$i\n" >>& /dev/stderr
		    else
			xpaset -p daophot regions load $coadd.coords.$i
		    endif
		    printf "Add/Remove/Edit coordinates.  Hit y when ready, any key to continue with no changes or done to omit this iteration:  " >>& /dev/stderr
		    set input = $<
		    if ( $input == done ) then
			break
		    endif
		    if ( $input == psf ) then
			rm $PSFS
			goto epsf
		    endif
		    mv -f $coadd.coords.$i $coadd.obj.coords.$i
		    xpaget daophot regions > $coadd.coords.$i
		    mv -f $coadd.coo.$i $coadd.coo.0
		    head -n3 $coadd.coo.0 > $coadd.coo.$i
		    awk '{printf "%7d %10.4f %10.4f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,0,0,0,0}' $coadd.coords.$i >> $coadd.coo.$i
		    wc -l $coadd.coo.0
		    wc -l $coadd.coo.$i
		else
		    echo "DS9 daophot not available"
		endif
	    endif # force_view

	    # DO APERTURE PHOTOMETRY OF SELECTED STARS
	    if ( `cat $coadd.coo.$i | wc -l` > 3 ) then
		printf "Performing aperture photometry of %d detected sources...\n" `cat $coadd.coo.$i | wc -l`
		rm -fr $coadd.coo.$i.ap $coadd.als.$i $coadd.als.$i.tmp $coadd.sub.$i.fits >>& /dev/null
		set log = daophot.log
		@ loglim = 1000
		daophot <<EOF >>& $log 
AT $coadd.sub.$j.fits
PHOT
photo.opt          # File with aperture radii

$coadd.coo.$i      # Input position file
$coadd.coo.$i.ap   # Output file

EOF
		if ( -e $coadd.cpsf ) then
		    echo $coadd.cpsf already exists, skipping ahead to fitpsf...
		    goto fitpsf
		endif
	    else
		continue
	    endif
	# CREATE PSF FROM A SUBSET OF THIS LIST
epsf:
	    rm -fr $coadd.coo $coadd.ap $coadd.lst $coadd.nei $coadd.cpsf
	    rm -fr $coadd.als $coadd.sub.fits
	    if ( -e $PSFS ) then
		echo "Found master psf coord file, using that. $PSFS " 
		set npsf = `cat $PSFS | wc -l`
		awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > $coadd.lst
		awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
		    '$NAXIS1','$NAXIS2','-100','$maxval','$thresh[1]','$APER','$GAIN','$EFFRN','$fitrad'}' >> $coadd.lst
		awk '! /#/{printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,0,0,0,0}' $PSFS >> $coadd.lst
	    else
		if (  $sex == 2 ) then
		    echo "No master psf coord file found and sex set to $sex.  Finding psf sources with DAOPHOT FIND." #>>& /dev/stderr
		    printf "\nStarting DAOPHOT see daophot.log for details\n"
		    set log = daophot.log
		    @ loglim = 1000
		    daophot <<EOF >>& $log
AT $coadd
PICK
$coadd.coo.$i.ap   # Input file name
$npsf,20       # Desired number of stars, faintest magnitude:
$coadd.lst     # Output file name

EXIT
EOF
		else
		    echo "No master psf coord file found and sex set to $sex.  Finding psf sources within current list" 
		    if ( $coord[1] == null ) then
			# PICK APPROXIMATE MIDDLE PIXEL AND A BIG RANGE TO GET ALL PIXELS
			set xycoord = ( 500 500 1000000 )
		    else
			set xycoord = `sky2xy $coadd.fits $coord | awk '{print $(NF-1),$NF,'$coord[3]'*3600/'$SCALE'}'`
		    endif
		    echo $coord $xycoord
		    # CONVERT SEX TO DAO
		    awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > $coadd.lst
		    awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
			'$NAXIS1','$NAXIS2','-100','$maxval','$thresh[1]','$APER','$GAIN','$EFFRN','$fitrad'}' >> $coadd.lst
		    if ( ! -e $coadd.sex) then
			printf "$coadd.sex did not exist. looking for another input list... \n" >>& /dev/stderr
			if ( ! -e $coadd.coords.$i ) then
			    printf "No $coadd.coords.$i found.   Exiting...\n\n" >>& /dev/stderr
			    exit 2
			else
			    printf "Yes, $coadd.coords.$i found.  No SExtractor flags available for rejection though... \n\n" >>& /dev/stderr
			    if ( -e $sexi ) then
#				awk ' ! /#/ {print }' $coadd.coords.$i > $coadd.tmp
				awk 'BEGIN{RS=""}{if(NR>1){print $2,$3,$4,$8}}' $coadd.coo.$i.ap > $coadd.tmp
				printf "Rejecting Sources with less than $covfrac percent coverage.\n " >>& /dev/stderr
				getpix -n 1 %7.0f $sexi @$coadd.tmp | paste $coadd.tmp - | awk '! /#/{if ($NF>=('$covfrac'/100*('$MAXEXP[1]')) && ( $1>'$border[1]' && $1<'$border[2]' && $2>'$border[3]' && $2<'$border[4]' ) && sqrt((($1-'$xycoord[1]'))**2+($2-'$xycoord[2]')**2)<'$xycoord[3]' ){printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,$3,$4,0,0}}' | sort -g -k4 | head -n $npsf >> $coadd.lst
			    else
				awk '! /#/{if ( ( $1>'$border[1]' && $1<'$border[2]' && $2>'$border[3]' && $2<'$border[4]' ) && sqrt((($1-'$xycoord[1]'))**2+($2-'$xycoord[2]')**2)<'$xycoord[3]' ){printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,$3,$4,0,0}}' $coadd.sex | sort -g -k4 | head -n $npsf >> $coadd.lst
			endif
			    
			endif
		    else
			set STELL = 0.8
			set ELLIP = 0.2
			set LFWHM = 2
			if ( -e $sexi ) then
			    awk ' ! /#/ {print }' $coadd.sex > $coadd.tmp
			    printf "Rejecting Sources with less than $covfrac percent coverage.\n " 
			    getpix -n 1 %7.0f $sexi @$coadd.tmp | paste $coadd.tmp - | awk '! /#/{if ($NF>=('$covfrac'/100*('$GAIN')) && ($9+$10)<(1+10*'$usesat')*('$maxval') && $11>'$LFWHM' && $12<'$ELLIP' && 13 > '$STELL' && $14==0 && $16<=0 && ( $1>'$border[1]' && $1<'$border[2]' && $2>'$border[3]' && $2<'$border[4]' ) && sqrt((($1-'$xycoord[1]'))**2+($2-'$xycoord[2]')**2)<'$xycoord[3]' ){printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,$3,$4,0,0}}' | sort -n -k4 | head -n $npsf >> $coadd.lst
			else
			             # flux_max+back < maxval     &&  FWHM > '$LFWHM' &&   ELLIP < '$ELLIP'  && CLASS > '$STELL'
			    awk '! /#/{if ( ($9+$10)<(1+10*'$usesat')*('$maxval') && $11>'$LFWHM' && $12<'$ELLIP' && 13 >'$STELL' && $14==0 && $16<=0 && ( $1>'$border[1]' && $1<'$border[2]' && $2>'$border[3]' && $2<'$border[4]' ) && sqrt((($1-'$xycoord[1]'))**2+($2-'$xycoord[2]')**2)<'$xycoord[3]' ){printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,$3,$4,0,0}}' $coadd.sex | sort -g -k4 | head -n $npsf >> $coadd.lst
			endif
		    endif
		endif
	    endif
#   1 XPEAK_IMAGE            x-coordinate of the brightest pixel                        [pixel]
#   2 YPEAK_IMAGE            y-coordinate of the brightest pixel                        [pixel]
#   3 MAG_APER               Fixed aperture magnitude vector                            [mag]
#   4 MAGERR_APER            RMS error vector for fixed aperture mag.                   [mag]
#   5 MAG_AUTO               Kron-like elliptical aperture magnitude                    [mag]
#   6 MAGERR_AUTO            RMS error for AUTO magnitude                               [mag]
#   7 FLUX_AUTO              Flux within a Kron-like elliptical aperture                [count]
#   8 FLUX_RADIUS            Fraction-of-light radii                                    [pixel]
#   9 FLUX_MAX               Peak flux above background                                 [count]
#  10 BACKGROUND             Background at centroid position                            [count]
#  11 FWHM_IMAGE             FWHM assuming a gaussian core                              [pixel]
#  12 ELLIPTICITY            1 - B_IMAGE/A_IMAGE                                       
#  13 CLASS_STAR             S/G classifier output                                     
#  14 FLAGS                  Extraction flags                                          
#  15 IMAFLAGS_ISO           FLAG-image flags OR'ed over the iso. profile              
#  16 NIMAFLAGS_ISO          Number of flagged pixels entering IMAFLAGS_ISO            
createpsf:
	    # EDIT PSF LIST.
	    awk '{if(NR>3)print $2,$3}' $coadd.lst > $coadd.coords.1
	    awk '{if(NR>3)printf "image; annulus (%10.4f,%10.4f,%4.1f,%4.1f,%4.1f) \n",$2,$3,'$daofwhm','$fitrad','$psfrad'}' $coadd.lst > $coadd.reg
	    set mpsf = `cat $coadd.reg | wc -l`
	    if ( $force_view == 1 ) then
		# MUST EXIT DS9 AND RESTART
		if ( `xpaaccess daophot` == "yes" ) then
		    xpaset -p daophot exit
		endif
		if ( `xpaaccess daophot` == "yes" ) then
		    xpaset -p daophot cd `pwd`
		    xpaset -p daophot frame new
		    xpaset -p daophot file $coadd.psf.fits
		    xpaset -p daophot scale log
		    xpaset -p daophot scale zscale
		    xpaset -p daophot lock frame wcs
		    xpaset -p daophot lock scale yes
		    xpaset -p daophot lock colorbar yes
		else
		    ds9 -xpa local -title daophot  $coadd.psf.fits -view colorbar no -scale log -scale log exp 1000 \
			-scale zscale -zoom to fit -lock frame wcs -lock scale yes -lock colorbar yes   &
#			-scale zscale -zoom to fit -lock frame wcs -lock scale yes -lock colorbar yes -region $coadd.reg   &
		    sleep 3
		endif
		if ( `xpaaccess daophot` == "yes" ) then
		    set limits = `xpaget daophot scale limits`
		    xpaset -p daophot scale limits `awk 'BEGIN{print '$limits[1]'-2}'` `awk 'BEGIN{print '$limits[1]'+100}'`
		    if ( -z $coadd.reg ) then 
			printf "No stars in $coadd ( .coord.$i || .reg )\n" >>& /dev/stderr
		    else
			xpaset -p daophot regions load $coadd.reg
		    endif
		    if ( 1 ) then
			xpaset -p daophot zoom to 8
			rm -fr $coadd.coords
			@ kk = 0
			foreach loc ( "`cat $coadd.coords.1`" )
			    @ kk ++
			    xpaset -p daophot pan to $loc image
			    printf "hit r to reject or any key to accept and continue: $kk of $mpsf " >>& /dev/stderr
			    set input = $<
			    echo -n "$loc  --> " >>& /dev/stderr
			    if ( $input != r ) then
				printf "$loc\n" >> $coadd.coords
				echo "ACCEPTED ">>& /dev/stderr
			    else
				echo "REJECTED ">>& /dev/stderr
			    endif
			end
			xpaset -p daophot regions delete all
		    endif
		    xpaset -p daophot regions format xy
		    xpaset -p daophot regions system image
		    if ( -e $coadd.coords ) then
			mv $coadd.coords $coadd.psf.coords.0
			xpaset -p daophot regions load $coadd.psf.coords.0
		    endif
		    xpaset -p daophot zoom to fit
		    printf "Add/Remove/Edit coordinates for PSF STARS.  Hit y when ready, any key to continue with no changes:  " >>& /dev/stderr
		    set input = $<
		    if ( $input == done ) then
			echo haha, this does nothing.  
		    endif
		    xpaget daophot regions > $coadd.psf.coords
		    mv $coadd.lst $coadd.lst.0
		    head -n3 $coadd.lst.0 > $coadd.lst
		    awk '{printf "%7d %10.4f %10.4f %9.3f %9.3f %9.3f %9.3f\n",NR,$1,$2,0,0,0,0}' $coadd.psf.coords >> $coadd.lst
		else
		    echo "DS9 daophot not available" 
		endif
		# WRITE PSF COORDS TO MASTER FILE 
		set input = yes
		if ( $force_view == 1 ) then
		    printf "Update master psf coord file? [no|yes]" >>& /dev/stderr
		    set input = $<
		endif
		if ( $input == yes ) then
		    awk '{if(NR>3)print $2,$3}' $coadd.lst > $coadd.tmp
		    xy2sky $coadd.fits @$coadd.tmp  | awk '{print $1,$2,$3}'  > $pwd/$coadd.$filter.psf.coords
		    rm -fr $coadd.tmp
		endif
	    endif  # force_view
	    
	    # DO APERTURE PHOTOMETRY OF PSF STARS
	    rm -fr $coadd.lst.ap >>& /dev/null
	    printf "Aperture photometry of PSF sources...\n" 
	    set log = daophot.log
	    @ loglim = 1000
	    daophot <<EOF >>& $log 
AT $coadd.psf.fits
PHOT
photo.opt       # File with aperture radii

$coadd.lst      # Input position file
$coadd.lst.ap   # Output file

EXIT
EOF
	    #  CREATE PSF FROM SELECTED PSF STARS
	    rm -fr $coadd.cpsf >>& /dev/null
	    printf "Making PSF from PSF selected sources...\n"
	    set log = daophot.log
	    @ loglim = 1000
	    daophot <<EOF >>& $log
AT $coadd.psf.fits
PSF
$coadd.lst.ap   # File with aperture results
$coadd.lst      # File with PSF stars
$coadd.cpsf     # File for the PSF 

EXIT
EOF
	    if ( -z $coadd.cpsf ) then
		echo psf not created... Exiting. 
		exit 1
	    endif

	    #SUBTRACT PSF STARS
	    if ( 1 ) then
		rm -fr $coadd.als.0 $coadd.sub.0.fits >>& /dev/null
		printf "\nStarting ALLSTAR see allstar.log for details\n" 
		set log = allstar.log
		@ loglim = 1000
		# NOTE FIRST GAP IS NECESSARY.  
		allstar <<EOF >>& $log

$coadd        # Input image name
$coadd.cpsf   # File with the PSF
$coadd.lst.ap     # Input file
$coadd.als.0    # File for results
$coadd.sub.0.fits       # Name for subtracted image
EOF
		# PREVIEW
		if ( $force_view == 1 ) then
		    if ( `xpaaccess daophot` == "yes" ) then
			xpaset -p daophot cd `pwd`
			xpaset -p daophot frame new
			xpaset -p daophot file $coadd.sub.0.fits
			xpaset -p daophot scale log
			xpaset -p daophot scale zscale
			set limits = `xpaget daophot scale limits`
			xpaset -p daophot scale limits `awk 'BEGIN{print '$limits[1]'-2}'` `awk 'BEGIN{print '$limits[1]'+100}'`
		    endif
		    printf "Is this okay. redo | fitrad | psfrad to try again, any key to continue: " >>& /dev/stderr
		    set input = $<
		    if ( $input == redo ) then
			goto epsf
		    endif
		    if ( $input == fitrad ) then
			printf "Current fitrad = $fitrad, enter a new value: " >>& /dev/stderr
			set input = $<
			if ( $input != $fitrad ) then
			    set fitrad = $input
			    mv -f daophot.opt daophot.opt.old
			    awk '{if($0 ~ "FItting radius" ){$NF = '$fitrad'};print $0 }' daophot.opt.old > daophot.opt
			endif
			goto createpsf
		    endif
		    if ( $input == psfrad ) then
			printf "Current psfrad = $psfrad, enter a new value: " >>& /dev/stderr
			set input = $<
			if ( $input != $psfrad ) then
			    set psfrad = $input
			    mv -f daophot.opt daophot.opt.old
			    awk '{if($0 ~ "PSf radius" ){$NF = '$psfrad'};print $0 }' daophot.opt.old > daophot.opt
			endif
			goto createpsf
		    endif
		endif
	    endif  # SUBTRACT PSF STARS


fitpsf:
	    # DO PSF FITTING, NOTE FIRST GAP IS NECESSARY.  
	    printf "Performing PSF photometry of detected sources...\n" 
	    rm -fr $coadd.als.$i $coadd.als.$i.fits >>& /dev/null
	    set log = allstar.log
	    @ loglim = 1000
	    if ( $i == -1 ) then
		set tname = $coadd
	    else
		set tname = $coadd.sub.$j.fits
	    endif
	    allstar <<EOF >>& $log 

$tname                # Input image name
$coadd.cpsf           # File with the PSF
$coadd.coo.$i.ap      # Input file
$coadd.als.$i         # File for results
$coadd.sub.$i.fits    # Name for subtracted image

EXIT
EOF

	    # OFFSET THE STAR IDS TO AVOID CONFLICT WITH PREVIOUS LISTS
	    mv -f $coadd.als.$i $coadd.als.$i.tmp
	    set offset = `cat $coadd.als.$j | wc -l`
	    printf "OFFSETTING $coadd.als.$i BY $offset \n" 
	    daophot <<EOF >>& $log 
OFFSET
$coadd.als.$i.tmp     # Input file name:
$offset,0,0,0           # Additive offsets ID, DX, DY, DMAG: 
$coadd.als.$i     # Output file name (default image.off):

EXIT
EOF
	    rm -fr $coadd.als.$i.tmp >>& /dev/null

	    # INTERACTIVELY VIEW SUBTRACTED SOURCES
	    if ( $force_view == 1  ) then
		if ( `xpaaccess daophot` == "yes" ) then
		    xpaset -p daophot cd `pwd`
		    xpaset -p daophot frame new
		    xpaset -p daophot file $coadd.sub.$i.fits
		    xpaset -p daophot scale log
		    xpaset -p daophot scale zscale
		    xpaset -p daophot lock frame wcs
		    xpaset -p daophot lock scale yes
		    xpaset -p daophot lock colorbar yes
		else
		    ds9 -xpa local -title daophot  $coadd.sub.$i.fits -view colorbar no -scale log -scale log exp 1000 \
			-scale zscale -zoom to fit -lock frame wcs -lock scale yes -lock colorbar yes  &
		    sleep 3
		endif
		if ( `xpaaccess daophot` == "yes" ) then
		    set limits = `xpaget daophot scale limits`
		    xpaset -p daophot scale limits `awk 'BEGIN{print '$limits[1]'-2}'` `awk 'BEGIN{print '$limits[1]'+100}'`
		    printf " Thresh = ($thresh): Hit any key to continue or type 'done' to finish here: " >>& /dev/stderr
		    set input = $<
		    if ( $input == done ) then
			break
		    endif
		else
		    echo "DS9 daophot not available"
		endif
	    endif # force_view

	    printf "END OF NITER $i \n\n"
	end # END NITER WHILE LOOP

	# CAT ALS FILES TOGETHER
	if ( ! -e $coadd.als.1 ) then
	     printf "Something went wrong with object detection. $coadd \n  " >>& /dev/stderr
	    exit 1
	endif
	head -n3 $coadd.als.0 > $coadd.als
	cat $coadd.als.[0-9] | awk ' ! /nan/ {if(NF==9)printf "%7d %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f\n",$1,$2,$3,$4,$5,$6,$7,$8,$9}' | sort -g -k4 | head -n100000 >> $coadd.als
#	head -n3 $coadd.coo.1.ap > $coadd.ap
#	cat $coadd.coo.*.ap | awk '{print }' >> $coadd.ap


# TBD
# SUBTRACT ALL EXCEPT PSF STARS, GO BACK AND RECREATE PSF WITH BACKGROUND STARS REMOVED FOR A CLEANER PSF
	if ( $psf2 == 1 ) then
	    set psf2 = 0     # TURN OFF TO PREVENT RE-ENTERING
	    set mfact = 2.0
	    printf "\nPerforming Second pass PSF fitting with PSFRAD set to $mfact times original.\n" #>>& /dev/stderr
#	    set psfrad = `awk 'BEGIN{print '$mfact'*'$psfrad'}'`  #  EXTEND THE PSF A LITTLE LARGER NOW THAT STARS HAVE BEEN REMOVED
#	    set fitrad = `awk 'BEGIN{print '$mfact'*'$fitrad'}'`  #  EXTEND THE PSF A LITTLE LARGER NOW THAT STARS HAVE BEEN REMOVED
#	    set fitrad = 10
#	    set psfrad = 40
	    set PINAP = $fitrad
	    set POUTAP = $psfrad
	    mv -f daophot.opt daophot.opt.old
	    awk '{if($0 ~ "FItting radius" ){$NF = '$fitrad'};print $0 }' daophot.opt.old > daophot.opt
	    mv -f daophot.opt daophot.opt.old
	    awk '{if($0 ~ "PSf radius" ){$NF = '$psfrad'};print $0 }' daophot.opt.old > daophot.opt

	    rm -fr $coadd.psf.fits >>& /dev/null
	    printf "Subtracting all but original PSF stars from $coadd.fits\n" 
	    set log = daophot.log
	    @ loglim = 1000
	    daophot <<EOF >>& $log
AT $coadd
SUBSTAR      
$coadd.cpsf     # File with the PSF 
$coadd.als      # File with photometry
Y               # Do you have stars to leave in?
$coadd.als.0    # File with star list 
$coadd.psf.fits # Name for subtracted image

EXIT
EOF
	    rm -fr $coadd.cpsf >>& /dev/null
	    goto detect
#	    goto createpsf
	endif
    endif # ENDIF PSF EXISTS


correct:
    # CORRECT FOURSTAR PHOTOMETRY
    if ( $TELESCOP == Baade ) then
	echo "Correcting FourStar photometry "
	if ( -e image.alf ) then
	    set ext = alf
	else
	    set ext = als
	endif
	# NO STANDARD FOURSTAR APERTURE.  USE THE PSF VALUES, FINAL PHOT OFFSET DETERMINED FROM 2MASS STARS in phot.csh script.  
	set APER = $APER
	set INAP = $INAP
	set OUTAP = $OUTAP
	printf "\n  Creating photo.opt to local directory `pwd` and setting parameters \n"
	awk 'BEGIN {printf "%s = %4.1f\n","A1",'$APER'}' > photo.opt
	awk 'BEGIN {printf "%s = %4.1f\n","IS",'$INAP'}' >> photo.opt
	awk 'BEGIN {printf "%s = %4.1f\n","OS",'$OUTAP'}' >> photo.opt
	# RUN PHOT ON ONLY PSF STARS. 
	rm -fr $coadd.lst.ap >>& /dev/null
	set log = daophot.log
	@ loglim = 1000
	daophot <<EOF >>& $log
AT $coadd.psf.fits
PHOT
photo.opt       # File with aperture radii

$coadd.lst      # Input position file
$coadd.lst.ap   # Output file

EXIT
EOF

	$scriptpath/match.csh $coadd.lst.ap $coadd.$ext $coadd.match -2 2 $dao
	rm -f $coadd.match3 $coadd.match3 >>& /dev/null
	# (MAPER*APC) - MPSF
	awk '{d=$4-$6;s=sqrt($5**2+$7**2);if(NR>3){print d,s,$4}} ' $coadd.match.raw > $coadd.match2
	set APCOR = `$scriptpath/stats.csh -f $coadd.match2 -niter 4 -o $coadd.match3`
	echo "STATS: $APCOR"
#                     avg       dont add aperture correction error.  
#	set apc = ( $APCOR[5]  0 )
#                     avg     sigma_n-1/sqrt(n)  
	set apc = `awk 'BEGIN{print '$APCOR[5]','$APCOR[7]'/sqrt('$APCOR[1]')}'`
#                     avg        sigma_n-1
#	set apc = ( $APCOR[5]  $APCOR[7] )
#                   w_avg       1/sum(1/sigma^2)
#	set apc = ( $APCOR[8]  $APCOR[9] )
	echo "aperture correction: $apc"
    # MAKE PLOT 
	set psfile = $coadd.ps
	rm -fr $psfile
	if ( ! -e $psfile && -e /usr/local/bin/sm ) then
#>>& /dev/null
	    /usr/local/bin/sm -S << FIN >>& /dev/null
if ( '$psfile' == '' ) {device x11} else {dev postencap $psfile}   # output to .ps
define print_noheader 1
define TeX_strings 1
add_ctype gray 128 128 128
data $coadd.match2
lines 4 0
read { diff 1  err 2  apmag 3  }

data $coadd.match3
lines 4 0
read { diff2 1  err2 2  apmag2 3 }

window 1 1 1 1 
#limits apmag diff
limits 10 18 -0.5 0.5

ctype black
lweight 1
ltype 0
expand 1
box 1 2 0 0

ctype gray
ptype 4 0
points apmag diff

ctype black
ptype 4 3
points apmag2 diff2
error_y apmag2 diff2 err2


set xx = 0,30
set average = $apc[1]+0*xx
set RMS = $apc[2]+0*xx
ltype 0
connect xx average
ltype 1 
connect xx (average - RMS)
connect xx (average + RMS)
quit

FIN
	endif

	echo SM-DONE, DONE.
	mv -f $coadd.$ext $coadd.$ext.old
	head -n3 $coadd.$ext.old > $coadd.radec
	awk '{if(NR>3){ print $2,$3}}' $coadd.$ext.old > $coadd.tmp
	xy2sky -d $coadd.fits @$coadd.tmp >> $coadd.radec
	head -n3 $coadd.$ext.old > $coadd.$ext
	set ZP = $MAGZP
	set ZPOFFSET = `awk 'BEGIN {print -25.0+'$ZP'+'$apc[1]'}'`
	paste $coadd.$ext.old $coadd.radec | \
	awk ' ! /nan/ {if(NR>3 && NF>3){printf "%7.d %8.3lf %8.3lf %8.3lf %8.4lf %8.3lf %7d. %8.3lf %8.3lf %8.3lf\n", \
	    $1,$2,$3,\
	    $4+'$ZPOFFSET',\
	    sqrt($5**2+'$apc[2]'**2),\
	    $6,$7,$8,$9,$NF } }' >> $coadd.$ext
    endif
    #  END FOURSTAR CORRECTION


    # CORRECT SPITZER PHOTOMETRY
    if ( $TELESCOP == Spitzer ) then
	echo "Correcting Spitzer photometry "
	if ( -e image.alf ) then
	    set ext = alf
	else
	    set ext = als
	endif
	# STANDARD APERTURE
	set APER = 6
	set INAP = 6
	set OUTAP = 14
	printf "\n  Creating photo.opt to local directory `pwd` and setting parameters \n"
	awk 'BEGIN {printf "%s = %4.1f\n","A1",'$APER'}' > photo.opt
	awk 'BEGIN {printf "%s = %4.1f\n","IS",'$INAP'}' >> photo.opt
	awk 'BEGIN {printf "%s = %4.1f\n","OS",'$OUTAP'}' >> photo.opt
	# RUN PHOT ON ONLY PSF STARS. 
	rm -fr $coadd.lst.ap >>& /dev/null
	set log = daophot.log
	@ loglim = 1000
	daophot <<EOF >>& $log
AT $coadd.psf.fits
PHOT
photo.opt       # File with aperture radii

$coadd.lst      # Input position file
$coadd.lst.ap   # Output file

EXIT
EOF

	$scriptpath/match.csh $coadd.lst.ap $coadd.$ext $coadd.match -2 2 $dao
	rm -f $coadd.match3 $coadd.match3 >>& /dev/null
	# (MAPER*APC) - MPSF
	awk '{d=$4-$6;s=sqrt($5**2+$7**2);if(NR>3){print d,s,$4}} ' $coadd.match.raw > $coadd.match2
	set APCOR = `$scriptpath/stats.csh -f $coadd.match2 -niter 4 -o $coadd.match3`
	echo "STATS: $APCOR"
#                     avg       dont add aperture correction error.  
#	set apc = ( $APCOR[5]  0 )
#                     avg     sigma_n-1/sqrt(n)  
	set apc = `awk 'BEGIN{print '$APCOR[5]','$APCOR[7]'/sqrt('$APCOR[1]')}'`
#                     avg        sigma_n-1
#	set apc = ( $APCOR[5]  $APCOR[7] )
#                   w_avg       1/sum(1/sigma^2)
#	set apc = ( $APCOR[8]  $APCOR[9] )
	echo "aperture correction: $apc"
    # MAKE PLOT 
	set psfile = $coadd.ps
	rm -fr $psfile
	if ( ! -e $psfile && -e /usr/local/bin/sm ) then
#>>& /dev/null
	    /usr/local/bin/sm -S << FIN >>& /dev/null
if ( '$psfile' == '' ) {device x11} else {dev postencap $psfile}   # output to .ps
define print_noheader 1
define TeX_strings 1
add_ctype gray 128 128 128
data $coadd.match2
lines 4 0
read { diff 1  err 2  apmag 3  }

data $coadd.match3
lines 4 0
read { diff2 1  err2 2  apmag2 3 }

window 1 1 1 1 
#limits apmag diff
limits 10 18 -0.5 0.5

ctype black
lweight 1
ltype 0
expand 1
box 1 2 0 0

ctype gray
ptype 4 0
points apmag diff

ctype black
ptype 4 3
points apmag2 diff2
error_y apmag2 diff2 err2


set xx = 0,30
set average = $apc[1]+0*xx
set RMS = $apc[2]+0*xx
ltype 0
connect xx average
ltype 1 
connect xx (average - RMS)
connect xx (average + RMS)
quit

FIN
	endif
	echo SM-DONE, DONE.
    # GET PHOTOMETRIC CORRECTION
	mv -f $coadd.$ext $coadd.$ext.old
	head -n3 $coadd.$ext.old > $coadd.photcorr
	awk '{if(NR>3){ print $2,$3}}' $coadd.$ext.old > $coadd.tmp
	echo $corr
	getpix -n 1 %6.4f $corr @$coadd.tmp >> $coadd.photcorr
    # APPLY CORRECTION TO ALS FILE
	head -n3 $coadd.$ext.old > $coadd.$ext
	set ZPOFFSET = `awk 'BEGIN {print -25.0+'$ZP'+'$apc[1]'+( 2.5*log('$EXP') - 2.5*log('$FC')  )/log(10)}'`
	paste $coadd.$ext.old $coadd.photcorr | \
	awk ' ! /nan/ {if(NR>3 && NF>3){printf "%7.d %8.3lf %8.3lf %8.3lf %8.4lf %8.3lf %7d. %8.3lf %8.3lf %8.3lf\n", \
	    $1,$2,$3,\
	    $4+'$ZPOFFSET' + 2.5*log($NF)/log(10),\
	    sqrt($5**2+'$apc[2]'**2),\
	    $6,$7,$8,$9,$NF } }' >> $coadd.$ext
#	    $4-25.0+'$ZP'+'$apc[1]'+( 2.5*log('$EXP') - 2.5*log('$FC') + 2.5*log($NF) )/log(10),\
    endif
#  END SPITZER CORRECTION


#  GALEX CORRECTION	
    if ( $TELESCOP == Galex ) then
	echo "Correcting Galex photometry -25+$ZP "
	if ( -e image.alf ) then
	    set ext = alf
	else
	    set ext = als
	endif
	# STANDARD APERTURE
	set APER = 10
	set INAP = 10
	set OUTAP = 20
	printf "\n  Creating photo.opt to local directory `pwd` and setting parameters \n"
	awk 'BEGIN {printf "%s = %4.1f\n","A1",'$APER'}' > photo.opt
	awk 'BEGIN {printf "%s = %4.1f\n","IS",'$INAP'}' >> photo.opt
	awk 'BEGIN {printf "%s = %4.1f\n","OS",'$OUTAP'}' >> photo.opt
	# RUN PHOT ON ONLY PSF STARS. 
	rm -fr $coadd.lst.ap >>& /dev/null
	set log = daophot.log
	@ loglim = 1000
	daophot <<EOF >>& $log
AT $coadd.psf.fits
PHOT
photo.opt       # File with aperture radii

$coadd.lst      # Input position file
$coadd.lst.ap   # Output file

EXIT
EOF
	$scriptpath/match.csh $coadd.lst.ap $coadd.$ext $coadd.match -2 2 $dao
	rm -f $coadd.match3 $coadd.match3 >>& /dev/null
    # (MAPER*APC) - MPSF
	awk '{d=$4-$6;s=sqrt($5**2+$7**2);if(NR>3){print d,s,$4}} ' $coadd.match.raw > $coadd.match2
	set APCOR = `$scriptpath/stats.csh -f $coadd.match2 -niter 4 -o $coadd.match3`
	echo $APCOR
#                     avg       dont add aperture correction error.  
#	set apc = ( $APCOR[5]  0 )
#                     avg     sigma_n-1/sqrt(n)  
	set apc = `awk 'BEGIN{print '$APCOR[5]','$APCOR[7]'/sqrt('$APCOR[1]')}'`
#                     avg        sigma_n-1
#	set apc = ( $APCOR[5]  $APCOR[7] )
#                   w_avg       1/sum(1/sigma^2)
#	set apc = ( $APCOR[8]  $APCOR[9] )
	echo $apc
    # MAKE PLOT 
	set psfile = $coadd.ps
	rm -fr $psfile
	if ( ! -e $psfile && -e /usr/local/bin/sm ) then
#>>& /dev/null
	    /usr/local/bin/sm -S << FIN >>& /dev/null
if ( '$psfile' == '' ) {device x11} else {dev postencap $psfile}   # output to .ps
define print_noheader 1
define TeX_strings 1
add_ctype gray 128 128 128
data $coadd.match2
lines 4 0
read { diff 1  err 2  apmag 3  }

data $coadd.match3
lines 4 0
read { diff2 1  err2 2  apmag2 3 }

window 1 1 1 1 
#limits apmag diff
limits 10 18 -1.5 1.5

ctype black
lweight 1
ltype 0
expand 1
box 1 2 0 0

ctype gray
ptype 4 0
points apmag diff

ctype black
ptype 4 3
points apmag2 diff2
error_y apmag2 diff2 err2


set xx = 0,30
set average = $apc[1]+0*xx
set RMS = $apc[2]+0*xx
ltype 0
connect xx average
ltype 1 
connect xx (average - RMS)
connect xx (average + RMS)
quit

FIN
	endif
	echo SM-DONE, DONE.
	mv -f $coadd.$ext $coadd.$ext.old
	head -n3 $coadd.$ext.old > $coadd.radec
	awk '{if(NR>3){ print $2,$3}}' $coadd.$ext.old > $coadd.tmp
	xy2sky -d $coadd.fits @$coadd.tmp >> $coadd.radec
	head -n3 $coadd.$ext.old > $coadd.$ext
	set ZPOFFSET = `awk 'BEGIN {print -25.0+'$ZP'+'$apc[1]'+( 2.5*log('$GSCALE') )/log(10)}'`
	paste $coadd.$ext.old $coadd.radec | \
	awk ' ! /nan/ {if(NR>3 && NF>3){printf "%7.d %8.3lf %8.3lf %8.3lf %8.4lf %8.3lf %7d. %8.3lf %10.5lf %10.5lf \n", \
	    $1,$2,$3,\
	    $4+'$ZPOFFSET',\
	    sqrt($5**2+'$apc[2]'**2),\
	    $6,$7,$8,$10,$11 } }' >> $coadd.$ext
    endif
#	    $4-25.0+'$ZP'+'$apc[1]'+( 2.5*log('$GSCALE') )/log(10),\
#  END GALEX CORRECTION


# WRITE COO COORDS TO MASTER FILE 
    if ( -e $pwd/$coadd.coo.coords ) then
	set input = no
    else
	set input = yes
    endif
    if ( $force_view == 1 ) then
	printf "Update master coo coord file? [no|yes]" >>& /dev/stderr
	set input = $<
	if ( $input == yes ) then
	    printf "Updating master coo file...\n" >>& /dev/stderr
	    awk '{if(NR>3)print $2,$3}' $coadd.als > $coadd.tmp
	    xy2sky $coadd.fits @$coadd.tmp | awk '{print $1,$2,$3}' > $pwd/$coadd.$filter.coo.coords
	    rm -fr $coadd.tmp
	    cp -f $coadd.als $pwd/$coadd.$filter.alf.coords
	endif
    endif
endif # SEX = 0 1 2 3
################################################################################


# BRING ANY DS9 DAOPHOT BACKGROUND JOB TO THE FOREGROUND.
#ps -a | grep -E 'ds9 -title daophot' >>& /dev/stderr
#jobs >>& /dev/stderr
if ( `xpaaccess daophot` == "yes" ) then
    echo "Exiting ds9 daophot..." >>& /dev/stderr
    xpaset -p daophot exit
endif


################################################################################
density:
# MAKE OBJECT DENSITY MAP
if ( $fake != 0 ) then
#rm -fr $coadd.rho.fits tmp.fits tmp.txt tmp2.txt
    if ( -e $coadd.rho.fits ) then
	echo "Density Map $coadd.rho.fits already exists." >>& /dev/stderr
    else
	echo "Making Density Map $coadd.rho.fits" >>& /dev/stderr
	rm -fr tmp.fits tmp.txt tmp2.txt >>& /dev/null
	set block = 60   # number of sources in a block x block arcsecond box

	set magnify = `awk 'BEGIN {print ('$block'/'$SCALE')}'`
	set scale1 = `awk 'BEGIN {print int('$NAXIS1'/('$magnify')+1)}'`
	set scale2 = `awk 'BEGIN {print int('$NAXIS2'/('$magnify')+1)}'`
	set magnify1 = `awk 'BEGIN {print ('$NAXIS1'/('$magnify')+0.5)}'`
	set magnify2 = `awk 'BEGIN {print ('$NAXIS2'/('$magnify')+0.5)}'`
	awk 'BEGIN{for(j=1;j<='$scale2';j++){for(i=1;i<='$scale1';i++){printf "%04d %04d\n",j,i}}}{if(NR>3)printf "%04d %04d\n",int($3/'$magnify'+1),int($2/'$magnify'+1)}' $coadd.als | sort -g | uniq -c | awk '{print $1-1}' > tmp.txt
	awk 'BEGIN{for(j=1;j<='$scale2';j++){for(i=1;i<='$scale1';i++){printf "%04d %04d\n",j,i}}}{if(NR>3)printf "%04d %04d\n",int($3/'$magnify'+1),int($2/'$magnify'+1)}' $coadd.als | sort -g | uniq -c | awk '{print $2,$3,$1-1}' > tmp2.txt

	cp $daopath/iraf/rtext.par rtext.par
	sedi 's|input = |input = \"'tmp.txt'\"|' rtext.par
	sedi 's|output = |output = \"'tmp.fits'\"|' rtext.par
	sedi 's|dim = |dim = \"'$scale1','$scale2'\"|' rtext.par
	dataio rtextimage \@rtext.par
	cp $daopath/iraf/magnify.par magnify.par
	sedi 's|input = |input = \"'tmp.fits'\"|' magnify.par
	sedi 's|output = |output = \"'$coadd.rho.fits'\"|' magnify.par
	sedi 's|xmag = |xmag = \"'$magnify'\"|' magnify.par
	sedi 's|ymag = |ymag = \"'$magnify'\"|' magnify.par
	sedi 's|x1 = INDEF|x1 = \"'0.5'\"|' magnify.par
	sedi 's|x2 = INDEF|x2 = \"'$magnify1'\"|' magnify.par
	sedi 's|y1 = INDEF|y1 = \"'0.5'\"|' magnify.par
	sedi 's|y2 = INDEF|y2 = \"'$magnify2'\"|' magnify.par
	images magnify \@magnify.par
	sethead $coadd.rho.fits BUNIT\=Sources/${block}x${block} arcseconds
#	rm -fr tmp.fits tmp.txt tmp2.txt >>& /dev/null
# CURRENTLY THE UNITS ARE SOURCES PER PIXEL.  
    endif
endif

################################################################################
fake:
# PERFORM FAKE STAR ERROR ANALYSIS
if ( $fake != 0 ) then
    echo "Performing Fake star test on $coadd.fits." >>& /dev/stderr
    
    if ( -e $coadd.tmp.2 ) then
	goto pyth
    endif
    rm -fr ${coadd}_* daophot_*.log >>& /dev/null

# number of simultaneous iterations to run.  depends on computer performace.  
    set BKJOBS = 25
# get the mag limits from the mag file:
    if ( 1 ) then
#	set mag = `awk 'BEGIN{min=99;max=-99}{if(NR>3 && $4<40){min=$4<min?$4:min;max=$4>max?$4:max}}END{print min,max+2.0}' $coadd.als`
	set mag = `awk 'BEGIN{min=99;max=-99}{if(NR>3 && $4<40){min=$4<min?$4:min;max=$4>max?$4:max}}END{print 25-2.5*log('$maxval')/log(10)+('$ZPOFFSET'),max+0.5}' $coadd.als`
    endif
# FORCE ZP DIFFERENCE TO BE ZERO
#    if ( 0 ) then
#	set ZPOFFSET = 0
#    endif

    echo "mag limits for artificial star data are: $mag" >>& /dev/stderr
    # GENERATE FAKE STARS IN NATIVE DAOPHOT MAGNITUDES
    set mag = `awk 'BEGIN{print '$mag[1]'-('$ZPOFFSET'),'$mag[2]'-('$ZPOFFSET')}'`
    echo "mag limits for scaled artificial star data are: $ZPOFFSET :  $mag" >>& /dev/stderr

#  START THE ARTIFICIAL STAR ITERATIONS.
    @ niter = $fake
    @ iter = 1
    @ xiter = 0
    while ( $xiter < $niter )
	@ yiter = 0
	while ( $yiter < $niter )
	    set offsets = `awk 'BEGIN{print ('$grid[1]'/'$niter')*'$xiter',('$grid[1]'/'$niter')*'$yiter'}'`
	    $daopath/fakestar.csh -image $coadd.fits -id $iter -grid "$grid" -offsets "$offsets" -mag "$mag" -gain $GAIN -iraf $iraf -irafarch $irafarch -dao "$dao" >>& ${coadd}_${iter}.log &
	    
	    set numbkjobs = `ps -a | grep -E 'CarDAO' | wc -l`
	    while ( $numbkjobs > $BKJOBS )
		set numbkjobs = `ps -a | grep -E 'CarDAO' | wc -l`
		echo "CarDAO $numbkjobs current processes,  waiting for open slot..."
		sleep 5
	    end
	    @ iter ++
	    @ yiter ++
	end
	@ xiter ++
    end
    printf "\nWaiting for iterations to finish...\n" >>& /dev/stderr
    wait
# CONCATENTATE ALL ITERATION INTO ONE LIST
    printf "\nConcatenating files...\n" >>& /dev/stderr
    # CONVERT FAKE STARS BACK ONTO THE CORRECT ZERO POINT
    set mag = `awk 'BEGIN{print '$mag[1]'+('$ZPOFFSET'),'$mag[2]'+('$ZPOFFSET')}'`
    cat ${coadd}_*.comp | awk '{print $1,$2,$3,$4,$5+('$ZPOFFSET'),$6+('$ZPOFFSET'),$7}' > $coadd.fake    
    cat ${coadd}_*.coo | awk 'BEGIN{printf "\n\n\n"}{if(NF==7) print $1,$2,$3,$4+('$ZPOFFSET'),$5,$6,$7}' > $coadd.orig    
    if ( $rmfake == 1 ) then
	rm -fr ${coadd}_* >>& /dev/null
	rm -fr daophot_* >>& /dev/null
    endif
# COMPILE RESULTS TO ESTIMATE ERRORS FROM STAR TEST
    cat  ${coadd}.als | awk '{if(NR>3)print $2,$3,$4,$5}' > $coadd.tmp.1
    set coaddrho = $coadd.rho.fits
    if ( -e $coaddrho ) then
	getpix -n 1 %10.6f $coaddrho @$coadd.tmp.1 | paste $coadd.tmp.1 - | awk '{if($1>0)printf "%8.2f %8.2f %8.3f %8.3f %10.7f\n",$1,$2,$3,$4,$5}' > $coadd.tmp.2
    else
	awk '{if($1>0)printf "%8.2f %8.2f %8.3f %8.3f %10.7f\n",$1,$2,$3,$4,"0"}' $coadd.tmp.1 > $coadd.tmp.2
    endif

# ANALYZE THE RESULTS
pyth:
    if ( 1 ) then
	printf "\nStarting python script...\n" >>& /dev/stderr
	if ( -e /Users/amonson/software/CarPy/Setup.csh ) then
	    source /Users/amonson/software/CarPy/Setup.csh
	endif
	python $scriptpath/fakestar.py $coadd.orig $coadd.fake $mag[2] $coadd.tmp.2
	# ADD NEW COLUMN OF ARTIFICIAL STAR TEST MAGERR.
	mv $coadd.als $coadd.als.tmp
	head -n3 $coadd.als.tmp > $coadd.als
#	awk '{if(NR>3)print}' $coadd.als.tmp | paste - $coadd.tmp.2 >> $coadd.als
#    1 2 3  4  5    6     7    8    9    
#   ID X Y MAG MER BACK NITER CHI SHARP
	awk '{if(NR>3)print}' $coadd.als.tmp | paste - $coadd.tmp.2 | awk '{if($4<30)printf "%7d %10.3f %10.3f %8.3f %5.3f %7.3f %7.0f %7.2f %7.2f \n ",$1,$2,$3,$4,$16,$6,$7,$8,$9 }' >> $coadd.als
    endif

endif


printf "Finished with $image\n"
printf "Finished \n"

exit 0
