#! /bin/csh

#sky2xy /Volumes/Data-3/FourStar/CRRP/NGC1835/FINAL/Ks/TARGETS/2013-01-05_Ks_NGC1835_c1_56297_09441.fits @/Users/amonson/Documents/CRRP/OGLE/RRabc2.dat | paste - /Users/amonson/Documents/CRRP/OGLE/RRabc2.dat | grep -v off | awk '{RA=(substr($1,1,2)+substr($1,4,2)/60+substr($1,7,5)/3600)*15;DEC=substr($2,1,1)1*(substr($2,2,2)+substr($2,5,2)/60+substr($2,8,5)/3600);print RA,DEC,substr($3,16,6),$10,$11,$12,$13}' > /Users/amonson/Documents/CRRP/NGC1835/rr_lyrae.cat

# FIRST 2 arguments must be image and coordinate file

set cmd = /usr/local/bin/ds9
set datadir = $1:h
set image = $1
set coords = $2
set name = $1:t
set NX = 10
set scale = log
set pscale = 0
set limits = (-20 1700)
set postage = 0
#  remove first two arguments and look for other commands. 
shift;shift


set ncoord = `cat $coords | wc -l`
#set ncoord = 1
# MAKE A GRID OF X*Y = ncoord POSTAGE STAMPS 
set NY = `awk 'BEGIN {print int('$ncoord'/('$NX'+0.01))+1 }'`
set gap = 10


while ( 1 )
    switch( $1 )
	case -postage
	    set postage = 1 ; shift
	    breaksw
	case -pscale
	    set pscale = $2 ; shift; shift
	    breaksw
	case -scale
	    set scale = $2 ; shift; shift
	    breaksw
	case -limits
	    set limits = ( $2 ) ; shift; shift
	    breaksw
	case -nx
	    set NX = $2 ; shift; shift
	    breaksw
	case -ncoord
	    set ncoord = $2 ; shift; shift
	    breaksw
	default:
	    break
    endsw
end

echo $limits $ncoord
#exit 0

if ( $postage == 0 ) then
    awk '! /#/ {if($1~":"){split($1,a,":");split($2,b,":");RA=15*(a[1]+a[2]/60+a[3]/3600);DEC=(b[1]~"-"?-1:1)*((b[1]~"-"?-(b[1]):b[1])+b[2]/60+b[3]/3600)}else{RA=$1;DEC=$2};TEXT=$3;printf "wcs; circle(%10.6f,%10.6f,0.0001) # text = {%s}\n",RA,DEC,TEXT}' $coords > $coords.ds9
    $cmd $image -view colorbar no -scale zscale -region $coords.ds9
    exit
endif


# NOTE THERE IS A MINIMUM EDGE LIMIT, SO IF NECESSARY START LARGER THEN ZOOM IN
if ( $pscale != 0 ) then
    set bsize = 20      #  size of box in arc-seconds if pscale is provided.  
    set edge = `awk 'BEGIN {print int('$bsize'/'$pscale')}'` # pixels
else
    set edge = 100 # pixels, up to you to determine corresponding physical scale.
endif
set zoom = `awk 'BEGIN {print 200/'$edge'}'`  # enlargement factor for figures. 
echo $bsize $pscale $edge $zoom
# EACH STAMP IS edge/zoom*pscale arcseconds 
set W = `awk 'BEGIN{print int('$NX'*'$edge'*'$zoom'+('$NX'-1)*'$gap')}'`
set H = `awk 'BEGIN{print int('$NY'*'$edge'*'$zoom'+('$NY'-1)*'$gap')}'`

###############################################################

# DEFINE PRINTER
set args = "-print destination file"

# TURN OFF PANELS
set args = "$args -view colorbar no -view info no -view panner no"
set args = "$args -view magnifier no -view buttons no "

# SET TILE LAYOUT
set args = "$args -tile yes -tile grid -tile grid gap $gap -tile grid layout $NX $NY "
set args = "$args -width $W -height $H"

# SET GLOBAL REGIONS SETTINGS
set arg = "$args -region color black -region "

# LOAD IMAGE INTO EACH TILE AND CENTER SOURCE
foreach image ( `ls $datadir/$name` )
#    echo $image 
#    sleep 1
#    continue
    # SET ps FILENAME
    set args = "$args -print filename $image.ps"
    @ i = 0
    while ( $i <= $ncoord )
	@ i ++
	@ j = $i
	# SWITCH TO NEW TILE AND LOAD IMAGE, JUST LOAD FIRST IMAGE SINCE FRAME IS ALREADY OPEN
	if ( $i == 1 ) then
	    set args = "$args -fits $image "
	else if ( $i > $ncoord ) then
	    set args = "$args -frame first "
    	    set args = "$args -region delete all "
	    @ j = 1
	else
	    set args = "$args -frame new -fits $image "
	endif
	set coord = `awk '{if(NR=='$j'){print $1,$2}}' $coords`
	set label = `awk '{if(NR=='$j'){print $3}}' $coords`

	if ( 1 ) then
	    # CROP TO 1-arcmin, makes processing much faster.
	    set args = "$args -crop $coord 60 60 wcs fk5 arcsec "
	endif
	if ( 1 ) then
	    # Align wcs N up East left.
	    set args = "$args -wcs align yes "
	endif
	if ( 0 ) then
	    # SMOOTH IMAGE FOR DETECTION
	    set args = "$args -smooth function gaussian "
	    set args = "$args -smooth radius 3 "
	    set args = "$args -smooth yes "
	endif

	# SET WHERE TO ZOOM TO.
	set args = "$args -pan to $coord wcs fk5 "
	# SET WHERE TO ZOOM TO.
	set args = "$args -zoom to $zoom "


	# DISPLAY CROSSHAIRS
#	set args = "$args -crosshair $coord wcs fk5"
	# DISPLAY LABEL
#	set font = "times 12 bold italic"
	set font = "helvetica 16 bold roman" 
	set off = `awk 'BEGIN{print int(-0.4*'$zoom'*'$edge')}'`
	set args = "$args -region command "\""wcs;text $coord # text="\'"$label"\'" color=white font="\'"$font"\'" "\"" "
	set args = "$args -region select all -cursor 0 $off" 
    end
end

# SET IMAGE CONTRAST
switch ($scale)
    case zscalelin
    set args = "$args -scale zscale -scale linear"
    breaksw

    case zscalelog
    set args = "$args -scale zscale -scale log"
    breaksw

    default:
    set args = "$args -scale $scale -scale log exp 1000 -scale limits $limits[1] $limits[2]"
    breaksw
endsw


set args = "$args -invert"

# MATCH ALL FRAMES TO SAME CONTRAST
set args = "$args -match colorbars -match scales "


echo $cmd $args
#eval $cmd $args 
eval $cmd $args -print -exit &

exit 0



