#!/bin/csh -f
echo $*
# SET MAGNITUDE RANGE OF FAKE STARS TO BE ADDED
set mag = ( 13 25 )
set GAIN = 1.0
# SET DEFAULT GRID SPACING BETWEEN FAKE STARS
set grid = ( 50 50 )
set offsets = ( 0 0 )

# WHERE AM I
set pwd = `pwd`
set scriptpath = $0:h/      # LOCATION OF THIS SCRIPT.
if ( $scriptpath == "./" ) then
    set scriptpath = $pwd
endif
set daopath = $scriptpath
set dao = "~/software/daophot/amonson"    # LOCATION OF PBS's daophot executables   

# GET COMMAND LINE ARGUMENTS
set image = "null"
set REDO = 0
while ( 1 )
    switch($1)
	case -image
	    if ( "$2" =~ "" ) then
		echo no image specified... exiting.
		exit 1
	    endif
	    set image = "$2" ; shift; shift
	    breaksw
	case -redo
	    if ( "$2" =~ "" ) then
		echo no redo specified... exiting.
		exit 1
	    endif
	    set REDO = $2 ; shift; shift
	    breaksw
	case -offsets
	    if ( "$2" =~ "" ) then
		echo no offsets specified... exiting.
		exit 1
	    endif
	    set offsets = ( $2 ) ; shift; shift
	    breaksw
	case -grid
	    if ( "$2" =~ "" ) then
		echo no grid spacing specified... exiting.
		exit 1
	    endif
	    set grid = ( $2 ) ; shift; shift
	    breaksw
	case -id
	    if ( "$2" =~ "" ) then
		echo no id specified... exiting.
		exit 1
	    endif
	    set id =  $2  ; shift; shift
	    breaksw
	case -dao
	    if ( "$2" =~ "" ) then
		echo no daopath specified... exiting.
		exit 1
	    endif
	    set dao = "$2" ; shift; shift
	    breaksw
	case -gain
	    if ( "$2" =~ "" ) then
		echo no gain specified... exiting.
		exit 1
	    endif
	    set GAIN = ( $2 ) ; shift; shift
	    breaksw
	case -mag
	    if ( "$2" =~ "" ) then
		echo no mag range specified... exiting.
		exit 1
	    endif
	    set mag = ( $2 ) ; shift; shift
	    breaksw
	case -iraf
	    if ( "$2" =~ "" ) then 
		echo no irafpath specified... exiting. 
		exit 1
	    endif
	    set iraf = "$2" ; shift; shift
	    breaksw
	case -irafarch
	    if ( "$2" =~ "" ) then
		echo no irafarch specified... exiting. 
		exit 1
	    endif
	    set irafarch = $2 ; shift; shift
	    breaksw
	default:
	    break
    endsw
end

# CHECK IF DAOPHOT IS IN PATH
set dao = `which \daophot`
if ( $status == 0 ) then
    set dao = $dao:h
else
    if ( ! -e $dao/daophot ) then
	echo "DAOPHOT not found in Path."    
	exit 1
    endif
    alias daophot $dao/daophot
endif

echo check $irafarch
# GET IMAGE PARAMETERS
    if ( ! -e $image ) then
	printf "\n$image does not exist... Exiting.\n"
	exit 1
    endif
    set imgpath = $image:h
    set image = $image:t
    if ( $imgpath == $image ) then
	set imgpath = $pwd
    endif
    cd $imgpath


# MAKE A FAKE STAR LIST TO ADD TO EXISTING IMAGE.
    foreach keyword ( SCALE EFFGAIN SATURATE EFFRN NAXIS1 NAXIS2 )
	set $keyword = `gethead -u $image $keyword`
	if ( `eval echo \$$keyword` == ___ ) then
	    eval set $keyword = 1.0
	endif
    end
    if ( $SATURATE == 1.0 ) then
	set SATURATE = 10000
	set FWHM_AVE = 4
    endif


# set PSF to one created during first round of daophot
    set psfimg = $image:t:r.cpsf
    if ( ! -e $psfimg ) then
	echo $psfimg does not exist... Exiting.
	exit 2
    endif 

# MAKE A UNIQUE NAME ON WHICH TO ADD FAKE STARS
    if ( $?id ) then
	echo "Using ID: $id"
	set coadd = ${image:r}_${id}.fits
     else
	@ id = 0
	mkid:
	@ id ++
	set coadd = ${image:r}_${id}.fits
	if ( -e $coadd ) then
	    goto mkid
	endif
	echo "Using Created ID: $id"
     endif

# CONSIDER USING IRAF's STARLIST.
    set irafsl = 0
    set coords = ${image:r}_${id}.coo
    if ( $irafsl ) then
	echo not implemented yet
    else
	if ( 0 ) then
	    # UNIFORM DISTRIBUTION
	    awk 'BEGIN{srand();for(i='$offsets[1]';i<='$NAXIS1';i+='$grid[1]') {for(j='$offsets[2]';j<='$NAXIS2';j+='$grid[2]'){num++;printf "%6d %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f \n",num,i+rand(),j+rand(),rand()*('$mag[2]'-'$mag[1]')+'$mag[1]',0.000,0.5,1.0 }}}' > $coords
	else
	    # POWER LAW
	    # smaller power favors bright end
	    # larger power favors faint end.  (0.6 is standard)
	    set pow = 0.5
	    awk 'BEGIN{srand();for(i='$offsets[1]';i<='$NAXIS1';i+='$grid[1]') {for(j='$offsets[2]';j<='$NAXIS2';j+='$grid[2]'){num++;printf "%6d %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f \n",num,i+rand(),j+rand(),log(1*rand()*(10**(('$pow')*'$mag[2]'/(2.5))-10**(('$pow')*'$mag[1]'/(2.5)))+10**(('$pow')*'$mag[2]'/(-2.5)))/log(10)*(2.5)/('$pow'),0.000,0.5,1.0 }}}' > $coords
	endif
    endif
#    cp $coords $coords.1

# IF THERE IS A WEIGHT OR EXPOSURE MAP, REMOVE FAKE SOURCES FROM AREAS OF NULL WEIGHT.  
#set coaddw = $image:t:r.exp.0.fits
    set coaddw = $image
#    set FOT = 1.39      #  FAKE OBJECT THRESH,  BAD IMAGE VALUE.  

    set FOT = 0.00       # same %.2f format as in getpix.  
    if ( -e $coaddw ) then
	echo "Getting image pixel data from $coaddw"
	getpix -i -n 1 %.2f $coaddw @$coords | paste $coords - > $coords.1
    endif

# IF THERE IS A DENSITY MAP, PLACE VALUE AS CHISQ
    set coaddrho = $image:t:r.rho.fits
    if ( -e $coaddrho ) then
	getpix -i -n 1 %10.6f $coaddrho @$coords | paste $coords.1 - | \
	    awk '{if(NF>5){den=($NF<=0)?0:$NF/('$SCALE'**2);\
	    print $1,$2,$3,$4,$5,$6,den,$(NF-1)}}' > $coords.2
	mv $coords.2 $coords.1
    endif
#    awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > $coords
#    awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
#	'$NAXIS1','$NAXIS2','-100','$SATURATE','5','2','$GAIN','$EFFRN','5'}' >> $coords
    head -n3 ${image:r}.coo.1 > $coords
    awk '{if($NF !~ '$FOT' && $2>1 && $2<'$NAXIS1' && $3>1 && $3<'$NAXIS2') printf "%6d %9.3f %9.3f %9.3f %9.3f %9.3f %9.5f \n",$1,$2,$3,$4,$5,$6,$7 }' $coords.1 >> $coords #; rm -fr $coords.1 >>& /dev/null

# ADD FAKE STARS TO IMAGE.  
    set log = daophot_$id.log
    @ loglim = 1000
    printf "Making fake image $coadd\n" #>>& /dev/stderr
    daophot <<EOF >& $log &
AT $image
ADDSTAR      
$psfimg        # File with the PSF 
$id            # Seed (any integer):
$GAIN          # Photons per ADU:
$coords        # Input data file
$coadd
EXIT
EOF
    set lbid = $! # last job ID
    set wcold = 0 
    while ( `ps -c | grep $lbid` != "" )
	set wcnew = `cat $log | wc -l`
	if ( $wcnew > $loglim ) then
	    kill -9 $lbid
	    printf "\nSomething went wrong.  Check $log for details.\n" >>& /dev/stderr
	    exit 1
	endif
	set wcold = $wcnew
	sleep 1
    end
    wait

##############################################################################
##############################################################################
#  CALL dophot.csh script
set sex = -1
# ADD COORDINATES OF NEW ARTIFICIAL STARS
awk '{if(NR>3) print $2,$3}' $coords > $imgpath/$coords.fakecoo
# ADD COORDINATES OF ORIGINAL DETECTIONS
awk '{if(NR>3) print $2,$3}' ${image:r}.als >> $imgpath/$coords.fakecoo
set ASSOC = $imgpath/$coords.fakecoo
echo $ASSOC
# NOW TRY TO RECOVER STARS AT PROVIDED COORDINATES
$daopath/dophot.csh -image $coadd -dao "$dao" -iraf "$iraf" -irafarch $irafarch -sex $sex -assoc "$ASSOC" -force 0 -psf2 0 -fake 0 -redo 1 -skipc 1
cp daophot_$coadd:r/image.als $coords.als

##############################################################################
##############################################################################

# NOW MATCH FOUND FAKE SOURCES WITH ORIGINAL FAKE CATALOG.  
    echo "finding match between: $coords $coords.als"
    $scriptpath/match.csh $coords $coords.als $coords -1 2 $dao
# .cor/.raw file contains:
#  1  2  3  (     4        5    ) (     6        7    )   NF-1  NF
# ID  X  Y  Inst-MAG STDERR(EST)  Inst-MAG STDERR(EST)    CHI  SHARP 

# .mag file contains:
#  1  2  3               4        5                          6                       7      8    9      10        11
# ID  X  Y  Int-weight-MEANMAG STDERR(BASED ON IND FRAMES) EXTERR(REPEATABILITY)  NFRAMES  CHI SHARP var_INDEX frac_pos_res

# .mtr file contains:
#  1  2  3     4     5       6        7     8   9   10  11   12
# ID  X  Y  REFMAG REFERR REFSHARP REFCHI NEWID dx  dy  dmag dr  

# X Y DR DEN MAG MAG MERR

    if ( ! -e $coords:r.mtr ) then
	printf "Something went wrong During the Final Fake matching $coords ...\n"
	exit 1
    endif
    paste $coords:r.mtr $coords.raw | awk '{if(NR>3 && NF>=19 )print $2,$3,$12,$7,$4,$18,$19}' > $coords.comp
#rm -fr $log $coords.1 $coords.1.ap $coords.raw $coords.cor $coords.mag $coords:r.mtr $coords.mch $coords.als $coadd $coadd.sub.fits >>& /dev/null



exit 0

