import os
import sys
import numpy as np
#import pylab as pylab
import matplotlib.pyplot as plt
from matplotlib import rc
import pylab as pl
import scipy.optimize as opt
#import scipy.stats as stat


# ADD LATEX SUPPORT
#os.environ['PATH'] = os.environ['PATH'] + ':/usr/texbin'
#rc('text', usetex=True)
#rc('font', family='serif')

#print os.getcwd()
indao = sys.argv[1]
outdao = sys.argv[2]
mlim = float(sys.argv[3])
# READ INPUT DAOPHOT PARAMETRS
xin,yin,magin,rhoin = \
    np.loadtxt(indao,
    skiprows=3,
    dtype='float,float,float,float',
    usecols=(1,2,3,6),
    unpack=True)

# READ OUTPUT DAOPHOT PARAMETERS
xout,yout,dr,rho,true,mag,mer = \
    np.loadtxt(outdao,
    dtype='float,float,float,float,float,float,float',
    usecols=(0,1,2,3,4,5,6),
    unpack=True)


######\/ \/ \/ \/ \/  OPTIMIZE THE BIN SIZE \/ \/ \/ \/ \/#########
#  Shimazaki and Shinomoto. Neural Computation 2007, 19(6), 1503-1527
#  http://176.32.89.45/~hideaki/res/histogram.html
x = np.power(10,(0.6*true/2.5))
x_max = np.max(x)
x_min = np.min(x)
N_MIN = 4
N_MAX = 50
N = np.array(range(N_MIN,N_MAX))
D = (x_max-x_min)/N
C = np.zeros((np.size(D),1))
#Computation of the cost function
for i in xrange(np.size(N)):
    edges = np.linspace(x_min,x_max,N[i]+1) # Bin edges
    ki = plt.hist(x,edges) # Count # of events in bins
    ki = ki[0]    
    k = np.mean(ki) #Mean of event count
    v = sum((ki-k)**2)/N[i] #Variance of event count
    C[i] = (2*k-v)/((D[i])**2) #The cost Function
#Optimal Bin Size Selection
cmin = np.min(C)
idx  = np.where(C==cmin)
idx = int(idx[0])
optD = D[idx]
edges = np.linspace(x_min,x_max,N[idx]+1)
######/\ /\ /\ /\ /\  OPTIMIZE THE BIN SIZE /\ /\ /\ /\ /\#########



##########  BIN THE DATA  ############
#mbin = 2.5*np.log10(edges)/0.6

# BIN PARAMETERS
sorted = np.sort(mag)
indeces =  np.arange(0,sorted.size-1,sorted.size/11)
mbin = sorted[indeces]
# UNIFORM BINNING
mbin = np.linspace(np.min(true),np.max(true),20)
#mbin = np.arange(np.min(true),np.max(true),1)
binc = (mbin[:-1]+mbin[1:])/2

# BREAK INTO DIFFERENT DENSITY REGIONS
dense = [ "low", "medium", "high" ]
densecol = [ "b", "g", "r" ]
# ADD DENSITY DEPENDENCE
sorted = np.sort(rhoin)
print sorted[0], sorted[sorted.size-1], sorted.size, 
uniq = np.unique(sorted)
nden = np.minimum(uniq.size,len(dense)+1)
rhobin = np.linspace(uniq[0],uniq[uniq.size-1]+1e-10,nden)
rhoc = (rhobin[:-1]+rhobin[1:])/2
# NO DENSITY DEPENDENCE
rhobin = np.array([ 0, 10000 ])
rhoc = 0
# FIXED DENSITY DEPENDENCE
#rhobin = np.array([ 0, 0.001, 0.01, 10000 ])
#rhoc = [0, 0.001, 0.01]
print rhobin




rhocrit = np.digitize(rho,rhobin)
rhoincrit = np.digitize(rhoin,rhobin)
print rhoc

# FIND THE RELATIVE NUMBER OF RECOVERED SOURCES
np.seterr(all='ignore')
hisig = 3
losig = 3
truebin={}
magbin = {}
merbin = {}
drbin = {}
maginbin = {}
deltabin = {}
binassign = {}
ratiobin = {}
mean = {}
sig = {}
num = {}
xin = []
zin = []
yin = []
yer = []
wgt = []
print np.unique(rhoincrit)
print 
for rbval in range(1,rhobin.size): 

    maginbin[rbval] = magin[rhoincrit == rbval]
    truebin[rbval] = true[rhocrit == rbval]
    magbin[rbval] = mag[rhocrit == rbval]
    deltabin[rbval] = magbin[rbval] - truebin[rbval]
    merbin[rbval] = mer[rhocrit == rbval]
    drbin[rbval] = dr[rhocrit == rbval]
    ratiobin[rbval] = np.divide(np.maximum(0,np.histogram(truebin[rbval], mbin)[0]) , np.maximum(1,np.histogram(maginbin[rbval], mbin)[0]) ,dtype=float)
    print truebin[rbval], magbin[rbval], mbin, rbval
    binassign[rbval] = np.digitize( magbin[rbval], mbin )
    #try:
        #binassign[rbval] = np.digitize( magbin[rbval], mbin )
    #except RbvalueError:
        #binassign[rbval] = 0

    mean[rbval] = 0*binc
    sig[rbval] = 0*binc
    num[rbval] = 0*binc
    merfloor = 0.005
    for j in range(1,mbin.size):
        if ( len(deltabin[rbval][binassign[rbval]==j])>1 )  :
            tmpmean = np.median( deltabin[rbval][binassign[rbval]==j] )
            tmpsig = 1.4826*np.median( np.absolute( deltabin[rbval][binassign[rbval]==j] - tmpmean )  )
            #mean[rbval][j-1] = np.mean(  np.clip( deltabin[rbval][binassign[rbval]==j] , tmpmean-losig*tmpsig , tmpmean+hisig*tmpsig  ) )
            #sig[rbval][j-1] = np.std(  np.clip( deltabin[rbval][binassign[rbval]==j] , tmpmean-losig*tmpsig , tmpmean+hisig*tmpsig  ) , ddof = 1 )
            mean[rbval][j-1] = np.median(  np.clip( deltabin[rbval][binassign[rbval]==j] , tmpmean-losig*tmpsig , tmpmean+hisig*tmpsig  ) )
            sig[rbval][j-1] = 1.4826*np.median(  np.absolute( np.clip( deltabin[rbval][binassign[rbval]==j] , tmpmean-losig*tmpsig , tmpmean+hisig*tmpsig  ) - mean[rbval][j-1] )  )
            num[rbval][j-1] = len(np.clip( deltabin[rbval][binassign[rbval]==j] , tmpmean-losig*tmpsig , tmpmean+hisig*tmpsig  ))
            
        else:
            mean[rbval][j-1] = 0
            sig[rbval][j-1] = 0
            num[rbval][j-1] = 0
            
        sig[rbval][j-1] = np.maximum(merfloor,sig[rbval][j-1])
        print j,mbin[j-1], binc[j-1] ,mbin[j],mean[rbval][j-1] ,sig[rbval][j-1] ,num[rbval][j-1]

    xin = np.concatenate([np.array(xin),np.array(binc)])
    zin = np.concatenate([np.array(zin),np.array(rhobin[rbval-1]+0*binc)])
    yin = np.concatenate([np.array(yin),np.array(mean[rbval])])
    yer = np.concatenate([np.array(yer),np.array(sig[rbval])])
    wgt = np.concatenate([np.array(wgt),np.power(ratiobin[rbval],2)*np.where(sig[rbval]>merfloor,np.sqrt(num[rbval]),0) ])

#wgt = np.where(wgt>0,1,0.1) 
#print xin, zin, yin, yer, np.log(yer), wgt

            #    np.concatenate(ysig,sig[rbval])
lbound = lambda p, x: 1e4*np.sqrt(p-x) + 1e-3*(p-x) if (x<p) else 0
ubound = lambda p, x: 1e4*np.sqrt(x-p) + 1e-3*(x-p) if (x>p) else 0
bound  = lambda p, x: lbound(p[0],x) + ubound(p[1],x)
fixed  = lambda p, x: bound((p,p), x)

order = 1
if ( order == 1 ):
    fitfunc = lambda p, x, z: p[2]*z+((p[0]*x + p[1] ))
    p0 = [ 0, 0, 1 ]
    errfunc = lambda p, x, z, y, wgt: (fitfunc(p,x,z) - y  ) * wgt
    p1, cov1, info, mesg, success = opt.leastsq(errfunc, p0, args=(xin, zin , np.log(yer), wgt ) , full_output=1)
else:
    fitfunc = lambda p, x, z: p[2]*z+((p[0]*x + p[1] + p[3]*x*x ))
    p0 = [ -0.5, -4.5, 0 ,0.03 ]
    errfunc = lambda p, x, z, y, wgt: (fitfunc(p,x,z) - y + lbound(0,p[2]) + lbound(0,p[3]) ) * wgt
    p1, cov1, info, mesg, success = opt.leastsq(errfunc, p0, args=(xin, zin , np.log(yer), wgt ) , full_output=1)


print p1, success, mesg
#os.sys.exit()
######  IF INPUT PROVIDED, ESTIMATE MAG ERRORS #######
if (len(sys.argv) > 4):
    print len(sys.argv)  
    ifpt = sys.argv[4]
    print ifpt
    # READ INPUT DAOPHOT PARAMETRS
    fxin,fyin,fmagin,fmerr,frhoin = \
        np.loadtxt(ifpt,
        skiprows=0,
        dtype='float,float,float,float,float',
        usecols=(0,1,2,3,4),
        unpack=True)

    oerr = np.exp(fitfunc(p1,fmagin,frhoin))
    output = np.column_stack((fxin,fyin,fmagin,fmerr,frhoin,oerr))
    np.savetxt(ifpt,output,fmt='%8.2f %8.2f %8.3f %8.3f %10.7f %8.4f')


#########   MAKE PLOTS  ############
# PLOT LIMITS
#m1 = np.min(true)
#m2 = np.max(true)
m1 = np.min(true)
#m1 = 10
m2 = mlim+0.5
merr = 0.50
# PANEL 1
plt.subplot(221)
plt.xlim(m1, m2)
plt.ylim(0, 1.0999)
plt.ylabel('Fraction Recovered')
for i,rbval in enumerate(np.sort(np.unique(rhocrit))):
    plt.plot(binc,ratiobin[rbval],color=densecol[rbval-1]) 

# PANEL 2
plt.subplot(222)
plt.xlim(m1, m2)
plt.ylim(0, merr)
plt.ylabel('DAOPHOT ERR')
xfit = np.arange(m1,m2,0.1)
for i,rbval in enumerate(np.sort(np.unique(rhocrit))):
    pl.scatter(magbin[rbval],merbin[rbval],c=densecol[rbval-1],alpha = 0.03)
    pl.plot(xfit,np.sqrt(np.power(merfloor,2)+np.power(np.exp(fitfunc(p1,xfit,rhobin[rbval-1]+0*xfit)),2)),c=densecol[rbval-1] )
    #pl.plot(xfit,np.exp(fitfunc(p1,xfit,rhobin[rbval-1]+0*xfit)),c=densecol[rbval-1] )

# PANEL 3
if ( 0 ) :
    plt.subplot(223)
    plt.xlim(m1, m2)
    plt.ylim(0, 0.10)
    plt.ylabel('Centroid Error')
    for i,rbval in enumerate(np.sort(np.unique(rhocrit))):
        pl.scatter(truebin[rbval],drbin[rbval],c=densecol[rbval-1],alpha = 0.03)
else:
# PANEL 3
    plt.subplot(223)
    plt.xlim(m1, m2)
    plt.ylabel('LN Error')
    for i,rbval in enumerate(np.sort(np.unique(rhocrit))):
        pl.scatter((binc),np.log(sig[rbval]),c=densecol[rbval-1])
        pl.plot(xfit,(fitfunc(p1,xfit,rhobin[rbval-1]+0*xfit)),c=densecol[rbval-1])
        pl.plot(xfit,np.log(merfloor+0*xfit),c=densecol[rbval-1])
        print rhobin[rbval-1], densecol[rbval-1]
    
# PANEL 4
plt.subplot(224)
plt.xlim(m1, m2)
plt.ylim(-merr, merr)
plt.ylabel('DAOMAG - TRUE')
pl.plot(xfit,0.0+1.0*(xfit-mlim),c='k' )
for i,rbval in enumerate(np.sort(np.unique(rhocrit))):
    pl.scatter(magbin[rbval],deltabin[rbval],c=densecol[rbval-1],alpha = 0.03)
    pl.scatter(binc,mean[rbval],c=densecol[rbval-1])
    pl.errorbar(binc,0*mean[rbval],yerr=sig[rbval])
    pl.plot(xfit,np.sqrt(np.power(merfloor,2)+np.power(np.exp(fitfunc(p1,xfit,rhobin[rbval-1]+0*xfit)),2)),c=densecol[rbval-1] )


plt.xlabel('Magnitude(measured)')
#plt.show()
plt.savefig('fakestar.ps')
os.sys.exit()

