#!/bin/csh -f
set pwd = `pwd`

###############################################
# DEFAULT PROGRAM LOCATIONS
set iraf = /iraf/iraf              # LOCATION OF IRAF BINARIES
set dao = ~/software/daophot/amonson         # CUSTOMIZED DAO PROGRAMS
set daopath = $0:h/              # LOCATION OF THIS PROGRAM
if ( $daopath == ./ ) then
    set daopath = `pwd`
endif
###############################################
# DEFAULT DATA PATH LOCATIONS
#set datapath = /Volumes/Data-3/$INSTR/$PROJECT/$name
set datapath = /Volumes/Data-3/Galex/NGC6822_GALEX
set refdir = $datapath
set odir = $refdir
###############################################
#
#  wcstools package: sky2xy and xy2sky gethead sethead
#  cdsclient package: find2mass
set clients = ( cocat1.u-strasbg.fr axel.u-strasbg.fr vizier.hia.nrc.ca )
#  DAOPHOT/DAOMASTER/DAOMATCH/ALLSTAR  programs from Peter Stetson.  
#
###############################################


# DEFAULT BORDER ( 1 0 1 0)  # USE WHOLE IMAGE
set border = ( 1 0 1 0 )
###############################################
# INITIALIZE DEFAULTS
set name = NGC6822
set INSTR = Galex    #  FourStar | Spitzer
#set INSTR = Spitzer    #  FourStar | Spitzer
set PROJECT = NGC6822_GALEX       #     CHP   |   CRRP
set filt = NUV     #  NUV | FUV
set covfrac = 5         # minimum exposure map coverage (percent of maximum)
set REDO_PHOT = 0
set REDO_ANAL = 0
set REDO_ALF = 0
set redo_ds9 = 0
set ref_only = 0
set force = 0
set psf2 = 0
set ccoord = ( 0 0 0 )
set thresh = ( 2 )
# 2MASS CALIBRATION RANGE
set SEXFLAG = AAA    #   AAA | ALL

# PHOTOMETRY 
set sex = 1       # 1 | 2 | 3
set phot = cor    #   cor | raw
set rallframe = 0
set npsf = 100
set density = 0
set fake = 0
# SM PLOT OUTPUT
set smplot = 1
set smoutput = 0      # print diagnostics to terminal
set plot_error = 1
set showid = 1
set image_master = ""

echo $*
#  READ COMMAND LINE ARGUMENTS
while ( 1 )
    switch( $1 )
	case -filter
	    if ( "$2" =~ "" ) then
		echo filter not specified... exiting.
		exit 1
	    endif
	    set filt = ( $2 ) ; shift; shift
	    echo $filt
	    breaksw
	case -project
	    if ( "$2" =~ "" ) then
		echo project not specified... exiting.
		exit 1
	    endif
	    set project = $2 ; shift; shift
	    breaksw
	case -border
	    if ( "$2" =~ "" ) then
		echo border not specified... exiting.
		exit 1
	    endif
	    set border = ( $2 ) ; shift; shift
	    breaksw
	case -ref
	    set ref_only = 1 ; shift
	    echo Only doing reference image
	    breaksw
	case -psf2
	    if ( "$2" =~ "" ) then
		echo number of PSF iterations to use not specified... exiting.
		exit 1
	    endif
	    set psf2 = $2 ; shift ; shift
	    breaksw
	case -npsf
	    if ( "$2" =~ "" ) then
		echo number of PSF stars to use not specified... exiting.
		exit 1
	    endif
	    set npsf = $2 ; shift ; shift
	    breaksw
	case -covfrac
	    set covfrac = $2 ; shift; shift
	    echo setting minimum coverage fraction to $covfrac
	    breaksw
	case -force
	    set force = 1 ; shift
	    echo Forcing image display
	    breaksw
	case -redop
	    set REDO_PHOT = 1 ; shift
	    echo redoing photometry
	    breaksw
	case -ralf
	    set REDO_ALF = 1 ; shift
	    set rallframe = 1
	    echo redoing allframe
	    breaksw
	case -redoa
	    set REDO_ANAL = 1 ; shift
	    echo redoing analysis
	    breaksw
	case -image
	    if ( "$2" =~ "" ) then
		echo no image specified... exiting.
		exit 1
	    endif
	    set image_master = $2 ; shift; shift
	    breaksw
	case -fake
	    if ( "$2" =~ "" ) then
		echo no image specified... exiting.
		exit 1
	    endif
	    set fake = $2 ; shift; shift
	    set density = 1
	    breaksw
	case -name
	    if ( "$2" =~ "" ) then
		echo no object name specified... exiting.
		exit 1
	    endif
	    set name = $2 ; shift; shift
	    breaksw
	case -thresh
	    if ( "$2" =~ "" ) then
		echo Thresholds not specified... exiting.
		exit 1
	    endif
	    set thresh = ( $2 ) ; shift; shift
	    echo $thresh
	    breaksw
	case -dao
	    if ( "$2" =~ "" ) then
		echo no daopath specified... exiting.
		exit 1
	    endif
	    set dao = "$2" ; shift; shift
	    breaksw
	case -data
	    if ( "$2" =~ "" ) then
		echo no datapath specified... exiting.
		exit 1
	    endif
	    set datapath = "$2" ; shift; shift
	    breaksw
	default:
	    break
    endsw
end
###############################################
# UPDATE PARAMETERS
switch( $name )
    case SMC_MOS14_0003
	set ccoord = ( 6.3543168 -73.790494 0.45 )  # 
	breaksw
    case NGC6822
	set ccoord = ( 296.24057 -14.802683 0.45 )  # 
	breaksw

    default:
	breaksw
endsw

# FORCE APPLY A RADIAL CUT LIMIT
if ( 0 ) then
    set ccoord[3] = 0.2
endif


###  SHOULD NOT HAVE TO EDIT BEYOND HERE ######
###############################################
# SET MACHINE DEPENDENCIES
set sed = `which \sed`
set machine = `uname -sm`
if ( $machine[1] =~ Linux && ( $machine[2] =~ i386 || $machine[2] =~ i686 ) ) then
    set sedi = "$sed -i''"
    set irafarch = "linux"
    set NCPU = `grep -c processor /proc/cpuinfo`
else if ( $machine[1] =~ Linux && $machine[2] =~ x86_64 ) then
    set sedi = "$sed -i''"
    set irafarch = "linux"
    set NCPU = `grep -c processor /proc/cpuinfo`
else if ( $machine[1] =~ Darwin && ( $machine[2] =~ i386 || $machine[2] =~ 6386 ) ) then
    set sedi = "$sed -i ''"
    set irafarch = "macosx"
    set NCPU = `sysctl -n hw.ncpu` 
else if ( $machine[1] =~ Darwin && $machine[2] =~ x86_64 ) then
    set sedi = "$sed -i ''"
    set irafarch = "macintel"
    set NCPU = `sysctl -n hw.ncpu` 
else
    set sedi = "$sed -i ''"
    set irafarch = "macosx"
    set NCPU = 1
endif

printf "%s %s CPU's: %d\n" $machine[1] $machine[2] $NCPU
limit stacksize unlimited
if ( $machine[1] =~ Darwin ) then
    limit descriptors 2048
else if ( $machine[1] =~ Linux ) then
    limit openfiles 2048
endif
###############################################
alias sedi $sedi
###############################################
# alias PROGRAM EXECUTABLES
alias images $iraf/bin.$irafarch/x_images.e
alias astutil $iraf/noao/bin.$irafarch/x_astutil.e
alias daomatch $dao/daomatch 
alias daomaster $dao/daomaster 
alias allframe $dao/allframe 
alias montage2 $dao/montage2

###############################################
if ( $REDO_PHOT == 1 ) then
    set filters = "$filt"
    foreach filter ( $filters )
	echo Starting $filter
#	continue
###############################################
#	set master = ${name}-${filter}-int
	set master = ${name}_${filter}
	set image_master = $refdir/$master.fits
	if ( ! -e $refdir ) then
	    echo $refdir does not exist.  Exiting.  
	    exit 1
	endif
	cd $refdir
	pwd

	# DAOMASTER SETTINGS
	set minfrac = 0.5
	set startrad = 10
	set crad = 1
	set forder = 2

###############################################
###############################################
	# LOOP OVER INPUT IMAGES
	if ( ! -d $datapath ) then
	    echo "$datapath" does not exist.
	    exit 1
	endif

	# LIST INDIVIDUAL FRAMES
	if ( $INSTR == Galex ) then
	    echo $datapath
	    ls $datapath/*${filter}.fits > $refdir/phot.txt
	endif

	# LOOP OVER EACH FRAME, STARTING WITH MASTER
	set PSFS =  null
	set ASSOC = null
	set PSFS_REF = null
	set ASSOC_REF = null

	if ( 1 ) then
	    set PSFS_REF = $refdir/image.$filter.psf.coords
	    set ALF_REF = $refdir/image.$filter.alf.coords
	    set ASSOC_REF = $refdir/image.$filter.coo.coords
	endif


	@ i = 1
	foreach image ( `cat $refdir/phot.txt` )
	    if ( $REDO_PHOT == 0 ) then
		echo $image
		continue
	    endif
	    set TELESCOP = `gethead -u $image TELESCOP`
	    set NAXIS = `gethead -u $image NAXIS1 NAXIS2`
	    
	    rm $image.psf.coo $image.psf.coo.1 >>& /dev/null
	    if ( -e $PSFS_REF && ! -z $PSFS_REF   ) then
		echo $PSFS_REF exists, creating $image.psf.coo
		sky2xy $image @$PSFS_REF | awk ' ! /off/ {printf "%10.3f %10.3f \n",$(NF-1),$NF }' > $image.psf.coo.1
		getpix -n 1 %6.3f $image @$image.psf.coo.1 | paste $image.psf.coo.1 -  | awk ' ! /nan/ {if(NF>2) printf "%10.3f %10.3f \n",$1,$2  }' > $image.psf.coo
		rm -fr $image.psf.coo.1 >>& /dev/null
		set PSFS = $image.psf.coo
	    endif
	# DONT WASTE TIME FINDING ALL SOURCES IN EACH FRAME IF YOU PLAN ON RUNNING ALLFRAME.   
	    rm $image.coord.coo $image.coord.coo.1 >>& /dev/null
	    if ( -e $ASSOC_REF && ! -z $ASSOC_REF && ( $ref_only == 1 || $rallframe == 0 ) ) then
		echo $ASSOC_REF exists, creating $image.coord.coo
		sky2xy $image @$ASSOC_REF | awk ' ! /off/ {printf "%10.3f %10.3f \n",$(NF-1),$NF }' > $image.coord.coo.1
		getpix -n 1 %6.3f $image @$image.coord.coo.1 | paste $image.coord.coo.1 -  | \
		    awk ' ! /nan/ {if(NF>2) printf "%10.3f %10.3f \n",$1,$2  }' > $image.coord.coo
		rm -fr $image.coord.coo.1 >>& /dev/null
		set ASSOC = $image.coord.coo
	    endif

	    rm -fr $image.log >>& /dev/null
	    rm -fr $image:h/daophot.log >>& /dev/null
	    set log = $image:h/daophot_$filter.log
	    rm -fr $log >>& /dev/null
	    echo "Log = $log"
	    echo "i = $i   $image_master $ref_only "
	    if ( $i == 1 && -e $image_master && $ref_only == 1 ) then
		printf "%40s  %40s\n" "Performing photometry on Master image:" $image_master
		$daopath/dophot.csh -image $image_master -dao "$dao" -iraf "$iraf" -irafarch $irafarch -filter $filter \
		    -sedi "$sedi" -sex $sex -psfs "$PSFS" -assoc "$ASSOC" -redo $REDO_PHOT -coord "$ccoord" \
		    -force $force -npsf $npsf -psf2 $psf2 -covfrac $covfrac -thresh "$thresh" -border "$border" -fake $fake -telescope Galex > $log \
		; rm $image.psf.coo $image.psf.coo.1 >>& /dev/null \
		; rm $image.coord.coo $image.coord.coo.1 >>& /dev/null 
	    endif
	    @ i ++
	end
###############################################
	echo waiting for phot to finish ...
###############################################
#	wait
    end
endif
###############################################
wait
if ( $REDO_ANAL == 1 ) then
    cd $odir
    echo pwd is `pwd`
    printf "\nMatching SOURCES...\n"
    set filters = "$filt"
    foreach filter ( $filters )
	set oals = $odir/daophot_${name}_${filter}/image.als
	if ( -e $oals ) then
	    cp $oals $filter.als
	else
	    printf "$oals not found.  exiting."
	    exit 1
	endif
    end
    $daopath/match.csh NUV.als FUV.als galex 1 2 $dao
    mv galex.raw galex.raw.tmp
    head -n3 galex.raw.tmp > galex.raw
    awk '{if(NR>3){printf "%8d %10.3f %10.3f %7.3f %7.3f\n",$1,$2,$3,$4,$5} }' NUV.mtr > galex.raw.1
    awk '{if(NR>3){printf "%7.3f %7.3f %10.6f %10.6f\n",$4,$5,$9,$10} }' FUV.mtr > galex.raw.2
    paste  galex.raw.1 galex.raw.2 >> galex.raw

    if ( 1 ) then
/usr/local/bin/sm -S << FIN #
VERBOSE 0
macro plot 12 {
     if(\$?2==0){dev x11 -device 0 -bg white -fg white} else {
     if('\$1'=='lpr'){dev mypostscript \$2} else {
     if('\$1'=='ps'){dev postportfile_colour :SY=echo File is \$F\:OF=\$2:} else {
     if('\$1'=='psl'){dev postlandfile_colour :SY=echo File is \$F\:OF=\$2:} else {
     if('\$1'=='pss'){dev postencap :SY=echo File is \$F\:OF=\$2:}
     }}}}
###### SET SOME DEFAULT VALUES #################################################
     define print_noheader 1      # when printing vectors, dont print a header
     define TeX_strings 1         # use TeX.  (commented out in .sm file, comment out if undesired)
     ltype 0       # 0 solid | 1 dot | 2 short dash | 3 long dash | 4 dot-short-dash
     	   	   # 5 dot-long-dash | 6 short-long dash | 10 erase lines | also ltype expand
     lweight 3	   #
     ptype 4 3	   # ptype n s, n: sided polygon (30max for circle)
     	     	   #            s: 0 open, 1 skeletal, 2 starred, 3 solid  
     ctype black
################################################################################
################################################################################
#
#   START SCRIPT HERE
#
################################################################################
################################################################################

     data galex.raw
     read !{ id 1.s xc 2 yc 3 nuv 4 nuve 5 fuv 6 fuve 7 }

     window 1 1 1 1 
     limits -5 5 25 10
     box 1 2 0 0

     expand 1
     ptype  4 1
     ctype black
     xlabel FUV-NUV
     ylabel NUV
     toplabel $name
# PLOT FIELD STARS
     points ( nuv-fuv ) nuv

################################################################################
################################################################################
#
#   END SCRIPT HERE
#
################################################################################
################################################################################
     if ( \$?2==0 ) {
       cursor
     }
}
if ( 1 == $smplot ) {
    plot pss $odir/cmd_$filter.ps
} else {
    plot t
}
FIN
endif

endif




exit 0

