#!/bin/csh -f

#  MATCH TWO INPUT CATALOGS.  SOURCE MUST BE PRESENT IN BOTH CATALOGS.  
set pwd = `pwd`

set ref = $1
set input = $2
set output = $3
@ rad = $4
set distort = $5
alias daomatch  $6/daomatch
alias daomaster  $6/daomaster

printf "desired match radius = $rad\n"
printf "desired distortion = $distort\n"

foreach check ( $ref $input ) 
    if ( ! -e $check ) then
	printf "$check does not exist.  Exiting.\n"
	exit 1
    else
#	printf "$check exists.\n"
    endif
end

###  RUN DAOMATCH ########
rm -fr $output.mch >>& /dev/null
set tmpdir = `mktemp -d -t daomatch `
#set tmpdir = `pwd`/daomatch
#mkdir daomatch
set log = ${tmpdir}/daomatch.log
set loglim = 2000
cat - << EOF > ${tmpdir}/daomatch.txt
$ref
$output.mch
$input
Y
EXIT
EOF
daomatch < ${tmpdir}/daomatch.txt >& $log &

#daomatch <<EOF >& $log &
#$ref
#$output.mch
#$input
#EXIT
#EOF
set lbid = $! # last job ID
set wcold = 0 
while ( `ps -c | grep $lbid` != "" )
    set wcnew = `cat $log | wc -l`
    if ( $wcnew > $loglim ) then
	kill -9 $lbid
	printf "\nSomething went wrong.  Check $log for details.\n" >>& /dev/stderr
	exit 1
    endif
    set wcold = $wcnew
    sleep 1
end
wait
############################


#    # FORCE UNITY SOLUTION.  The ";" does not seem to work in my version of daomatch.  
if ( $rad < 0 ) then
    echo FORCING UNITY SOLUTION
    mv $output.mch ${tmpdir}/tmpxx.mch ; awk '{if(NR==1){str=$0;subs=$1;print}else{sub(subs,$1,str);print str} }' ${tmpdir}/tmpxx.mch > $output.mch ; rm ${tmpdir}/tmpxx.mch
endif
set nframe = 2
# REFINED SOLUTION AND OUTPUT
#  Desired degrees of freedom ---
#                  2:  Translations only
#                  4:  Translations, rotation, and scale
#                  6:  Six-constant linear transformation
#                 12:  Quadratic transformation
#                 20:  Cubic transformation

rm -fr $output.mag $output.cor $output.raw $output.tfr $input:r.mtr $ref:r.mtr  >>& /dev/null
echo $output.mch > ${tmpdir}/daomaster.txt
awk 'BEGIN {printf "%d,%3.1f,%d\n", '$nframe'*1, 1, '$nframe'*1}' >> ${tmpdir}/daomaster.txt  # Minimum number, minimum fraction, enough frames:
awk 'BEGIN {printf "%3.1f\n", 99}' >> ${tmpdir}/daomaster.txt  # Maximum sigma:
awk 'BEGIN {printf "%d\n", '$distort'}' >> ${tmpdir}/daomaster.txt   #  Desired degrees of freedom ---
awk 'BEGIN {printf "%d\n", 20}' >> ${tmpdir}/daomaster.txt # Critical match-up radius:
if ( 1 ) then
    awk 'BEGIN {for(i=1;i<'$nframe';i++) printf "\n"}' >> ${tmpdir}/daomaster.txt  # HIT ENTER
endif
awk 'BEGIN {for(i=20;i>=(sqrt((('$rad')**2)));i--) printf "%d\n",i}' >> ${tmpdir}/daomaster.txt   # New match-up radius (0 to exit):
awk 'BEGIN {for(i=0;i<=5;i++) printf "%d\n",sqrt((('$rad')**2))}' >> ${tmpdir}/daomaster.txt   # New match-up radius (0 to exit):    HIT DESIRED RADIUS A FEW MORE TIMES TO CONVERGE
awk 'BEGIN {printf "%d\n",0}' >> ${tmpdir}/daomaster.txt  # New match-up radius (0 to exit):
awk 'BEGIN {printf "%s\n","n"}' >> ${tmpdir}/daomaster.txt # Assign new star IDs? 
#awk 'BEGIN {printf "%s\n","y"}' >> ${tmpdir}/daomaster.txt # Assign new star IDs? 
awk 'BEGIN {printf "%s\n%s\n","y","'$output.mag'"}' >> ${tmpdir}/daomaster.txt # A file with mean magnitudes and scatter? 
awk 'BEGIN {printf "%s\n%s\n","y","'$output.cor'"}' >> ${tmpdir}/daomaster.txt # A file with corrected magnitudes and errors?
awk 'BEGIN {printf "%s\n%s\n","y","'$output.raw'"}' >> ${tmpdir}/daomaster.txt # A file with raw magnitudes and errors?
awk 'BEGIN {printf "%s\n","n"}' >> ${tmpdir}/daomaster.txt # A file with the new transformations? 
#awk 'BEGIN {printf "%s\n","n"}' >> ${tmpdir}/daomaster.txt # A file with the transfer table?
awk 'BEGIN {printf "%s\n%s\n","y","'$output.tfr'"}' >> ${tmpdir}/daomaster.txt # A file with the transfer table?
awk 'BEGIN {printf "%s\n","n"}' >> ${tmpdir}/daomaster.txt # Individual .COO files?
#awk 'BEGIN {printf "%s\n%s\n","y","'$output.mtr'"}' >> ${tmpdir}/daomaster.txt # Simply transfer star IDs?
awk 'BEGIN {printf "%s\n","y"}' >> ${tmpdir}/daomaster.txt # Simply transfer star IDs?


###### RUN DAOMASTER ###########
set log = ${tmpdir}/daomaster.log
set loglim = 1000
daomaster < ${tmpdir}/daomaster.txt >& $log &
set lbid = $! # last job ID
set wcold = 0 
while ( `ps -c | grep $lbid` != "" )
    set wcnew = `cat $log | wc -l`
    if ( $wcnew > $loglim ) then
	kill -9 $lbid
	printf "\nSomething went wrong.  Check $log for details.\n" >>& /dev/stderr
	exit 1
    endif
    set wcold = $wcnew
    sleep 1
end
wait
################################


rm -fr ${tmpdir} >>& /dev/null
#rm -fr $output.mch ${tmpdir}/daomaster.txt

exit 0
