#!/bin/csh -f
set pwd = `pwd`

###############################################
# DEFAULT PROGRAM LOCATIONS
set iraf = /iraf/iraf              # LOCATION OF IRAF BINARIES
set dao = ~/software/daophot/amonson         # CUSTOMIZED DAO PROGRAMS
set daopath = $0:h/              # LOCATION OF THIS PROGRAM
if ( $daopath == ./ ) then
    set daopath = `pwd`
endif
###############################################
# DEFAULT DATA PATH LOCATIONS
#set datapath = /Volumes/Data-3/$INSTR/$PROJECT/$name
set datapath = /Volumes/Data-3/
set refdir = $datapath
set odir = $refdir
###############################################
#
#  wcstools package: sky2xy and xy2sky gethead sethead
#  cdsclient package: find2mass
set clients = ( cocat1.u-strasbg.fr axel.u-strasbg.fr vizier.hia.nrc.ca )
#  DAOPHOT/DAOMASTER/DAOMATCH/ALLSTAR  programs from Peter Stetson.  
#
###############################################


# DEFAULT BORDER ( 1 0 1 0)  # USE WHOLE IMAGE
set border = ( 1 0 1 0 )
###############################################
# CRRP
#set name = Reticulum
set name = Omega_Cen
#set name = NGC7089
#set name = NGC1835
#set name = NGC1841
#set name = NGC1851
#set name = NGC1904
#set name = NGC1466
#set name = NGC2257

# CHP
#set name = NGC6822
#set name = Sextans_A
#set name = NGC3109


# DATA LOCATIONS


# INITIALIZE DEFAULTS
#set INSTR = FourStar    #  FourStar | Spitzer
#set INSTR = Spitzer    #  FourStar | Spitzer
#set PROJECT = CRRP       #     CHP   |   CRRP
set PROJECT = CHP       #     CHP   |   CRRP
set filter = Ks          # H | Ks | 3p6um | 4p5um
set covfrac = 5         # minimum exposure map coverage (percent of maximum)
set REDO_PHOT = 0
set REDO_ANAL = 0
set REDO_ALF = 0
set redo_ds9 = 0
set ref_only = 0
set force = 0
set psf2 = 0
set include_master = 0
# 2MASS CALIBRATION RANGE
set SEXFLAG = AAA    #   AAA | ALL
set maglim1 = 13.0
set maglim2 = 15.5


# PHOTOMETRY 
set sex = 1       # 0 | 1 | 2 | 3   
set phot = cor    #   cor | raw
set rallframe = 0  #     0 | 1 
set npsf = 100
set density = 0
set fake = 0
set thresh = ( 5 )

# SM PLOT OUTPUT
set smplot = 1
set smoutput = 0      # print diagnostics to terminal
set plot_error = 1
set showid = 1
set template_fit = 0    #  0-average | 1-gloess | 2-templates
# USE/PLOT DALLORA DATA (RETICULUM Ks DATA ONLY)
set dallora = 1
# PLOT V versus color
set OCMD = 0

while ( 1 )
    switch( $1 )
	case -filter
	    if ( "$2" =~ "" ) then
		echo filter not specified... exiting.
		exit 1
	    endif
	    set filter = $2 ; shift; shift
	    breaksw
	case -project
	    if ( "$2" =~ "" ) then
		echo project not specified... exiting.
		exit 1
	    endif
	    set PROJECT = $2 ; shift; shift
	    breaksw
	case -border
	    if ( "$2" =~ "" ) then
		echo border not specified... exiting.
		exit 1
	    endif
	    set border = ( $2 ) ; shift; shift
	    breaksw
	case -ref
	    set ref_only = 1 ; shift
	    echo Only doing reference image
	    breaksw
	case -psf2
	    if ( "$2" =~ "" ) then
		echo number of PSF iterations to use not specified... exiting.
		exit 1
	    endif
	    set psf2 = $2 ; shift ; shift
	    breaksw
	case -npsf
	    if ( "$2" =~ "" ) then
		echo number of PSF stars to use not specified... exiting.
		exit 1
	    endif
	    set npsf = $2 ; shift ; shift
	    breaksw
	case -covfrac
	    set covfrac = $2 ; shift; shift
	    echo setting minimum coverage fraction to $covfrac
	    breaksw
	case -force
	    if ( "$2" =~ "" ) then
		echo no force specified... exiting.
		exit 1
	    endif
	    echo Forcing image display
	    set force = $2 ; shift; shift
	    breaksw
	case -redop
	    set REDO_PHOT = 1 ; shift
	    echo redoing photometry
	    breaksw
	case -ralf
	    set REDO_ALF = 1 ; shift
	    set rallframe = 1
	    echo redoing allframe
	    breaksw
	case -redoa
	    set REDO_ANAL = 1 ; shift
	    echo redoing analysis
	    breaksw
	case -image
	    if ( "$2" =~ "" ) then
		echo no image specified... exiting.
		exit 1
	    endif
	    set image_master = $2 ; shift; shift
	    breaksw
	case -fake
	    if ( "$2" =~ "" ) then
		echo no image specified... exiting.
		exit 1
	    endif
	    set fake = $2 ; shift; shift
	    set density = 1
	    breaksw
	case -name
	    if ( "$2" =~ "" ) then
		echo no object name specified... exiting.
		exit 1
	    endif
	    set name = $2 ; shift; shift
	    breaksw
	case -thresh
	    if ( "$2" =~ "" ) then
		echo Thresholds not specified... exiting.
		exit 1
	    endif
	    set thresh = ( $2 ) ; shift; shift
	    echo $thresh
	    breaksw
	case -dao
	    if ( "$2" =~ "" ) then
		echo no daopath specified... exiting.
		exit 1
	    endif
	    set dao = "$2" ; shift; shift
	    breaksw
	case -data
	    if ( "$2" =~ "" ) then
		echo no datapath specified... exiting.
		exit 1
	    endif
	    set datapath = "$2" ; shift; shift
	    breaksw
	default:
	    break
    endsw
end
###############################################
set pfilt = $filter
switch ( $filter )
    case Ks
	set pfilt = "K_s"
	set INSTR = FourStar
	set fsfilt = -2
	breaksw
    case H
	set pfilt = "H"
	set INSTR = FourStar
	set fsfilt = -1
	breaksw
    case J
	set pfilt = "J"
	set INSTR = FourStar
	set fsfilt = -5
	breaksw
    case 4p5um
	set pfilt = "[4.5]"
	set INSTR = Spitzer
	set fsfilt = -4
	breaksw
    case 3p6um
	set pfilt = "[3.6]"
	set INSTR = Spitzer
	set fsfilt = -3
	breaksw
    default:
	set pfilt = $filter
	breaksw
endsw

if ( $name == Reticulum && $filter == Ks ) then
#    set maglim1 = 13.0
#    set maglim2 = 13.5
endif


if ( $rallframe == 1 ) then
    set allframe = "a"
else
    set allframe = ""
endif

set ccoord = ( 0 0 0 )
switch( $name )
# CRRP ########
    case Omega_Cen
	set ccoord = ( 201.697 -47.47954 1 )  # NGC1466
	breaksw
    case NGC1466
	set ccoord = ( 56.134989 -71.670479 0.1 )  # NGC1466
	breaksw
    case NGC1835
	set ccoord = ( 76.277987 -69.40406 0.015 )  # NGC1835
	breaksw
    case NGC1841
	set ccoord = ( 71.336745 -83.998975 0.0345 )  # NGC1841
	breaksw
    case NGC1851
	set ccoord = ( 78.528151 -40.046982 0.1 )  # NGC1851
	breaksw
    case NGC1904
	set ccoord = ( 81.046622 -24.524938 0.1 )  # NGC1904
	breaksw
    case NGC2257
	set ccoord = ( 97.56017 -64.31773 0.067 )  # NGC2257
	breaksw
    case Reticulum
	set ccoord = ( 69.043739 -58.856239 0.0524 )  # RETICULUM
	breaksw
    case NGC7089
	set ccoord = ( 323.3627 -0.8225 0.0524 )  # NGC7089
	breaksw
# CHP ########
    case NGC6822
	set ccoord = ( 296.23193 -14.815535 0.1 )  # NGC6822
	breaksw
    case Sextans_A
	set ccoord = ( 152.74579 -4.69463 0.05 )  # Sextans_A
	breaksw
    case NGC3109
	set ccoord = ( 150.7666 -26.1572 0.05 )  # Sextans_A
	breaksw


    default:
	breaksw
endsw

# APPLY A RADIAL CUT LIMIT
if ( 0 ) then
    set ccoord[3] = 0.01
endif


###############################################
# SET MACHINE DEPENDENCIES
set sed = `which \sed`
set machine = `uname -sm`
if ( $machine[1] =~ Linux && ( $machine[2] =~ i386 || $machine[2] =~ i686 ) ) then
    set sedi = "$sed -i''"
    set irafarch = "linux"
    set NCPU = `grep -c processor /proc/cpuinfo`
else if ( $machine[1] =~ Linux && $machine[2] =~ x86_64 ) then
    set sedi = "$sed -i''"
    set irafarch = "linux"
    set NCPU = `grep -c processor /proc/cpuinfo`
else if ( $machine[1] =~ Darwin && ( $machine[2] =~ i386 || $machine[2] =~ 6386 ) ) then
    set sedi = "$sed -i ''"
    set irafarch = "macosx"
    set NCPU = `sysctl -n hw.ncpu` 
else if ( $machine[1] =~ Darwin && $machine[2] =~ x86_64 ) then
    set sedi = "$sed -i ''"
    set irafarch = "macintel"
    set NCPU = `sysctl -n hw.ncpu` 
else
    set sedi = "$sed -i ''"
    set irafarch = "macosx"
    set NCPU = 1
endif

printf "%s %s CPU's: %d\n" $machine[1] $machine[2] $NCPU
limit stacksize unlimited
if ( $machine[1] =~ Darwin ) then
    limit descriptors 2048
else if ( $machine[1] =~ Linux ) then
    limit openfiles 2048
endif
###############################################
alias sedi $sedi
###############################################
# alias PROGRAM EXECUTABLES
alias images $iraf/bin.$irafarch/x_images.e
alias astutil $iraf/noao/bin.$irafarch/x_astutil.e
alias daomatch $dao/daomatch 
alias daomaster $dao/daomaster 
alias allframe $dao/allframe 
alias montage2 $dao/montage2
###############################################


###############################################
set initial = init_$filter
set master = master_$filter
set refdir = /Users/amonson/Documents/$PROJECT/$name
set datapath = /Volumes/Data-3/$INSTR/$PROJECT/$name
set odir = $refdir/aphot/$filter
set image_master = $refdir/$master.fits
if ( ! -e $refdir ) then
    echo $refdir does not exist.  Exiting.  
    exit 1
endif
cd $refdir
pwd
if ( ! -e $odir ) then
    mkdir -p $odir
endif

# DAOMASTER SETTINGS
set minfrac = 0.25
set startrad = 10
set crad = 2
set forder = 2
# REFINED SOLUTION AND OUTPUT
#  Desired degrees of freedom ---
#                  2:  Translations only
#                  4:  Translations, rotation, and scale
#                  6:  Six-constant linear transformation
#                 12:  Quadratic transformation
#                 20:  Cubic transformation
if ( $INSTR == Spitzer) then
# ALLOW for field rotation.  forder = 4
    set forder = 4
#    set minfrac = 0.5
endif
if ( $filter == H ) then
    set minfrac = 1
endif
###############################################


###############################################
# LOOP OVER INPUT IMAGES
if ( ! -d $datapath ) then
    echo "$datapath" does not exist.
    exit 1
endif

rm -fr $refdir/phot.txt >>& /dev/null
if ( ! -e $image_master ) then
    echo MAKING $image_master with MONTAGE2
else if ( -e $image_master  && $allframe != "" ) then
    echo $image_master > $refdir/phot.txt
else
    echo $image_master > $refdir/phot.txt
endif

# LIST INDIVIDUAL FRAMES
if ( $ref_only == 0 ) then
    if ( $INSTR == Spitzer ) then
	echo $datapath
	ls $datapath/*_e[0-9]*/*[0-9]_${filter}.fits >> $refdir/phot.txt
    else
	if ( $PROJECT == CRRP ) then
	    echo CRRP
	    if ( `ls $datapath/20*/$filter/20*${name}*mos.fits >>& /dev/null ; echo $status` == 0 ) then
		echo "Found *.mos.fits files"
		foreach filen (  $datapath/20*/$filter/20*${name}*mos.fits )
		    ln -fs $filen $filen:s/.mos//
		end
	    endif
	    ls $datapath/20*/$filter/20*${name}*[0-9][0-9][0-9].fits >> $refdir/phot.txt
	else
	    echo CHP
	    if ( `ls $datapath/20*/$filter/20*${name}*mos.fits >>& /dev/null ; echo $status` == 0 ) then
		echo "Found *.mos.fits files"
		foreach filen (  $datapath/20*/$filter/20*${name}*mos.fits )
		    ln -fs $filen $filen:s/.mos//
		end
	    endif
	    ls $datapath/20*/$filter/20*${name}*[0-9][0-9][0-9].fits >> $refdir/phot.txt
	endif
    endif
endif

if ( 0 ) then
    emacs $refdir/phot.txt
    wait
endif
#exit

if ( `cat $refdir/phot.txt | wc -l` == 1 ) then
    set include_master = 1
endif

#exit

# LOOP OVER EACH FRAME, STARTING WITH MASTER
set PSFS =  null
set ASSOC = null
set PSFS_REF = null
set ASSOC_REF = null

if ( 1 ) then
    set PSFS_REF = $refdir/image.$filter.psf.coords
    set ALF_REF = $refdir/image.$filter.alf.coords
    set ASSOC_REF = $refdir/image.$filter.coo.coords
else
    set PSFS_REF = $refdir/image.Ks.psf.coords
    set ALF_REF = $refdir/image.Ks.alf.coords
    set ASSOC_REF = $refdir/image.Ks.coo.coords
endif


@ i = 1
foreach image ( `cat $refdir/phot.txt` )
    if ( $REDO_PHOT == 0 ) then
	echo $image
	continue
    endif
    set TELESCOP = `gethead -u $image TELESCOP`
    set NAXIS = `gethead -u $image NAXIS1 NAXIS2`
    if ( $border[2] == 0 ) then
	set border[2] = $NAXIS[1]
    endif
    if ( $border[4] == 0 ) then
	set border[4] = $NAXIS[2]
    endif

    rm $image.psf.coo $image.psf.coo.1 >>& /dev/null
    if ( -e $PSFS_REF && ! -z $PSFS_REF   ) then
	echo $PSFS_REF exists, creating $image.psf.coo
	sky2xy $image @$PSFS_REF | awk ' ! /off/ {printf "%10.3f %10.3f \n",$(NF-1),$NF }' > $image.psf.coo.1
	getpix -n 1 %6.3f $image @$image.psf.coo.1 | paste $image.psf.coo.1 -  | awk ' ! /nan/ {if(NF>2) printf "%10.3f %10.3f \n",$1,$2  }' > $image.psf.coo
	rm -fr $image.psf.coo.1 >>& /dev/null
	set PSFS = $image.psf.coo
    endif
# DONT WASTE TIME FINDING ALL SOURCES IN EACH FRAME IF YOU PLAN ON RUNNING ALLFRAME.   
    rm $image.coord.coo $image.coord.coo.1 >>& /dev/null
    if ( -e $ASSOC_REF && ! -z $ASSOC_REF && ( $ref_only == 1 || $rallframe == 0 ) ) then
	echo $ASSOC_REF exists, creating $image.coord.coo
	sky2xy $image @$ASSOC_REF | awk ' ! /off/ {printf "%10.3f %10.3f \n",$(NF-1),$NF }' > $image.coord.coo.1
	getpix -n 1 %6.3f $image @$image.coord.coo.1 | paste $image.coord.coo.1 -  | \
	    awk ' ! /nan/ {if(NF>2) printf "%10.3f %10.3f \n",$1,$2  }' > $image.coord.coo
	rm -fr $image.coord.coo.1 >>& /dev/null
	set ASSOC = $image.coord.coo
    endif

    rm -fr $image.log >>& /dev/null
    rm -fr $image:h/daophot_$filter.log >>& /dev/null
    rm -fr $image:h/daophot.log >>& /dev/null
    set log = $image:h/daophot_$image:t:r.log
    rm -fr $log >>& /dev/null
    echo $log
    if ( $i == 1 && -e $image_master && $ref_only == 1 ) then
	if ( $sex == 1 ) then
#	    set thresh = ( 5 1e9 1e9 )
#	    set thresh = ( 10 1e9 1e9 )
	else
#	    set thresh = ( 2 0.5 0.3 )
#	    set thresh = ( 0.05 )
	endif
	printf "%40s  %40s\n" "Performing photometry on Master image:" $image_master
	#set force = 1
	$daopath/dophot.csh -image $image_master -dao "$dao" -iraf "$iraf" -irafarch $irafarch -filter $filter \
	    -sedi "$sedi" -sex $sex -psfs "$PSFS" -assoc "$ASSOC" -redo $REDO_PHOT -coord "$ccoord" \
	    -force $force -npsf $npsf -psf2 $psf2 -covfrac $covfrac -thresh "$thresh" -border "$border" \
	    -fake $fake > $log
	rm $image.psf.coo $image.psf.coo.1 >>& /dev/null
	rm $image.coord.coo $image.coord.coo.1 >>& /dev/null
#	exit 0
    else
#	set thresh = ( 5 )
#	set force = 0
	printf "%40s  %40s\n" "Started photometry on image:" $image
	$daopath/dophot.csh -image $image -dao "$dao" -iraf "$iraf" -irafarch $irafarch -filter $filter \
	    -sedi "$sedi" -sex $sex -psfs "$PSFS" -assoc "$ASSOC" -redo $REDO_PHOT -coord "$ccoord" \
	    -force $force -npsf $npsf -psf2 $psf2 -covfrac $covfrac -thresh "$thresh" -border "$border" \
	    -fake $fake > $log &

    endif
    @ i ++
end
###############################################
echo waiting for phot to finish ...
wait
#exit

if ( $sex == 0 || $REDO_ANAL == 0 ) then
    echo Finished.
    exit 1
endif

cd $odir
###############################################
## PERFORM DAOMASTER ON ALL FRAMES
if ( 1 ) then
    if ( $REDO_ANAL ) then
	rm -fr $odir/* >>& /dev/null
    endif
    echo pwd is `pwd`
    printf "\n\n   Running Daomatch/Daomaster...\n\n"
    @ i = 0
    @ skip = 0
    rm -fr daomatch.txt daomatch.log >>& /dev/null
    set refimage = NULL
    rm -fr $master.mjd >>& /dev/null

#    exit 0
#exit
################################################################################

    #  COPY/LINK EACH ALS FILE TO LOCAL DIRECTORY. 
    foreach image ( `cat $refdir/phot.txt` )
	@ i ++
	if ( -e image_$i.als && ! $REDO_ANAL ) then
	    echo image_$i.als already exists
	else
	    rm -fr image_$i.als >>& /dev/null
	    # for sextractor output, parse into single line als format.
	    if ( $sex == 0 ) then
		awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > $i.als
		awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
		'$NAXIS1','$NAXIS2','-100','$SATURATE','5','2','$GAIN','$EFFRN','5'}' >> image_$i.als
		# PSF MAG
		ls $image:h/sex_$image:t:r/image.dat
		awk '{printf "%5d %10.3f %10.3f %7.6f %7.6f   %6.3f %6.3f\n",NR,$1,$2,$5,$6,0.0,0.0}' $image:h/sex_$image:t/image.dat >> image_$i.als
		# MAG_AUTO 
#		awk '{printf "%5d %10.3f %10.3f %7.6f %7.6f   %6.3f %6.3f\n",NR,$1,$2,$7,$8,0.0,0.0}' $image:h/sex_$image:t/image.dat >> $i.als
	    # for daophot mag and als files, parse the multiline output into a single line
	    else
#		ln -fs $image:h/daophot_$image:t:r/image.fits image_$i.fits
		ln -fs $image image_$i.fits
		ln -fs $image:h/daophot_$image:t:r/image.als image_$i.als
		ln -fs $image:h/daophot_$image:t:r/image.cpsf image_$i.psf
		if ( $INSTR == Spitzer ) then
		    set CHNL = `gethead $image CHNLNUM`
		    set cora = ( $image:s/3p6um/correction_3p6um/ $image:s/4p5um/correction_4p5um/ )
		    ln -fs $cora[$CHNL]:s/_dn// image_c_$i.fits
		    ln -fs $image:h/daophot_$image:t:r/image.als image_c_$i.als
		    ln -fs $image:h/daophot_$image:t:r/image.cpsf image_c_$i.psf
		endif
#		setenv image$i $image:h/daophot_$image:t:r
		if ( $status != 0 ) then
		    echo linking error...
		    exit 1
		endif
	    endif
	endif

	#  COUNT HOW MANY SOURCE IN EACH ALS FILE.  
	@ count = `cat image_$i.als | wc -l | awk '{print $0-3}'`
	printf "%50s %15s %8d sources.\n" $image "image_$i.als" $count
	if ( $count < 10 ) then
	    echo less than 10 sources, not including...
	    @ skip ++
	    continue
	endif

	#  INCLUDE THE MASTER DEEP IMAGE IN ANALYSIS
	if ( ! $include_master ) then
	    if ( $i == 1 && -e $image_master ) then
		echo NOT USING HJD OF $image_master
		@ skip ++
		continue
	    endif
	endif

	#  GET HJD FOR EACH OBSERVATION
	set MJD = `gethead -u $image MJD`
	if ( $MJD != ___ ) then
	    echo $MJD >> $master.mjd
	else
	    cp $daopath/iraf/setjd.par ${image}.setjd.par
	    sedi 's|images = |images = \"'$image'\"|' ${image}.setjd.par
	    sedi 's|observatory = \"obspars\"|observatory = "lco"|' ${image}.setjd.par
	    if ( $INSTR == Spitzer ) then
		sedi 's|epoch = \"EPOCH\"|epoch = \"EQUINOX\"|' ${image}.setjd.par
		sedi 's|date = \"DATE-OBS\"|date = \"DATE_OBS\"|' ${image}.setjd.par
	    endif
	    astutil setjd \@${image}.setjd.par | awk ' ! /#/ {printf "%12.5f\n",$(NF-1)-2400000.5 }' >> $master.mjd
	    rm -fr ${image}.setjd.par >>& /dev/null
	endif
	
	if ( $refimage == NULL  ) then
	    set coord = `gethead -u $image CRVAL1 CRVAL2 CRPIX1 CRPIX2 SCALE`
	    foreach keyword ( TELESCOP GAIN SATURATE SCALE EFFRN CRVAL1 CRVAL2 NAXIS1 NAXIS2 )
		set $keyword = `gethead -u $image $keyword`
		if ( `eval echo \$$keyword` == ___ ) then
		    eval set $keyword = 1.0
		endif
	    end
	    if ( $INSTR == Spitzer ) then
		set SATURATE = 10000
		set SCALE = 0.600012
		set coord[5] = $SCALE
	    endif
	    set refimage = $image
	    set refcoord = ( $coord )
	    # set daomatch.txt in case I want to use daomatch for initial offset solution
	    echo "image_$i.als" > daomatch.txt
	    echo $initial.mch >> daomatch.txt
	    # also fake daomatch output for the simple offset case, in case daomatch gives bad output.  
#	    printf "'image${i}:image_$i.als     '      0.00      0.00   1.00000   0.00000   0.00000   1.00000     0.000     0.000\n" > $initial.mch
	    printf "'image_$i.als     '      0.00      0.00   1.00000   0.00000   0.00000   1.00000     0.000     0.000\n" > $initial.mch
	else
	    echo "image_$i.als" >> daomatch.txt
	    echo "y" >> daomatch.txt
#	    printf "'image${i}:image_$i.als     ' %9.2f  %9.2f   1.00000   0.00000   0.00000   1.00000     0.000     0.000\n" \
	    printf "'image_$i.als     ' %9.2f  %9.2f   1.00000   0.00000   0.00000   1.00000     0.000     0.000\n" \
	    `awk 'BEGIN {print -1*( ('$coord[1]'*(3600/'$coord[5]')-('$coord[3]')) - ('$refcoord[1]'*(3600/'$refcoord[5]')-('$refcoord[3]')) ),\
			       +1*( ('$coord[2]'*(3600/'$coord[5]')-('$coord[4]')) - ('$refcoord[2]'*(3600/'$refcoord[5]')-('$refcoord[4]')) )}'` >> $initial.mch
	endif
    end
    echo EXIT >> daomatch.txt
    echo "REFIMAGE = $refimage"
    @ nframe = $i - $skip
    if ( $nframe == 1 ) then
	printf "\nThere is only $nframe frame.\n"
    else
	printf "\nThere are $nframe frames.\n"
#	if ( -e $initial.mch && ! $REDO_ANAL ) then
	if ( 0 ) then
	    printf "$initial.mch already exists... \n"
	else
	    # TRY DAOMATCH........
	    if ( 1 ) then
		# DAOMATCH WILL FIND INITIAL OFFSET BETWEEN INPUT PHOTOMETRY FILES.   
		echo Trying DAOMATCH...
		rm -fr $initial.mch
		set log = daomatch.log
		set loglim = 5000
		daomatch < daomatch.txt  >& $log &
		set lbid = $! # last job ID
		set wcold = 0 
		while ( `ps -c | grep $lbid` != "" )
		    set wcnew = `cat $log | wc -l`
		    if ( $wcnew > $loglim ) then
			kill -9 $lbid
			printf "\nSomething went wrong.  Check $log for details.\n" >>& /dev/stderr
			exit 1
		    endif
		    set wcold = $wcnew
		    sleep 1
		end
	    else
		# DAOMATCH NOT GOOD AT HANDLING IF IMAGE SHIFTS ARE LARGE AND MORE THAN HALF THE SOURCES ARE LOST IN ADJACENT FRAMES. APPLY MANUAL OFFSETS IF KNOWN
	    endif
	endif

	# RUN DAOMASTER
	rm -fr $master.mch $master.mag $master.cor $master.raw daomaster.log
	if ( -e $master.mag && ! $REDO_ANAL ) then
	    printf "$master.mag already exists...\n"
	else
	    # DAOMASTER WILL REFINE SOLUTION AND GENERATE FINAL PHOTOMETRIC OUTPUT
	    echo $initial.mch > daomaster.txt
	    awk 'BEGIN {printf "%d,%3.1f,%d\n", ('$nframe'*'$minfrac'<1)?1:'$nframe'*'$minfrac', '$minfrac', ('$nframe'*'$minfrac'<1)?1:'$nframe'*'$minfrac'}' >> daomaster.txt
	    awk 'BEGIN {printf "%d\n", 99}' >> daomaster.txt
	    awk 'BEGIN {printf "%d\n", '$forder'}' >> daomaster.txt
	    awk 'BEGIN {printf "%d\n", '$startrad'}' >> daomaster.txt # Critical match-up radius:
	    if ( 1 ) then
		awk 'BEGIN {for(i=1;i<'$nframe';i++) printf "\n"}' >> daomaster.txt  # HIT ENTER
	    endif
	    awk 'BEGIN {for(i='$startrad';i>='$crad';i--) printf "%d\n",i}' >> daomaster.txt   # New match-up radius (0 to exit):
	    awk 'BEGIN {for(i=0;i>=10;i++) printf "%d\n",'$crad'}' >> daomaster.txt   # New match-up radius (0 to exit):
	    awk 'BEGIN {printf "%d\n",0}' >> daomaster.txt  # New match-up radius (0 to exit):
	    awk 'BEGIN {printf "%s\n","y"}' >> daomaster.txt
	    awk 'BEGIN {printf "%s\n%s\n","y","'$master.mag'"}' >> daomaster.txt
	    awk 'BEGIN {printf "%s\n%s\n","y","'$master.cor'"}' >> daomaster.txt # A file with corrected magnitudes and errors?
	    awk 'BEGIN {printf "%s\n%s\n","y","'$master.raw'"}' >> daomaster.txt # A file with raw magnitudes and errors?
	    awk 'BEGIN {printf "%s\n%s\n","y","'$master.mch'"}' >> daomaster.txt # A file with the new transformations? 
#	    awk 'BEGIN {printf "%s\n","n"}' >> daomaster.txt # A file with the new transformations? 
	    awk 'BEGIN {printf "%s\n","n"}' >> daomaster.txt # A file with the transfer table?
	    awk 'BEGIN {printf "%s\n","n"}' >> daomaster.txt # Individual .COO files?
	    awk 'BEGIN {printf "%s\n","n"}' >> daomaster.txt # Simply transfer star IDs?
	    ###### RUN DAOMASTER ###########
	    set log = daomaster.log
	    set loglim = 1000
	    daomaster < daomaster.txt >>& $log &
	    set lbid = $! # last job ID
	    set wcold = 0 
	    while ( `ps -c | grep $lbid` != "" )
		set wcnew = `cat $log | wc -l`
		if ( $wcnew > $loglim ) then
		    kill -9 $lbid
		    printf "\nSomething went wrong.  Check $log for details.\n" >>& /dev/stderr
		    exit 1
		endif
		set wcold = $wcnew
		sleep 1
	    end
	    wait
	    ################################
#	    rm -fr daomaster.txt
	    echo DAOMASTER DONE
	endif
	if ( ! -e $master.mch ) then
	    printf "$master.mch not created.    Exiting.\n"
	    exit 1
	endif
# IF you get this message.   
#   ERROR --- No stars left.   CHECK THERE ARE NO nan ENTRIES IN THE MAGNITUDES.   
#  
# RUN MONTAGE
	pwd
	if ( -e $image_master ) then
	    echo $image_master exists...
	else
	    montage2 <<EOF
$master.mch     # File with transformations:

3,0.5		# Minimum number of frames, percentile:
1,$NAXIS1	# X limits of output image 
1,$NAXIS2	# Y limits of output image:
1               # Expansion factor: 
y		# Determine sky from overlap region? 
$image_master:r:t
EOF
#	    mv $image_master:r:t.fits $image_master
	    cp $daopath/iraf/imexpr.par imexpr.par
	    sedi 's|imexpr.expr = |imexpr.expr = \"(a<100000) ? a+'1' : 0 \"|' imexpr.par
	    sedi 's|imexpr.output = |imexpr.output = \"'$image_master'\"|' imexpr.par
	    sedi 's|imexpr.a = |imexpr.a = \"'$image_master:r:t.fits'\"|' imexpr.par
	    images imexpr \@imexpr.par
	    if ( $INSTR == Spitzer ) then
		awk '{sub("_","_c_",$1); print}' $master.mch > $master.cp.mch
		montage2 <<EOF
$master.cp.mch     # File with transformations:

3,0.5		# Minimum number of frames, percentile:
1,$NAXIS1	# X limits of output image 
1,$NAXIS2	# Y limits of output image:
1               # Expansion factor: 
y		# Determine sky from overlap region? 
$image_master:r:t
EOF
#		mv $image_master:t:r.fits $image_master:s/master/master_correction/
		cp $daopath/iraf/imexpr.par imexpr.par
		sedi 's|imexpr.expr = |imexpr.expr = \"(a<100000) ? a+'1' : 0 \"|' imexpr.par
		sedi 's|imexpr.output = |imexpr.output = \"'$image_master:s/master/master_correction/:s/_dn//'\"|' imexpr.par
		sedi 's|imexpr.a = |imexpr.a = \"'$image_master:t:r.fits'\"|' imexpr.par
		images imexpr \@imexpr.par
	    endif
	endif


#exit 0
# TRY ALLFRAME
	if ( $allframe == a ) then
#	    rm $master.nmg >>& /dev/null
	    if ( -e $master.nmg && ! $REDO_ALF ) then
		printf "$master.nmg already exists...\n"
	    else
		rm -fr allframe.txt allframe.log >>& /dev/null
		printf "\n  Creating allframe.opt in local directory `pwd` and setting parameters \n"
		awk 'BEGIN {printf "%s = %6.2f\n","CE (CLIPPING EXPONENT)", '6.0'}' > allframe.opt
		awk 'BEGIN {printf "%s = %6.2f\n","CR (CLIPPING RANGE)", '2.5'}' >> allframe.opt
		awk 'BEGIN {printf "%s = %6.2f\n","GEOMETRIC COEFFICIENTS",'6.0'}' >> allframe.opt
		awk 'BEGIN {printf "%s = %6.2f\n","WATCH PROGRESS", '2.0'}' >> allframe.opt
		awk 'BEGIN {printf "%s = %6.2f\n","MINIMUM ITERATIONS", '5.0'}' >> allframe.opt
		awk 'BEGIN {printf "%s = %6.2f\n","MAXIMUM ITERATIONS", '200.00'}' >> allframe.opt
		awk 'BEGIN {printf "%s = %6.2f\n","PERCENT ERROR (in %)", '0.75'}' >> allframe.opt
		awk 'BEGIN {printf "%s = %6.2f\n","PROFILE ERROR (in %)", '5.00'}' >> allframe.opt
		if ( $TELESCOP == Spitzer ) then
		    awk 'BEGIN {printf "%s = %6.2f\n","IS (INNER SKY RADIUS)", '6.0'}' >> allframe.opt
		    awk 'BEGIN {printf "%s = %6.2f\n","OS (OUTER SKY RADIUS)", '14.00'}' >> allframe.opt
		else
		    awk 'BEGIN {printf "%s = %6.2f\n","IS (INNER SKY RADIUS)", '2.5'}' >> allframe.opt
		    awk 'BEGIN {printf "%s = %6.2f\n","OS (OUTER SKY RADIUS)", '25.00'}' >> allframe.opt
		endif

		awk 'BEGIN {printf "\n%s\n","'$master.mch'"}' > allframe.txt  # File with list of images:	    
#		awk 'BEGIN {printf "%s\n","'$master.mag'"}' >> allframe.txt # File with list of stars:	    
	     # USE als FILE FROM DEEP IMAGE AS NUMBER 1. 
		if ( -e $ALF_REF ) then
		    cp $ALF_REF image_1.mag
		else
		    cp image_1.als image_1.mag
		endif
#exit 0
		rm -fr *_c_* >>& /dev/null
		foreach aname ( image_*.als )
		    echo $aname
		    mv -f $aname $aname.orig
		    head -n3 $aname.orig > $aname
		end

		awk 'BEGIN {printf "%s\n","'image_1.mag'"}' >> allframe.txt # File with list of stars:	    
		echo STARTING ALLFRAME, SEE allframe.log
#		exit 0

		if ( 1 ) then
		    echo NO, REALLY... STARTING ALLFRAME, SEE allframe.log
		    allframe < allframe.txt >>& allframe.log
		    # COPY ALF FILES TO ORIGINAL LOCATION. CANNOT GET PBS directory:file.ext notation to work.
		    @ i = 0
		    foreach aname ( image_*.als.orig )
			@ i ++
			if ( $i == 1 ) then
			    continue
			endif
			set lname = `ls -l $aname | awk '{print $NF}'`
			echo "$aname --> $lname"
			cp $aname:s/.als.orig/.alf/ $lname:s/.als/.alf/
		    end

		    # CORRECT SPITZER PHOT.
		    if ( $TELESCOP == Spitzer ) then
			@ i = 0
			foreach image ( `cat $refdir/phot.txt` ) 
			    @ i ++
			    if ( $i == 1 ) then
				continue
			    endif
			    $daopath/dophot.csh -image $image -dao "$dao" -iraf "$iraf" -irafarch $irafarch -filter $filter \
				-sedi "$sedi" -sex $sex -redo 0 -telescope Spitzer >>& $image.log &
			end
			wait
		    endif
		    # LINK NEW ALF FILES TO CURRENT DIRECTORY.
		    @ i = 0
		    foreach image ( `cat $refdir/phot.txt` )
			@ i ++
			if ( $i == 1 ) then
			    continue
			endif
			cp -f $image:h/daophot_$image:t:r/image.alf image_$i.alf
		    end
		endif
		echo ALLFRAME FINISHED.
	    endif
	# MAKE NEW MONTAGE FROM ALLFRAME SUBTRACED IMAGES... LOOK FOR RESIDUAL SOURCES
	    if ( 1 ) then 
		rm -fr ${image_master:r:t}j.fits >>& /dev/null
		montage2 <<EOF
$master.mch     # File with transformations:
j
3,0.5		# Minimum number of frames, percentile:
1,$NAXIS1	# X limits of output image 
1,$NAXIS2	# Y limits of output image:
1               # Expansion factor: 
y		# Determine sky from overlap region? 
${image_master:r:t}j
EOF
		rm -fr ${image_master:r:t}.res.fits >>& /dev/null
		cp $daopath/iraf/imexpr.par imexpr.par
		sedi 's|imexpr.expr = |imexpr.expr = \"( a > 1e10 ) ? 0 : a \"|' imexpr.par
		sedi 's|imexpr.output = |imexpr.output = \"'${image_master:r:t}.res.fits'\"|' imexpr.par
		sedi 's|imexpr.a = |imexpr.a = \"'${image_master:r:t}j.fits'\"|' imexpr.par
		images imexpr \@imexpr.par
	    endif


#exit 0
	    # DAOMASTER WILL REFINE SOLUTION AND GENERATE FINAL PHOTOMETRIC OUTPUT
	    rm -fr $master.maga $master.cora $master.rawa daomaster.log
	    awk '{sub("als","alf");print}' $master.mch > $master.mcha
	    echo $master.mcha > daomaster.txt
	    awk 'BEGIN {printf "%d,%3.1f,%d\n", '$nframe'*'$minfrac', '$minfrac', '$nframe'*'$minfrac'}' >> daomaster.txt
	    awk 'BEGIN {printf "%d\n", 99}' >> daomaster.txt
	    awk 'BEGIN {printf "%d\n", '$forder'}' >> daomaster.txt
	    awk 'BEGIN {printf "%d\n", '$startrad'}' >> daomaster.txt # Critical match-up radius:
	    awk 'BEGIN {for(i=0;i<'$nframe';i++) printf "\n"}' >> daomaster.txt  # HIT ENTER
	    awk 'BEGIN {for(i='$startrad';i>='$crad';i--) printf "%d\n",i}' >> daomaster.txt   # New match-up radius (0 to exit):
	    awk 'BEGIN {for(i=0;i>=10;i++) printf "%d\n",'$crad'}' >> daomaster.txt   # New match-up radius (0 to exit):    HIT DESIRED RADIUS A FEW MORE TIMES TO CONVERGE
	    awk 'BEGIN {printf "%d\n",0}' >> daomaster.txt  # New match-up radius (0 to exit):
	    awk 'BEGIN {printf "%s\n","y"}' >> daomaster.txt
	    awk 'BEGIN {printf "%s\n%s\n","y","'$master.maga'"}' >> daomaster.txt
	    awk 'BEGIN {printf "%s\n%s\n","y","'$master.cora'"}' >> daomaster.txt # A file with corrected magnitudes and errors?
	    awk 'BEGIN {printf "%s\n%s\n","y","'$master.rawa'"}' >> daomaster.txt # A file with raw magnitudes and errors?
	    awk 'BEGIN {printf "%s\n","n"}' >> daomaster.txt # A file with the new transformations? 
	    awk 'BEGIN {printf "%s\n","n"}' >> daomaster.txt # A file with the transfer table?
	    awk 'BEGIN {printf "%s\n","n"}' >> daomaster.txt # Individual .COO files?
	    awk 'BEGIN {printf "%s\n","n"}' >> daomaster.txt # Simply transfer star IDs?
	    daomaster < daomaster.txt >>& daomaster.log
#	    rm -fr daomaster.txt
	    if ( ! -e $master.maga ) then
		echo $master.maga not created.  Exiting.
		exit 1
	    endif
	    echo DAOMASTER DONE
	endif # TRY ALLFRAME
    endif # MORE THAN ONE IMAGE.
endif

#exit
################################################################################
cd $odir
# USE PHOTOMETRY FROM REFERENCE IMAGE (NO LIGHT CURVE INFO, JUST A DEEP AVERAGE)
if ( $include_master ) then
    if ( $sex == 0 ) then
	awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > tma.mag
	awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
	    '$NAXIS1','$NAXIS2','-100','$SATURATE','5','2','$GAIN','$EFFRN','5'}' >> tma.mag
	awk '{if($0 \!~ /99./) printf "%5d %10.3f %10.3f %7.4f %7.4f %7.4f %6d %6.2f %6.2f %6.2f %6.2f\n"\
	    ,NR,$1,$2,$5,$6,$12,10,0,0,0,0}' $refimage:h/sex_$refimage:t/image.dat >> fourstar_$filter.mag
    else
	ln -fs image_1.als fourstar_$filter.mag
	ln -fs image_1.als fourstar_$filter.cor
	if ( $status != 0 ) then
	    echo linking error...
	    exit 1
	endif
    endif
# USE AVERAGE PHOTOMETRY FROM INDIVIDUAL IMAGES.
else
    ln -fs $master.mag fourstar_$filter.mag
    ln -fs $master.cor fourstar_$filter.cor
    if ( -e $master.maga ) then
	ln -fs $master.maga fourstar_$filter.maga
	ln -fs $master.cora fourstar_$filter.cora
    endif
endif
#exit

################################################################################
# CREATE DIRECTORY FOR PLOTS.
if ( ! -d $odir ) then
    mkdir -p $odir
endif
################################################################################
# REFINE ZEROPOINT BY USING 2MASS STANDARDS
printf "\nFINDING $filter ZEROPOINT \n"
echo "REFIMAGE = $refimage"
set REFPOS1 = 8
set TMF = Ks
if ( $filter == J ) then
    set REFPOS1 = 4
    set TMF = J
endif
if ( $filter == H ) then
    set REFPOS1 = 6
    set TMF = H
endif
if ( $filter == Ks ) then
    set REFPOS1 = 8
    set TMF = Ks
endif
if ( $TELESCOP == Spitzer ) then
    set REFPOS1 = 8
    set TMF = Ks
endif


set coords = ( $CRVAL1 $CRVAL2 $NAXIS1 $NAXIS2 $SCALE )
if ( -e 2MASS_${filter}.cat && ! -z 2MASS_${filter}.cat ) then
    echo 2MASS_${filter}.cat is not empty.  not downloading reference catalog.
else
    printf "Downloading 2MASS data for $coords :\n"   
    # reports 3E-2 convert to 3e-2 for find2mass
    set coords[1] = $coords[1]:l
    set coords[2] = $coords[2]:l
    set radius = `echo " sqrt($coords[3]*$coords[3] + $coords[4]*$coords[4]) * 0.50 * $coords[5] / 60.0 " | bc`
    @ nser = 1
tryagain:
    setenv CDSCLIENT $clients[$nser]
    echo "CDSCLIENT = $CDSCLIENT"
    echo "find2mass $coords[1],$coords[2] -r $radius -eb -lJ 8,20 -m10000000"
    find2mass $coords[1],$coords[2] -r $radius -eb -lJ 8,20 -m10000000 > 2MASS_${filter}.cat
    if ( $status != 0 ) then
	if ( $nser == $#clients ) then
	    echo "DID NOT FIND 2MASS STARS... SERVER DOWN?"
	    rm -fr 2MASS_${filter}.cat
	    exit 1
	endif
	@ nser ++
	goto tryagain
	exit 1
    endif
endif

if ( -e stds_$filter.als && ! $REDO_ANAL ) then
    echo stds.als already exists.
else
    echo "FINDING NEW ZEROPOINT"
    if ( $SEXFLAG == ALL ) then
	grep -v \# 2MASS_${filter}.cat | cut -d "|" -f1-5 | tr "|" " " > 2MASS_${filter}.tmp
    else
	grep $SEXFLAG 2MASS_${filter}.cat | cut -d "|" -f1-5 | tr "|" " " > 2MASS_${filter}.tmp
    endif
    mv 2MASS_${filter}.tmp 2MASS_${filter}.tmp.orig
    awk '{gsub("---","0.1",$0); print}' 2MASS_${filter}.tmp.orig > 2MASS_${filter}.tmp
    rm -fr 2MASS_${filter}.tmp.orig
    sky2xy $refimage @2MASS_${filter}.tmp > 2MASS_${filter}.dat
    
    awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > stds_$filter.als
    awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
	'$NAXIS1','$NAXIS2','-100','$SATURATE','5','2','$GAIN','$EFFRN','5'}' >> stds_$filter.als
    paste 2MASS_${filter}.tmp 2MASS_${filter}.dat | awk ' ! /off/ {printf "%5d %10.3f %10.3f %7.6f %7.6f    0.000\n",\
	NR,$(NF-1),$NF,$('$REFPOS1'),$('$REFPOS1'+1)}' >> stds_$filter.als

endif

if ( -e standard_$filter.raw && ! $REDO_ANAL ) then
    echo standard_$filter.raw already exists.
else
    printf "\nMatching to 2MASS SOURCES...\n"
    $daopath/match.csh stds_$filter.als fourstar_$filter.mag$allframe standard_$filter -$crad $forder $dao
endif
################################################################################
if ( ! -e standard_$filter.raw ) then
    echo "standard_$filter.raw did not get created... Exiting."
    exit 1
endif
awk '{if(NR>3 && ($4>'$maglim1' && $4<'$maglim2' ) ){ave=($4-$6);sig=sqrt($5^2+$7^2);print ave,sig}}' standard_$filter.raw > standard_$filter.stat
$daopath/stats.csh -f standard_$filter.stat -niter 10 -v
set MZ = `$daopath/stats.csh -f standard_$filter.stat -niter 10`
echo $MZ
echo $MZ[5] $MZ[7]
echo $MZ[8] $MZ[9]
set MZP = ( $MZ[8] $MZ[9] )

if ( $TELESCOP == Spitzer ) then
    set MZP = ( 0 0 )
endif

printf "zero-point offset = %s  \n" $MZP[1]
$daopath/std.csh standard_$filter.raw $MZP[1] $maglim1 $maglim2 $filter $TMF $odir/standard_$filter.ps
################################################################################
################################################################################
#exit









################################################################################
cd $odir
if ( $PROJECT == CRRP ) then
    cp $refdir/authors/rr_lyrae.cat varstars.cat
endif
if ( $PROJECT == CHP ) then
    cp $refdir/authors/ceph.cat varstars.cat
endif
if ( -e $refdir/authors/cmdstars.cat ) then
    cp $refdir/authors/cmdstars.cat cmdstars.cat
endif
if ( ! -e varstars.cat ) then
    echo no varstars.cat found.  Exiting...
    exit 1
endif
################################################################################
# FIND KNOWN VARIABLES 
if ( ! -e varstars.cat ) then
    echo no varstars.cat found.  Not looking for known variables.
    goto cmd
endif
set output = $odir/amag_${filter}.dat
rm -fr $output
if ( $REDO_ANAL ) then
    rm -fr $output >>& /dev/null
endif

if ( -e $output && ! $REDO_ANAL ) then
    echo $output already exists.
else
    sky2xy $refimage @varstars.cat > tmprr.cat
    awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > tmprr.als
    awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
	'$NAXIS1','$NAXIS2','-100','$SATURATE','5','2','$GAIN','$EFFRN','5'}' >> tmprr.als
    paste varstars.cat tmprr.cat | awk ' ! /off/ {printf "%5d %10.3f %10.3f %7.6f %7.6f    0.000\n",$3,$(NF-1),$(NF),$6,$5}' >> tmprr.als


    if ( $PROJECT == CRRP ) then
	printf "\nFINDING KNOWN RR LYRAE STARS\n"
    endif
    if ( $PROJECT == CHP ) then
	printf "\nFINDING KNOWN CEPHEID STARS\n"
    endif

    echo PWD is `pwd`
    $daopath/match.csh tmprr.als fourstar_$filter.mag$allframe variables_$filter -$crad $forder $dao
    if ( -e fourstar_$filter.mtr ) then
	mv fourstar_$filter.mtr fourstar_$filter.mtr.var 
    else
	printf "fourstar_$filter.mtr did not get created. \n" >>& /dev/stderr
#	printf "No match found between catalogs:  tmprr.als fourstar_$filter.mag$allframe  \n" >>& /dev/stderr
#	exit 1
#	if ( -e tmprr.mtr ) then
#	    mv tmprr.mtr fourstar_$filter.mtr.var 
#	else
#	    printf "tmprr.mtr did not get created either. \n" >>& /dev/stderr
#	endif 
   endif


    if ( ! -e variables_$filter.raw ) then
	echo "variables_$filter.raw did not get created... Exiting."
	exit 1
    endif

    # USE THE RAW MAGS
    awk '{if(NR>3){$6=$6+'$MZP[1]'; print} }' variables_$filter.raw > $output.tmp
    awk '{if(NR>3)print $2,$3}' variables_$filter.mag > $output.coo
    xy2sky -d $refimage @$output.coo | awk '{if($1~":"){split($1,a,":");split($2,b,":");RA=15*(a[1]+a[2]/60+a[3]/3600);DEC=(b[1]~"-"?-1:1)*((b[1]~"-"?-b[1]:b[1])+b[2]/60+b[3]/3600)}else{RA=$1;DEC=$2};DR=sqrt((cos(DEC*3.1415926/180)*(RA-('$ccoord[1]')))^2+(DEC-('$ccoord[2]'))^2);printf "%f %f %f\n",RA,DEC,DR}' | paste - $output.tmp | awk '{print $1,$2,$4,$8,$3 }' | sort -k 4 > $output.radec
    paste $output.tmp $output.radec > $output ; rm $output.tmp
    awk '{if($1~":"){split($1,a,":");split($2,b,":");RA=15*(a[1]+a[2]/60+a[3]/3600);DEC=(b[1]~"-"?-1:1)*((b[1]~"-"?-b[1]:b[1])+b[2]/60+b[3]/3600)}else{RA=$1;DEC=$2};DR=sqrt((cos(DEC*3.1415926/180)*(RA-('$ccoord[1]')))^2+(DEC-('$ccoord[2]'))^2);printf "%f\n",DR}' varstars.cat | paste varstars.cat - > varstars_2.cat

    # MAKE A FINDER CHART WITH LOCATION OF FOUND VARIABLES
#    if ( 1 ) then
#	echo "Enter the following command to make a finder chart."
#	echo "$daopath/ds9.csh $image_master $output.radec"
#	set input = $<
#    endif

    if ( $redo_ds9 == 1 ) then
	rm -f $image_master.ps >>& /dev/null
    endif
    if ( ! -e $image_master.ps ) then
	echo $image_master
#	$daopath/ds9.csh $image_master $output.radec -postage -limits "-1 1" -scale linear
	if ( $filter == Ks || $filter == H ) then
	   $daopath/ds9.csh $image_master $output.radec -postage -limits "-10 1000" -scale log -pscale 0.16
	else if ( $filter == 4p5um ) then
#	   $daopath/ds9.csh $image_master $output.radec -postage -limits "0.7 2" -scale linear -pscale 0.60
	   $daopath/ds9.csh $image_master $output.radec -postage -limits "0 100" -scale log -pscale 0.60
	else
	   $daopath/ds9.csh $image_master $output.radec -postage -limits "0.7 100" -scale log -pscale 0.60
	endif
    endif
#    $daopath/ds9.csh 
#    rm -fr tmprr.cat tmprr.als
endif

#exit
################################################################################
# MAKE LIGHT CURVES
@ i = 0
set num = `cat varstars.cat | wc -l `
#@ i = 6
#set num = 7
rm -fr ${output}_2
printf "\nMATCHING STARS TO MAKE LIGHT CURVES \n"

while ( $i < $num )
    @ i ++
    echo -n "$i   "
    set id = `awk '{if(NR=='$i') print $0 }' varstars_2.cat`
    echo -n $id
    if ( -e fourstar_$filter.mtr.var ) then
	set daoid = `awk '{if(NF>12  && $1 == '$id[3]') print $12 }' fourstar_$filter.mtr.var`
    else if ( -e variables_$filter.tfr ) then
	set linenum = `awk '{if(NR>3  && $1 == '$id[3]') print $NF }' variables_$filter.tfr`
	echo -n $linenum
	set daoid = `awk '{if(NR>3 && (NR-3)=='$linenum') print $1 }' fourstar_$filter.mag$allframe`
    else
	printf "No transfer table.  Exiting...\n"
	exit 2
    endif
#    if ( $nframe == 1  ) then
##	set daoid = `awk '{if(NF>12  && $1 == '$id[3]') print $10 }' fourstar_$filter.mtr.var`
#	set daoid = `awk '{if(NF>12  && $1 == '$id[3]') print $7 }' fourstar_$filter.mtr.var`
#    else
#	set daoid = `awk '{if(NF>12  && $1 == '$id[3]') print $12 }' fourstar_$filter.mtr.var`
#    endif

    rm -fr $odir/$id[3].txt >>& /dev/null
    if ( $daoid == "" ) then
	echo "    NO SOURCE FOUND"
	continue
    else
	echo "  $daoid"
	awk 'BEGIN{flag = 0}{if(NR==4){n=NF};if(NF==n){flag=($1=='$daoid')?1:0} if(flag==1){printf "%s",$0}  }' fourstar_$filter.$phot$allframe | awk '{for(i=4;i<=NF;i+=2) if( $i > 10 && $(i+1) > 0 && $(i+1) < 1.0 ){printf "%7.3f %7.3f '$fsfilt'\n",$i+'$MZP[1]',$(i+1)}else{printf "%7.3f %7.3f '$fsfilt'\n",99.99,9.99} }' | paste $master.mjd - | awk '{if(NF==4){ print}}'> $odir/$id[3].txt
    endif

    if ( $filter == Ks ) then
	foreach fsfiltr ( H Ks 3p6um 4p5um )
	    if ( -e $odir:h/$fsfiltr/$id[3].txt && $odir:h/$fsfiltr != `pwd`   ) then
		awk '{if($NF<=1){print $0}}' $odir:h/$fsfiltr/$id[3].txt >> $odir/$id[3].txt
	    endif
	end
    endif
# -4 4.5
# -3 3.6
# -2 Ks    FourStar
# -1 H     FourStar
# -5 J     FourStar
#  1- Dallora Ks data (Reticulum)
#  2- V data
#  3- B data
#  4- Ic data
#  5- Rc data

    if ( -e $refdir/authors/reticulum_k_lcvs/v${id[3]}k.lcv && $filter == Ks ) then
	awk '{printf "%10.4f %7.3f %7.3f 1\n",$1,($3-0.015),$4}' $refdir/authors/reticulum_k_lcvs/v${id[3]}k.lcv >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/Reticulum_J_lcv/v${id[3]}j.lcv  ) then
	awk ' ! /#/ {printf "%10.4f %7.3f %7.3f -5\n",$1,($3+0.00),$4}' $refdir/authors/Reticulum_J_lcv/v${id[3]}j.lcv >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/walker_var.cat) then
	awk '{if($NF == "V'$id[3]'" && $2<99) {printf "%10.4f %7.3f 0.02 2\n",$1+2440000.0-2400000.5,$2}}' $refdir/authors/walker_var.cat >> $odir/$id[3].txt
	awk '{if($NF == "V'$id[3]'" && $3<99) {printf "%10.4f %7.3f 0.02 3\n",$1+2440000.0-2400000.5,$3}}' $refdir/authors/walker_var.cat >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/walker_var2.cat) then
	awk '{if($NF == "V'$id[3]'" && $5<99) {printf "%10.4f %7.3f %7.3f 2\n",$1+2440000.0-2400000.5,$5,$8}}' $refdir/authors/walker_var2.cat >> $odir/$id[3].txt
	awk '{if($NF == "V'$id[3]'" && $6<99) {printf "%10.4f %7.3f %7.3f 3\n",$1+$3+2440000.0-2400000.5,$6,$9}}' $refdir/authors/walker_var2.cat >> $odir/$id[3].txt
	awk '{if($NF == "V'$id[3]'" && $7<99) {printf "%10.4f %7.3f %7.3f 4\n",$1+$4+2440000.0-2400000.5,$7,$10}}' $refdir/authors/walker_var2.cat >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/Lee_var_obs.dat) then
	awk '{if($NF == "V'$id[3]'" && $3<99) {printf "%10.4f %7.3f %7.3f 2\n",$1-2400000.5,$3,'0.02'}}' $refdir/authors/Lee_var_obs.dat >> $odir/$id[3].txt
	awk '{if($NF == "V'$id[3]'" && $5<99) {printf "%10.4f %7.3f %7.3f 3\n",$1-2400000.5,$5,'0.02'}}' $refdir/authors/Lee_var_obs.dat >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/kinman_var2.txt) then
	awk '{if($NF == "V'$id[3]'" && $2<99) {printf "%10.4f %7.3f 0.02 3\n",$1+2442000.0-2400000.5,$2}}' $refdir/authors/kinman_var2.txt >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/nemec_var.cat) then
	awk '{if($NF == "V'$id[3]'" && $4<99) {printf "%10.4f %7.3f %5.3f 2\n",$1+2450000.0-2400000.5,$4,$5}}' $refdir/authors/nemec_var.cat >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/Kains/table2.dat) then
	awk '{if( $1 == "V'$id[3]'" && $4<99 && $2 == "V" ) {printf "%10.4f %7.3f %5.3f 2\n",$3+0.0-2400000.5,$4,$6}}' $refdir/authors/Kains/table2.dat >> $odir/$id[3].txt
	awk '{if( $1 == "V'$id[3]'" && $4<99 && $2 == "I" ) {printf "%10.4f %7.3f %5.3f 4\n",$3+0.0-2400000.5,$4,$6}}' $refdir/authors/Kains/table2.dat >> $odir/$id[3].txt
	awk '{if( $1 == "V'$id[3]'" && $4<99 && $2 == "r" ) {printf "%10.4f %7.3f %5.3f 5\n",$3+0.0-2400000.5,$4,$6}}' $refdir/authors/Kains/table2.dat >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/ogle.cat) then
	awk '{if($2<99) {printf "%10.4f %7.3f %5.3f 2\n",$1+2450000.0-2400000.5,$2,$3}}' $refdir:h/OGLE/phot/V/OGLE-LMC-RRLYR-$id[3].dat >> $odir/$id[3].txt
	awk '{if($2<99) {printf "%10.4f %7.3f %5.3f 4\n",$1+2450000.0-2400000.5,$2,$3}}' $refdir:h/OGLE/phot/I/OGLE-LMC-RRLYR-$id[3].dat >> $odir/$id[3].txt
    endif

    if ( -e $refdir/authors/sos_var.cat) then
	awk '{if(NR<=152 && $1 == "'$id[3]'" && $3<99 && $4<99) {printf "%10.4f %7.3f %5.3f -5\n",$2-2400000.5,$3,$4}}' $refdir/authors/sos_var.cat >> $odir/$id[3].txt
	awk '{if(NR<=152 && $1 == "'$id[3]'" && $6<99 && $7<99) {printf "%10.4f %7.3f %5.3f -2\n",$5-2400000.5,$6,$7}}' $refdir/authors/sos_var.cat >> $odir/$id[3].txt
	awk '{if(NR>=196 && $1 == "'$id[3]'" && $2=="V" && $4<99 && $5<99) {printf "%10.4f %7.3f %5.3f 2\n",$3-2400000.5,$4,$5}}' $refdir/authors/sos_var.cat >> $odir/$id[3].txt
	awk '{if(NR>=196 && $1 == "'$id[3]'" && $2=="I" && $4<99 && $5<99) {printf "%10.4f %7.3f %5.3f 4\n",$3-2400000.5,$4,$5}}' $refdir/authors/sos_var.cat >> $odir/$id[3].txt
    endif

    if ( $smoutput == 1 ) then
	set smoutput = ""
    else
	set smoutput = ">>\&/dev/null"
    endif
    /usr/local/bin/sm -S << FIN 
verbose 0
macro read "/Users/amonson/software/sm/monson_macros.sm"
macro read "/Users/amonson/software/sm/fitting_macros.sm"
xtcolours
macro plot 12 {
     if(\$?2==0){dev x11 -device 0 -bg white -fg white} else {
     if('\$1'=='lpr'){dev mypostscript \$2} else {
     if('\$1'=='ps'){dev postportfile_colour :SY=echo File is \:OF=\$2:} else {
     if('\$1'=='psl'){dev postlandfile_colour :SY=echo File is \:OF=\$2:} else {
     if('\$1'=='pss'){dev postencap :SY=echo File is \:OF=\$2:}
     }}}}

###### SET SOME DEFAULT VALUES #################################################
     define print_noheader 1      # when printing vectors, dont print a header
     define TeX_strings 1         # use TeX.  (commented out in .sm file, comment out if undesired)
     ltype 0       # 0 solid | 1 dot | 2 short dash | 3 long dash | 4 dot-short-dash
     	   	   # 5 dot-long-dash | 6 short-long dash | 10 erase lines | also ltype expand
     lweight 3	   #
     ptype 4 3	   # ptype n s, n: sided polygon (30max for circle)
     	     	   #            s: 0 open, 1 skeletal, 2 starred, 3 solid  
     verbose 0
     ctype black
################################################################################
################################################################################
#
#   START SCRIPT HERE
#
################################################################################
################################################################################
     data "$odir/$id[3].txt"
     read ! { mjdt 1.f magt 2.f mert 3.f flagt 4 }

     foreach var ( mjd mag mer flag ) {
	set \$var = \$var""t if (magt < 50)
     }

     if ( dimen(mag) == 0 ) {
	quit
     }

# applied the offsets earlier
#     set mag = flag == 0 ? mag + $MZP : mag
# http://www.astro.caltech.edu/~jmc/2mass/v3/transformations/
#     set mag = flag == 1 ? mag - 0.015 : mag

     set PER = $id[5]
#     set PER = ( '$id[4]' == 'RRc' || ('$id[4]' == 'RRd' && $id[5] < 0.4) ) ? PER*1.34 : PER
#     set PER = ( '$id[4]' == 'RRc' ) ? PER*1.34 : PER
     set mjdmin = 0
     set phase = (mjd - mjdmin )/PER - int((mjd - mjdmin )/PER)
     set phase = (phase < 0 ) ? 1+phase : phase
#     print '%10.4f %5.3f %6.4f\n' {mjd phase PER }


     set filters = { b v i k j h l m }
     set labels = { B V I_C K_s J H [3.6] [4.5] }
     set srcid = { 3 2 4 -2 -5 -1 -3 -4 }
     set colors = { blue green red black violet brown blue red }
#     set colors = { black black black black black black black black  }
     set offset = { 0 0 0 -1.5 -0.5 -1.0 -2.0 -2.5 }

     define i 0
     foreach filter filters {
       set \$filter""mag = mag if(flag == srcid[\$i] && mag < 99 )
       set \$filter""mer = mer if(flag == srcid[\$i] && mag < 99 )
       set \$filter""pz = phase if(flag == srcid[\$i] && mag < 99 )
       set \$filter""flag = flag if(flag == srcid[\$i] && mag < 99 )
       define i (\$i+1)
     }

     define filter k
     if ( $dallora == 1 ) {
       set \$filter""mag2 = mag if(flag == 1 && mag < 99 )
       set \$filter""mer2 = mer if(flag == 1 && mag < 99 )
       set \$filter""pz2 = phase if(flag == 1 && mag < 99 )
       set \$filter""flag2 = flag if(flag == 1 && mag < 99 )
       set \$filter""mag = \$filter""mag concat \$filter""mag2
       set \$filter""mer = \$filter""mer concat \$filter""mer2
       set \$filter""pz = \$filter""pz concat \$filter""pz2
       set \$filter""flag = \$filter""flag concat \$filter""flag2
#       print { kmag kmer kflag }
     }


     set all = kmag concat hmag concat jmag concat lmag concat mmag concat vmag concat bmag concat imag 
     window 1 1 1 1
     toplabel '$id[3] $id[4] $id[5]'
     vecminmax all _min _max
     define _min (\$_min - 1 - 2.5 )
     define _max (\$_max + 1 )
     limits 0 2 \$_max \$_min
#     limits 0 2 20.5 16.5
     box 1 2 0 0
     xlabel Phase
     ylabel Apparent Mag

     define i 0
     foreach filter filters {
       if ( $template_fit == 0 || srcid[\$i] > 0 ) {
         if ( dimen(\$filter""pz)>=1 ) {
	   astats \$filter""mag
	   set \$filter""mean = rnd((astats[5]),4)
#           set \$filter""sig = rnd((astats[7]),4)
           set \$filter""sig = rnd(sqrt(((1.086*(astats[7]/astats[5]))**2/(astats[0])**1) + (sum(\$filter""mer)/astats[0])**2/(astats[0])**1),4)
	 } else {
           set \$filter""mean = 99.9
           set \$filter""sig = 99.9
	 }
       } else { 
       if ($template_fit == 1  ) {
         if ( dimen(\$filter""pz)>=5 ) {
           gloessv3 \$filter""pz \$filter""mag (1/(\$filter""mer)**2) \$filter""xfit \$filter""yfit
           set tmp = 10**(\$filter""yfit/-2.5)
           astats tmp
           set \$filter""mean = rnd(-2.5*lg(astats[5]),4)
           set \$filter""sig = rnd(sqrt(((1.086*(astats[7]/astats[5]))**2/(dimen(\$filter""pz))**1) + (sum(\$filter""mer)/dimen(\$filter""pz))**2/(dimen(\$filter""pz))**1),4)
         } else {
           set \$filter""mean = 99.9
           set \$filter""sig = 99.9
         }
       } else { 
       if ($template_fit == 2) {
         if ( dimen(\$filter""pz)>=1 && srcid[\$i] < 0 ) {
 	   if ( dimen(bmag)>1 ) {
	     range2 bmag _amp
	   } else {
	     define _amp 1.25
	   }
	   define var ab1
	   if ( \$_amp >= 1.1 ) { define var ab2 }
	   if ( \$_amp >= 1.4 ) { define var ab3 }
	   if ( \$_amp >= 1.6 ) { define var ab4 }
	   if ( '$id[4]' == 'RRc' || ('$id[4]' == 'RRd' && $id[5] < 0.4 ) ) {	define var c    }
	   if ('\$var' == 'c') {
	     set SF = 0.055
	   } else {
	     set SF = (0.108*\$_amp+0.168)/2
	   }

	   delete flagx
	   set flagx = 0*\$filter""pz
	   define niter 1
	   do iter = 0,\$niter {
#	    echo \$iter
	    delete tmp
	    delete fitmag2
	    delete meas
	    delete one
	    delete weight
	    delete res
	    set fitmag2 = \$filter""mag if( flagx == 0 )
	    set fitmer2 = \$filter""mer if( flagx == 0 )
	    set fitpz2 = \$filter""pz if( flagx == 0 )
	    set one = 1 + 0*fitmag2
	    if ( \$iter == 0 ) {
		set weight = one
	    } else {
		set weight = 1/fitmer2**2
	    }
	    if ( '\$filter' == 'k' ) {
	      set minrms = 9999999
	      do dp=0,1,0.01 {
		set tmp = fitpz2 + \$dp
		set tmp = tmp > 1 ? tmp -1 : (tmp < 0 ? tmp+1 : tmp)
		rrlt tmp
#	        foreach var { c ab1 ab2 ab3 ab4 }{
		    set meas = fitmag2 - SF * rrlt_\$!var 
		    set design = { one }
		    linfit2 design meas \$var""_\$dp var\$var""_\$dp weight
		    if ( linfit2_rms < minrms ) {
			set minrms = linfit2_rms
			define dphase \$dp
			define type \$var
#			set A = \$var""_\$dp
#			range2 rrlt_\$type range
#			set sigA = sqrt( 1/(sum(weight)) + (\$range)**2/12) /sqrt(dimen(meas)-1)
#			set sigA = sigA*SF
#		        set sigA = sqrt(var\$var""_\$dp)/sqrt(dimen(meas)-dimen(design))
		    }
#	        } # foreach var
	      }
	    }

#	    echo \$filter \$dphase \$var
	    if ( \$iter < \$niter || \$iter == -1 ) {
		delete tmp
		delete one
		delete meas
		delete weight
		set tmp = fitpz2 + \$dphase
		set tmp = tmp > 1 ? tmp -1 : (tmp < 0 ? tmp+1 : tmp)
		rrlt tmp
		set one = 1+0*tmp
		set weight = one
		if ( '\$type' == 'c' ) {
		    set meas = fitmag2 - 0.055 * rrlt_\$!type
		    set design = { one }
		} else {
		    set meas = fitmag2 - (0.108*\$_amp+0.168)/2 * rrlt_\$!var 
		    set design = { one }
		}
		linfit2 design meas A varA one
		set flagx = (abs(linfit2_res) > 5*fitmer2) ? 1 : 0
	    }
	}  # end niter

	set \$filter""xfit = 0,1,0.01
	set xfit2 = \$filter""xfit +\$dphase
	rrlt xfit2
	set \$filter""yfit = ( '\$type' == 'c'  ) ? A[0] + 0.055 * rrlt_\$type : A[0] + (0.108*\$_amp+0.168)/2*rrlt_\$type
        set tmp = 10**(\$filter""yfit/-2.5)
        astats tmp
        set \$filter""mean = rnd(-2.5*lg(astats[5]),4)
        set \$filter""sig = rnd(sqrt(((1.086*(astats[7]/astats[5]))**2/(dimen(\$filter""pz))**1) + (sum(\$filter""mer)/dimen(\$filter""pz))**2/(dimen(\$filter""pz))**1),4)
         
	 } else {
           set \$filter""mean = 99.9
           set \$filter""sig = 99.9
	 }
       } else {
	 echo NOTHING TO DO.  
       }}}

       define i (\$i+1)
     }

# INCLUDE CROWDING FLAG, MAKE ERRORS NEGATIVE IF CROWDED IN THAT FILTER
     if ( 1 ) {
	if ( '$name' == 'Reticulum' && ( '$id[3]' == '135' || '$id[3]' == '108' || '$id[3]' == '92' || '$id[3]' == 'null' ) ) {
	    foreach var (lsig msig) {set \$var = -\$var}
	}
	if ( '$name' == 'NGC2257'   && ( '$id[3]' == 'null' || '$id[3]' == 'null' || '$id[3]' == 'null' || '$id[3]' == 'null' ) ) {
	    foreach var (lsig msig) {set \$var = -\$var}
	}
     }



     !echo $id[3] $id[1] $id[2] $id[6] $id[5] $id[4] $id[7] \$(bmean[0]) \$(bsig[0]) \$(vmean[0]) \$(vsig[0]) \$(imean[0]) \$(isig[0]) \$(jmean[0]) \$(jsig[0]) \$(hmean[0]) \$(hsig[0]) \$(kmean[0]) \$(ksig[0]) \$(lmean[0]) \$(lsig[0]) \$(mmean[0]) \$(msig[0])   >> ${output}_2


     define i 0
     define j 1
     foreach filter filters {
       if ( dimen(\$filter""pz)>=1 ) {
         ctype \$(colors[\$i])
         ptype 4 3
         points (\$filter""pz+0) (\$filter""mag+(offset[\$i])) if(\$filter""flag == srcid[\$i] )
         points (\$filter""pz+1) (\$filter""mag+(offset[\$i])) if(\$filter""flag == srcid[\$i] )
         if ( $plot_error == 1 ) {
           error_y (\$filter""pz+0) (\$filter""mag+(offset[\$i])) abs(\$filter""mer)
           error_y (\$filter""pz+1) (\$filter""mag+(offset[\$i])) abs(\$filter""mer)
         }
	 if ( $dallora == 1 ) {
	   ctype red
           points (\$filter""pz+0) (\$filter""mag+(offset[\$i])) if(\$filter""flag == 1 )
           points (\$filter""pz+1) (\$filter""mag+(offset[\$i])) if(\$filter""flag == 1 )
	   ctype \$(colors[\$i])
	 }

	 if ( $template_fit > 0 && is_vector(\$filter""xfit) == 1 ) {
           connect (\$filter""xfit+0) (\$filter""yfit+(offset[\$i]))
           connect (\$filter""xfit+1) (\$filter""yfit+(offset[\$i]))
	 }
         legend 0.05 0.4 7 \$j 1 1 0 \$(labels[\$i])
         define j (\$j+1)
       }
       define i (\$i+1)
     }


#     set color = lmag - mmag
#     page
#     window 1 1 1 1
#     limits 0 2 -1 1
#     box 1 2 0 0
#     ctype black
#     relocate 0 0 draw 2 0
#     points (lpz) color
#     points (lpz+1) color

################################################################################
################################################################################
#
#   END SCRIPT HERE
#
################################################################################
################################################################################
     if ( \$?2==0 ) {
       cursor
     }
}
if ( 1 == $smplot ) {
    plot pss $odir/$id[3].ps
} else {
    plot t
}
FIN

end



if ( 1 ) then
printf "\nMAKING PL RELATIONS \n"
#>>& /dev/null
/usr/local/bin/sm -S << FIN #
VERBOSE 0
macro read "/Users/amonson/software/sm/monson_macros.sm"
macro read "/Users/amonson/software/sm/fitting_macros.sm"
xtcolours
macro plot 12 {
     if(\$?2==0){dev x11 -device 0 -bg white -fg white} else {
     if('\$1'=='lpr'){dev mypostscript \$2} else {
     if('\$1'=='ps'){dev postportfile_colour :SY=echo File is \$F\:OF=\$2:} else {
     if('\$1'=='psl'){dev postlandfile_colour :SY=echo File is \$F\:OF=\$2:} else {
     if('\$1'=='pss'){dev postencap :SY=echo File is \$F\:OF=\$2:}
     }}}}
###### SET SOME DEFAULT VALUES #################################################
     define print_noheader 1      # when printing vectors, dont print a header
     define TeX_strings 1         # use TeX.  (commented out in .sm file, comment out if undesired)
     ltype 0       # 0 solid | 1 dot | 2 short dash | 3 long dash | 4 dot-short-dash
     	   	   # 5 dot-long-dash | 6 short-long dash | 10 erase lines | also ltype expand
     lweight 3	   #
     ptype 4 3	   # ptype n s, n: sided polygon (30max for circle)
     	     	   #            s: 0 open, 1 skeletal, 2 starred, 3 solid  
     ctype black
################################################################################
################################################################################
#
#   START SCRIPT HERE
#
################################################################################
################################################################################
     foreach var ( period mag mer PER LPER Kmag Kmer Vmag ) {delete \$var}
     data "${output}_2"
     read !{ id 1.s mag1 4 period 5  type 6.s dr 7.f bmag 8 bmer 9 vmag 10 vmer 11 imag 12 imer 13 jmag 14 jmer 15 hmag 16 hmer 17 kmag 18 kmer 19 lmag 20 lmer 21 mmag 22 mmer 23  }
     set dr = dr*60

     define magmax 20
     define magmin 10

     set mag = kmag
     set mer = kmer

     if ( '$filter' == 'Ks' ) {
       set mag = kmag
       set mer = kmer
     }
     if ( '$filter' == 'H' ) {
       set mag = hmag
       set mer = hmer
     }
     if ( '$filter' == '3p6um' ) {
       set mag = lmag
       set mer = lmer
     }
     if ( '$filter' == '4p5um' ) {
       set mag = mmag
       set mer = mmer
     }

    if ( '$PROJECT' == 'CRRP' ) {
     define crit " (mag < \$magmax && mag > \$magmin) && (mer < 99 && mer > 0) && (mag1 < 99 && mag1 > 0)  &&  (type == 'RRab' || type == 'RRc' )  "
     define crit1 " (mag < \$magmax && mag > \$magmin) && (mer < 99 && mer > 0) && (type == 'RRab' || type == 'RRc' )   "
#     define crit " (mag < \$magmax && mag > \$magmin) && (mag1 < 99 && mag1 > 0) &&  (type == 'RRab' )  "
#     define crit1 " (mag < \$magmax && mag > \$magmin) && (type == 'RRab' )   " 
    }

    if ( '$PROJECT' == 'CHP' ) {
     define crit " (mag < \$magmax && mag > \$magmin) && (mer < 99 && mer > 0) && (mag1 < 99 && mag1 > 0)  &&  (type == 'CEPH' )  "
     define crit1 " (mag < \$magmax && mag > \$magmin) && (mer < 99 && mer > 0) && (type == 'CEPH' )   "
    }

     set lper = lg(period)
#     set lper = (type == 'RRc' || (type == 'RRd' && lper < -0.4) ) ? lper+0.127 : lper
     set lper = (type == 'RRc' ) ? lper+0.127 : lper

#     set mag = mag + $MZP
     set mag = mag 

     if ( '$name' == 'Reticulum' && $dallora == 1 ) {
	data "$refdir/authors/dallora2004.txt"
	read !{ dlper 2 dmag 4 dmer 5 dtype 6.s }
	set dlper = (dtype == 'c' ) ? dlper+0.127 : dlper
#       http://www.astro.caltech.edu/~jmc/2mass/v3/transformations/
	set dmag = dmag - 0.015
     }

     set LPER1 = lper if(\$crit1)
     set Kmag1 = mag  if(\$crit1)
     set Kmer1 = mer if(\$crit1)
     set dr1 = dr if(\$crit1)

     set PER = period if(\$crit)
     set LPER = lper if(\$crit)
     set ID = id if(\$crit)
     set Kmag = mag  if(\$crit)
     set Kmer = mer if(\$crit)
     set Vmag = mag1 if(\$crit)
     set color = Vmag - Kmag
     set TYPE = type if(\$crit)

     set meas = Kmag1
     set weight = 1/Kmer1**2
     set one = 1 + 0*meas
     set design = { one LPER1 }
#     print {meas weight}
     linfit2 design meas fit varfit weight 
     allfit LPER1 Kmag1 Kmer1
#     print {fit varfit linfit2_rms linfit2_rms2 }     
#     allfit LPER meas mer

     set xfit = -1,2,0.01
     set yfit = fit[0] + fit[1]*xfit


     define yoff 0.65

# PLOT PL
     window 1 1 1 1
     toplabel $name
     set width = 1.2
    if ( '$PROJECT' == 'CRRP' ) {
     define plotminp -0.4999
     define plotmaxp -0.04499
     }
    if ( '$PROJECT' == 'CHP' ) {
     define plotminp 0
     define plotmaxp 2
     }

     astats meas
     limits \$plotminp \$plotmaxp \$(astats[3]+width/2) \$(astats[3]-width/2)
#     limits \$plotminp \$plotmaxp meas
     box 1 2 0 0
     xlabel LogP[d]

     if ('$PROJECT' == 'CRRP') {
       ptype 30 3
       ctype black
       points lper mag if(type == 'RRab')
       legend 0.05 \$yoff 5 3 1 1.2 0 "RRab                   "
       ptype 30 0
       points lper mag if(type == 'RRc')
       legend 0.05 \$yoff 5 4 1 1.2 0 "RRc fundamentalized"
       ptype 4 0
       points lper mag if(type == 'RRd' )
       legend 0.05 \$yoff 5 5 1 1.2 0 "RRd "
       if ( $plot_error == 1 ){
 	 error_y lper mag mer
       }
       expand 3
       ptype 4 1
       points lper mag if( ! ( \$crit1 ) )
     }
     if ('$PROJECT' == 'CHP') {
       ptype 30 3
       ctype black
       points lper mag
       legend 0.05 \$yoff 5 3 1 1.2 0 "CEPH                  "
       if ( $plot_error == 1 ){
 	 error_y lper mag mer
       }
     }

     expand 1
     ylabel $pfilt
     connect xfit yfit
     ltype 1
     connect xfit (yfit + 2*linfit2_rms)
     connect xfit (yfit - 2*linfit2_rms)
     legend 0.05 \$yoff 5 2 1 1.2 1 "\pm 2\sigma "
     ltype 0

     set lb = '$pfilt = \$(sprintf('%5.2f',fit[1]))(LogP)+\$(sprintf('%5.2f',fit[0]))  \\\sigma=\$(sprintf('%5.3f',linfit2_rms)) n=\$(dimen(meas)) '

     legend 0.05 \$yoff 5 1 1 1.2 1 "\$!(lb[0])"

     expand 1

     if ( '$name' == 'Reticulum' && $dallora == 1 ){
	ptype 30 0
	ctype red
	points dlper dmag
     }
     
     if ( $showid == 1 ) { 
	ctype gray
	ptype id
	points lper mag
	ctype black
     }

     if ( \$?2==0 ) {
       cursor
     }


# PLOT RESIDUALS VS DR
     page
     erase
     delete meas
     set meas = mag - (fit[0] + fit[1]*lper)
     window 1 1 1 1
     toplabel $name
     vecminmax dr _min _max

     limits 0 \$_max -1.5 1.5
     box 1 2 0 0
     xlabel Distance from Cluster Center [arc-minutes]
     ylabel PL residual
     ptype 30 3
     ctype black
     points dr meas if(type == 'RRab')
     legend 0.05 0.8 5 3 1 1.2 0 "RRab                   "
     ptype 30 0
     points dr meas if(type == 'RRc')
     legend 0.05 0.8 5 4 1 1.2 0 "RRc fundamentalized"
     ptype 4 1
     points dr meas if(type == 'RRd' )
     if ( $plot_error == 1 ){
	error_y dr meas mer
     }
     legend 0.05 0.8 5 5 1 1.2 0 "RRd "
     if ( $showid == 1 ) { 
	ctype gray
	ptype id
	points dr meas
	ctype black
     }


# PLOT PL
     page
     erase
     delete meas
     delete one
     delete weight
     set meas = Kmag
     set weight = 1/Kmer**2
     set one = 1 + 0*meas
     set design = { one color }
     linfit2 design meas fit varfit weight
     set xfit = -2,2,0.01
     set yfit = fit[0] + fit[1]*xfit

     window 1 1 1 1
     toplabel $name
#     limits color meas
#    limits 0.8 1.4 18.3 17.5
     astats color 
     define plotminc 0.5
     define plotmaxc 2.0
     astats meas
     limits \$plotminc \$plotmaxc \$(astats[3]+width/2) \$(astats[3]-width/2)
     box 1 2 0 0
     xlabel V-$pfilt

     ptype 30 3
     ctype black
     points color meas if(TYPE == 'RRab')
     legend 0.05 \$yoff 5 3 1 1.2 0 "RRab                   "
     ptype 30 0
     points color meas if(TYPE == 'RRc')
     legend 0.05 \$yoff 5 4 1 1.2 0 "RRc fundamentalized"
     ptype 4 1
     points color meas if(TYPE == 'RRd' )
     legend 0.05 \$yoff 5 5 1 1.2 0 "RRd "
     if ( $plot_error == 1 ){
	error_y color meas Kmer
     }
     ylabel $pfilt
     connect xfit yfit
     ltype 1
     connect xfit (yfit + 2*linfit2_rms)
     connect xfit (yfit - 2*linfit2_rms)
     legend 0.05 \$yoff 5 2 1 1.2 1 "\pm 2\sigma "
     ltype 0

     set lb = '$pfilt = \$(sprintf('%5.2f',fit[1]))(V-$pfilt)+\$(sprintf('%5.2f',fit[0]))  \\\sigma=\$(sprintf('%5.3f',linfit2_rms)) n=\$(dimen(meas))'
     legend 0.05 \$yoff 5 1 1 1.2 1 "\$!(lb[0])"
     expand 1


     if ( $showid == 1 ) { 
	ctype gray
	ptype ID
	points color meas
	ctype black
     }



     if ( \$?2==0 ) {
       cursor
     }

# PLOT PLC
     page
     erase

     set design = { one LPER color }
     linfit2 design meas fit varfit weight
     set xfit = -2,2,0.1
     set xfit2 = -2,2,0.1
     set yfit = fit[0] + fit[1]*xfit

     set meas = meas - fit[2]*color

     window 1 1 1 1
     toplabel $name
#     limits LPER meas
     astats meas
     limits \$plotminp \$plotmaxp \$(astats[3]+width/2) \$(astats[3]-width/2)
     box 1 2 0 0
     xlabel LogP[d]

     ptype 30 3
     ctype black
     points LPER meas if(TYPE == 'RRab')
     legend 0.05 \$yoff 5 3 1 1.2 0 "RRab                   "
     ptype 30 0
     points LPER meas if(TYPE == 'RRc')
     legend 0.05 \$yoff 5 4 1 1.2 0 "RRc fundamentalized"
     ptype 4 1
     points LPER meas if(TYPE == 'RRd' )
     legend 0.05 \$yoff 5 5 1 1.2 0 "RRd "
     if ( $plot_error == 1 ) {
	error_y LPER meas Kmer
     }
     ylabel $pfilt - \$(fit[2]) (V-$pfilt)
     connect xfit yfit
     ltype 1
     connect xfit (yfit + 2*linfit2_rms)
     connect xfit (yfit - 2*linfit2_rms)
     legend 0.05 \$yoff 5 2 1 1.2 1 "\pm 2\sigma "
     ltype 0

     set lb = '$pfilt = \$(sprintf('%5.2f',fit[1]))(logP)+\$(sprintf('%5.2f',fit[0])) +\$(sprintf('%5.2f',fit[2]))(V-$pfilt)  \\\sigma=\$(sprintf('%5.3f',linfit2_rms)) n=\$(dimen(meas))'
     legend 0.05 \$yoff 5 1 1 1.2 1 "\$!(lb[0])"
     expand 1

     if ( $showid == 1 ) { 
	ctype gray
	ptype ID
	points LPER meas
	ctype black
     }


################################################################################
################################################################################
#
#   END SCRIPT HERE
#
################################################################################
################################################################################
     if ( \$?2==0 ) {
       cursor
     }
}
if ( 1 == $smplot ) {
    plot pss $odir/pl_$filter.ps
} else {
    plot t
}
FIN

endif

#exit 0
################################################################################
################################################################################
################################################################################
################################################################################
################################################################################



cmd:
################################################################################
###  FIND ALL KNOWN STARS FOR CMD
if ( ! -e cmdstars.cat ) then
    echo no cmdstars.cat found.  Not looking for known stars.
    goto finish
endif
set output2 = $odir/acmd_${filter}.dat
rm -fr $output2
if ( $REDO_ANAL ) then
    rm -fr $output2 >>& /dev/null
endif

if ( -e $output2 ) then
    echo $output2 already exists.
else
    awk 'BEGIN{print  " NL    NX    NY  LOWBAD HIGHBAD  THRESH     AP1  PH/ADU  RNOISE    FRAD"}' > tmpall.als
#    awk 'BEGIN{print  "  1  5000  5000    -4.0 80000.0    5.45    4.00   74.00    1.74    4.00\n"}' >> tmpall.als
    awk 'BEGIN{printf  "  1 %5d %5d %7.1f %7.1f %7.2f %7.2f %7.2f %7.2f %7.2f\n\n",\
	'$NAXIS1','$NAXIS2','-100','$SATURATE','5','2','$GAIN','$EFFRN','5'}' >> tmpall.als
    awk '{print $1,$2}' cmdstars.cat > tmpall.cat
    sky2xy $refimage @tmpall.cat | paste cmdstars.cat - | awk ' ! /off/ {printf "%5d %10.3f %10.3f %7.6f %7.6f    0.000\n",$3,$(NF-1),$(NF),$4,0}' >> tmpall.als
    printf "\nFINDING KNOWN CMD STARS\n"
    $daopath/match.csh tmpall.als fourstar_$filter.mag$allframe stars_$filter -$crad $forder $dao
    mv fourstar_$filter.mtr fourstar_$filter.mtr.cmd 
    if ( ! -e stars_$filter.raw ) then
	echo "stars_$filter.raw not created.  Something went Wrong, exiting..."
	exit 0
    endif
    awk '{if(NR>3){$6=$6+'$MZP[1]'; print} }' stars_$filter.raw > $output2
endif
################################################################################



if ( 1 ) then
#>>& /dev/null
/usr/local/bin/sm -S << FIN #
VERBOSE 0
macro read "/Users/amonson/software/sm/monson_macros.sm"
macro read "/Users/amonson/software/sm/fitting_macros.sm"
xtcolours
macro plot 12 {
     if(\$?2==0){dev x11 -device 0 -bg white -fg white} else {
     if('\$1'=='lpr'){dev mypostscript \$2} else {
     if('\$1'=='ps'){dev postportfile_colour :SY=echo File is \$F\:OF=\$2:} else {
     if('\$1'=='psl'){dev postlandfile_colour :SY=echo File is \$F\:OF=\$2:} else {
     if('\$1'=='pss'){dev postencap :SY=echo File is \$F\:OF=\$2:}
     }}}}
###### SET SOME DEFAULT VALUES #################################################
     define print_noheader 1      # when printing vectors, dont print a header
     define TeX_strings 1         # use TeX.  (commented out in .sm file, comment out if undesired)
     ltype 0       # 0 solid | 1 dot | 2 short dash | 3 long dash | 4 dot-short-dash
     	   	   # 5 dot-long-dash | 6 short-long dash | 10 erase lines | also ltype expand
     lweight 3	   #
     ptype 4 3	   # ptype n s, n: sided polygon (30max for circle)
     	     	   #            s: 0 open, 1 skeletal, 2 starred, 3 solid  
     ctype black
################################################################################
################################################################################
#
#   START SCRIPT HERE
#
################################################################################
################################################################################

# PLOT RR LYRAE STARS
     foreach var ( mag1 mag mer PER LPER Vmag Vmer Kmag ) {delete \$var}
     data "${output}_2"


     read !{ id 1.s mag1 4 period 5  type 6.s dr 7.f bmag 8 bmer 9 vmag 10 vmer 11 imag 12 imer 13 jmag 14 jmer 15 hmag 16 hmer 17 kmag 18 kmer 19 lmag 20 lmer 21 mmag 22 mmer 23  }

     set mag = kmag
     set mer = kmer

     if ( '$filter' == 'Ks' ) {
       set mag = kmag
       set mer = kmer
     }
     if ( '$filter' == 'H' ) {
       set mag = hmag
       set mer = hmer
     }
     if ( '$filter' == '3p6um' ) {
       set mag = lmag
       set mer = lmer
     }
     if ( '$filter' == '4p5um' ) {
       set mag = mmag
       set mer = kmer
     }


     define crit " mag < 99 || mag1 < 99 "
     set Vmag = mag1 if(\$crit)
     set Kmag = mag if(\$crit)
     set Kmer = mer if(\$crit)

     window -4 1 1:3 1
     limits -0.6 4 21.5 10
     box 4 2 0 0

     expand 2
#     ptype  4 1
#     ctype gray1
     ptype  30 0
     ctype black
     if ( $OCMD ) {
	points (Vmag - Kmag) Vmag
	define filterx V
     } else {
	points (Vmag - Kmag) Kmag
	define filterx "$pfilt"
     }
     expand 1
     ctype black
     xlabel V-$pfilt
     ylabel \$filterx
     
     toplabel $name

# PLOT FIELD STARS
     foreach var ( mag1 mag mer PER LPER Vmag Vmer Kmag ) {delete \$var}
     data "$output2"
     read {mag1 4 mag 6 mer 7}

#     set mag = mag + $MZP
     set mag = mag

     define crit " mag < 99 || mag1 < 99 "
     set Vmag = mag1 if(\$crit)
     set Kmag = mag if(\$crit)
     set Kmer = mer if(\$crit)

     window -4 1 1:3 1
     limits -0.6 4 21.5 10
     box 1 2 0 0

#     ptype 30 3
#     ctype black
     ptype 1 1
     ctype black
     if ( $OCMD ) {
	points (Vmag - Kmag) Vmag
     } else {
	points (Vmag - Kmag) Kmag
     }

# PLOT ERRORS
     window -4 1 4 1
     limits -0.0099 0.1 21.5 10
     box 1 3 0 0

     set meas = lg(Kmer )
     set ONE = 1 + 0*meas
     set X = (Kmag)
     set design = {ONE X}
     linfit2 design meas fit varfit
     print {fit varfit}
     set xfit = 10,20,0.01
     set yfit = 10**(fit[0] + fit[1]*(xfit))

     set yfit2 = 2 * 10**(fit[0] + fit[1]*(Kmag))

     ptype 30 3
     ctype black

     if ( $OCMD ) {
	points Kmer Vmag
     } else {
	points Kmer Kmag
     }

     xlabel \sigma_{$pfilt}
#     connect yfit xfit
#     connect (2*yfit) xfit

#     ctype red
#     points Kmer Kmag if ( Kmer > yfit2 ) 

#     window -4 1 1:3 1
#     limits -0.6 4 20.5 12
#     points (Vmag - Kmag) Kmag if ( Kmer > yfit2 ) 



################################################################################
################################################################################
#
#   END SCRIPT HERE
#
################################################################################
################################################################################
     if ( \$?2==0 ) {
       cursor
     }
}
if ( 1 == $smplot ) {
    plot pss $odir/cmd_$filter.ps
} else {
    plot t
}
FIN

endif



finish:
echo "REFIMAGE = $refimage"
rm -fr $odir/final.ps
gs -sDEVICE=pswrite -sOutputFile=$odir/final.ps -dNOPAUSE -dBATCH $odir/*.ps

exit 0
